@@ -5,15 +5,14 @@
 
 #include "articleadmin.h"
 #include "articleviewbase.h"
-#include "articleview.h"
 #include "drawareamain.h"
-#include "toolbar.h"
 
 #include "skeleton/msgdiag.h"
 
 #include "jdlib/miscutil.h"
 #include "jdlib/miscgtk.h"
 #include "jdlib/miscx.h"
+#include "jdlib/misccharcode.h"
 
 #include "dbtree/articlebase.h"
 #include "dbtree/interface.h"
@@ -24,6 +23,10 @@
 
 #include "config/globalconf.h"
 
+#include "history/historymanager.h"
+
+#include "message/logmanager.h"
+
 #include "global.h"
 #include "httpcode.h"
 #include "command.h"
@@ -36,6 +39,8 @@
 #include "controlutil.h"
 #include "controlid.h"
 
+#include "icons/iconmanager.h"
+
 #include <sstream>
 #include <cstring>
 
@@ -59,17 +64,25 @@ ArticleViewBase::ArticleViewBase( const std::string& url )
       m_popup_shown( false ),
       m_enable_menuslot( true ),
       m_current_bm( 0 ),
-      m_show_url4report( false )
+      m_show_url4report( false ),
+      m_url_show_status( false ),
+      m_enable_live( false ),
+      m_live( false )
 {
 #ifdef _DEBUG    
     std::cout << "ArticleViewBase::ArticleViewBase : " << get_url() << std::endl;
 #endif
 
+    set_id_toolbar( TOOLBAR_ARTICLE );
+
     // マウスジェスチャ可能
     set_enable_mg( true );
 
     // コントロールモード設定
     get_control().add_mode( CONTROL::MODE_ARTICLE );
+
+    // 板名セット
+    update_boardname();
 }
 
 
@@ -85,6 +98,11 @@ ArticleViewBase::~ArticleViewBase()
 }
 
 
+SKELETON::Admin* ArticleViewBase::get_admin()
+{
+    return ARTICLE::get_admin();
+}
+
 
 //
 // コピー用URL( readcgi型 )
@@ -111,12 +129,6 @@ DrawAreaBase* ArticleViewBase::drawarea()
 }
 
 
-ArticleToolBar* ArticleViewBase::get_articletoolbar()
-{
-    return dynamic_cast< ArticleToolBar* >( get_toolbar() );
-}
-
-
 DrawAreaBase* ArticleViewBase::create_drawarea()
 {
     return Gtk::manage( new ARTICLE::DrawAreaMain( m_url_article ) );
@@ -150,48 +162,13 @@ void ArticleViewBase::setup_view()
     m_drawarea->sig_on_url().connect( sigc::mem_fun(*this, &ArticleViewBase::slot_on_url ) );
     m_drawarea->sig_leave_url().connect( sigc::mem_fun(*this, &ArticleViewBase::slot_leave_url ) );
 
-    pack_widget();
+    pack_start( *m_drawarea, Gtk::PACK_EXPAND_WIDGET );
     setup_action();
 
     show_all_children();    
 }
 
 
-//
-// ツールバーやスクロールバーのパッキング
-//
-void ArticleViewBase::pack_widget()
-{
-    // ツールバーの設定
-    set_toolbar( Gtk::manage( new ArticleToolBar() ) );
-    get_articletoolbar()->get_close_button().signal_clicked().connect( sigc::mem_fun(*this, &ArticleViewBase::close_view ) );
-    get_articletoolbar()->m_button_reload.signal_clicked().connect( sigc::mem_fun(*this, &ArticleViewBase::slot_push_reload ) );
-    get_articletoolbar()->m_button_write.signal_clicked().connect( sigc::mem_fun(*this, &ArticleViewBase::slot_push_write ) );
-    get_articletoolbar()->m_button_delete.signal_clicked().connect( sigc::mem_fun(*this, &ArticleViewBase::slot_push_delete ) );        
-    get_articletoolbar()->m_button_board.signal_clicked().connect( sigc::mem_fun(*this, &ArticleViewBase::slot_push_open_board ) );
-    get_articletoolbar()->m_button_favorite.signal_clicked().connect( sigc::mem_fun(*this, &ArticleViewBase::slot_favorite ) );
-    get_articletoolbar()->m_button_stop.signal_clicked().connect( sigc::mem_fun(*this, &ArticleViewBase::stop ) );
-    get_articletoolbar()->m_button_open_search.signal_clicked().connect( sigc::mem_fun(*this, &ArticleViewBase::slot_push_open_search ) );
-
-    // 検索バー
-    get_articletoolbar()->m_entry_search.signal_activate().connect( sigc::mem_fun( *this, &ArticleViewBase::slot_active_search ) );
-    get_articletoolbar()->m_entry_search.signal_operate().connect( sigc::mem_fun( *this, &ArticleViewBase::slot_entry_operate ) );
-    get_articletoolbar()->m_button_close_search.signal_clicked().connect( sigc::mem_fun(*this, &ArticleViewBase::slot_push_close_search ) );
-    get_articletoolbar()->m_button_up_search.signal_clicked().connect( sigc::mem_fun(*this, &ArticleViewBase::slot_push_up_search ) );
-    get_articletoolbar()->m_button_down_search.signal_clicked().connect( sigc::mem_fun(*this, &ArticleViewBase::slot_push_down_search ) );
-    get_articletoolbar()->m_button_drawout_and.signal_clicked().connect( sigc::mem_fun(*this, &ArticleViewBase::slot_push_drawout_and ) );
-    get_articletoolbar()->m_button_drawout_or.signal_clicked().connect( sigc::mem_fun(*this, &ArticleViewBase::slot_push_drawout_or ) );
-    get_articletoolbar()->m_button_clear_hl.signal_clicked().connect( sigc::mem_fun(*this, &ArticleViewBase::slot_push_claar_hl ) );
-
-    if( SESSION::get_show_article_toolbar() ) get_articletoolbar()->show_toolbar();
-
-    pack_start( *get_articletoolbar(), Gtk::PACK_SHRINK );
-    pack_start( *m_drawarea, Gtk::PACK_EXPAND_WIDGET );
-}
-
-
-
-
 //
 // アクション初期化
 //
@@ -212,9 +189,9 @@ void ArticleViewBase::setup_action()
                          sigc::bind< bool >( sigc::mem_fun( *this, &ArticleViewBase::slot_copy_res ), false ) );
     action_group()->add( Gtk::Action::create( "CopyResRef", "引用コピー(_F)"),
                          sigc::bind< bool >( sigc::mem_fun( *this, &ArticleViewBase::slot_copy_res ), true ) );
-    action_group()->add( Gtk::Action::create( "Delete", "削除"), sigc::mem_fun( *this, &ArticleViewBase::delete_view ) );
+    action_group()->add( Gtk::Action::create( "Delete", "削除"), sigc::mem_fun( *this, &ArticleViewBase::exec_delete ) );
     action_group()->add( Gtk::Action::create( "DeleteOpen", "スレ情報を消さずにスレ再取得(_R)"), sigc::mem_fun( *this, &ArticleViewBase::delete_open_view ) );
-    action_group()->add( Gtk::Action::create( "Favorite", "お気に入りに登録する(_F)"), sigc::mem_fun( *this, &ArticleViewBase::slot_favorite ) );
+    action_group()->add( Gtk::Action::create( "Favorite", "お気に入りに登録する(_F)"), sigc::mem_fun( *this, &ArticleViewBase::set_favorite ) );
     action_group()->add( Gtk::Action::create( "Preference", "スレのプロパティ(_T)..."), sigc::mem_fun( *this, &ArticleViewBase::show_preference ) );
     action_group()->add( Gtk::Action::create( "PreferenceImage", "画像のプロパティ(_M)..."), sigc::mem_fun( *this, &ArticleViewBase::slot_preferences_image ) );
     action_group()->add( Gtk::Action::create( "SaveDat", "datファイルを保存(_S)..."), sigc::mem_fun( *this, &ArticleViewBase::slot_save_dat ) );
@@ -234,6 +211,7 @@ void ArticleViewBase::setup_action()
     action_group()->add( Gtk::Action::create( "DrawoutNAME", "名前抽出(_E)"), sigc::mem_fun( *this, &ArticleViewBase::slot_drawout_name ) );
     action_group()->add( Gtk::Action::create( "DrawoutID", "ID抽出(_I)"), sigc::mem_fun( *this, &ArticleViewBase::slot_drawout_id ) );
     action_group()->add( Gtk::Action::create( "DrawoutBM", "しおり抽出(_B)"), sigc::mem_fun( *this, &ArticleViewBase::slot_drawout_bm ) );
+    action_group()->add( Gtk::Action::create( "DrawoutPost", "書き込み抽出(_W)"), sigc::mem_fun( *this, &ArticleViewBase::slot_drawout_post ) );
     action_group()->add( Gtk::Action::create( "DrawoutURL", "URL抽出(_U)"), sigc::mem_fun( *this, &ArticleViewBase::slot_drawout_url ) );
     action_group()->add( Gtk::Action::create( "DrawoutRefer", "参照抽出(_E)"), sigc::mem_fun( *this, &ArticleViewBase::slot_drawout_refer ) );
     action_group()->add( Gtk::Action::create( "DrawoutAround", "周辺抽出(_A)"), sigc::mem_fun( *this, &ArticleViewBase::slot_drawout_around ) );
@@ -270,6 +248,10 @@ void ArticleViewBase::setup_action()
     action_group()->add( Gtk::Action::create( "PreBookMark", "PreBookMark"), sigc::mem_fun( *this, &ArticleViewBase::slot_pre_bm ) );
     action_group()->add( Gtk::Action::create( "NextBookMark", "NextBookMark"), sigc::mem_fun( *this, &ArticleViewBase::slot_next_bm ) );
     action_group()->add( Gtk::Action::create( "Jump", "ジャンプ(_J)"), sigc::mem_fun( *this, &ArticleViewBase::slot_jump ) );
+    action_group()->add( Gtk::Action::create( "PrevView", "PrevView"),
+                         sigc::bind< int >( sigc::mem_fun( *this, &ArticleViewBase::back_viewhistory ), 1 ) );
+    action_group()->add( Gtk::Action::create( "NextView", "NextView"),
+                         sigc::bind< int >( sigc::mem_fun( *this, &ArticleViewBase::forward_viewhistory ), 1 ) );
 
     // 画像系
     action_group()->add( Gtk::Action::create( "Cancel_Mosaic", "モザイク解除(_C)"), sigc::mem_fun( *this, &ArticleViewBase::slot_cancel_mosaic ) );
@@ -385,14 +367,19 @@ void ArticleViewBase::setup_action()
     "<menu action='Drawout_Menu'>"
     "<menuitem action='DrawoutWord'/>"
     "<menuitem action='DrawoutBM'/>"
+    "<menuitem action='DrawoutPost'/>"
     "<menuitem action='DrawoutURL'/>"
     "<menuitem action='DrawoutTmp'/>"
     "</menu>"
 
     "<menu action='Move_Menu'>"
+    "<menuitem action='PrevView'/>"
+    "<menuitem action='NextView'/>"
+    "<separator/>"
     "<menuitem action='Home'/>"
     "<menuitem action='End'/>"
     "<menuitem action='GotoNew'/>"
+    "<separator/>"
     "<menuitem action='PreBookMark'/>"
     "<menuitem action='NextBookMark'/>"
     "</menu>"
@@ -415,10 +402,8 @@ void ArticleViewBase::setup_action()
 
     "<menuitem action='SearchWeb'/>"
     "<separator/>"
-
     "<menuitem action='SearchTitle' />"
     "<separator/>"
-
     "<menuitem action='SearchCacheLocal'/>"
     "<menu action='SearchCacheAll'>"
     "<menuitem action='ExecSearchCacheAll'/>"
@@ -553,10 +538,42 @@ bool ArticleViewBase::set_command( const std::string& command, const std::string
     else if( command == "append_html" ) append_html( arg );
     else if( command == "clear_screen" )
     {
-    	if( m_drawarea ) m_drawarea->clear_screen();
+        if( m_drawarea ) m_drawarea->clear_screen();
     }
     else if( command == "goto_num" ) goto_num( atoi( arg.c_str() ) );
     else if( command == "delete_popup" ) delete_popup();
+    else if( command == "clear_highlight" ) clear_highlight();
+
+    // 実況手動切り替え
+    else if( command == "live_start_stop" ){
+
+        if( ! get_enable_live() ){
+
+            if( m_enable_live && ! DBTREE::board_get_live_sec( m_url_article ) ){
+                SKELETON::MsgDiag mdiag( NULL, "実況を行うには板のプロパティで更新間隔を設定して下さい。" );
+                mdiag.run();
+            }
+
+            return true;
+        }
+
+        if( get_live() ){
+            live_stop();
+
+            // 実況したスレは終了時に削除する
+            SESSION::remove_delete_list( m_url_article );
+        }
+        else{
+            live_start();
+
+            // 手動で停止した場合は終了時の削除をキャンセルする
+            SESSION::append_delete_list( m_url_article );
+        }
+    }
+
+    // dat落ちや更新が無い場合は実況停止
+    // 終了時にスレを削除する
+    else if( command == "live_stop" && get_enable_live() ) live_stop();
 
     return true;
 }
@@ -567,6 +584,7 @@ bool ArticleViewBase::set_command( const std::string& command, const std::string
 //
 // クロックタイマーの本体はコアが持っていて、定期的にadminがアクティブなviewにクロック入力を渡す
 //
+// virtual
 void ArticleViewBase::clock_in()
 {
     assert( m_drawarea );
@@ -580,16 +598,44 @@ void ArticleViewBase::clock_in()
     }
 
     m_drawarea->clock_in();
-
-    return;
 }
 
 
+//
+// スムーススクロール用クロック入力
+//
+// タイマー本体はArticleAdminが持っている
+//
+void ArticleViewBase::clock_in_smooth_scroll()
+{
+    assert( m_drawarea );
+
+    // ポップアップが出てたらそっちにクロックを回す
+    if( is_popup_shown() && m_popup_win->view() ){
+        ArticleViewBase* view = dynamic_cast< ArticleViewBase* >( m_popup_win->view() );
+        if( view ) view->clock_in_smooth_scroll();
+        return;
+    }
+
+    m_drawarea->clock_in_smooth_scroll();
+}
+
 
 //
-// 再読み込み
+// 再読み込みボタンを押した
 //
 void ArticleViewBase::reload()
+{
+    if( CONFIG::get_reload_allthreads() ) ARTICLE::get_admin()->set_command( "reload_all_tabs" );
+    else exec_reload();
+}
+
+
+//
+// 再読み込み実行
+//
+// virtual
+void ArticleViewBase::exec_reload()
 {
     // オフライン
     if( ! SESSION::is_online() ){
@@ -689,9 +735,18 @@ void ArticleViewBase::close_view()
 
 
 //
-// 記事削除
+// 削除ボタンを押した
 //
 void ArticleViewBase::delete_view()
+{
+    show_popupmenu( "popup_menu_delete", false );
+}
+
+
+//
+// 削除実行
+//
+void ArticleViewBase::exec_delete()
 {
     CORE::core_set_command( "delete_article", m_url_article );
     ARTICLE::get_admin()->set_command( "switch_admin" );
@@ -719,6 +774,13 @@ void ArticleViewBase::delete_open_view()
 }
 
 
+// 実況可能か
+const bool ArticleViewBase::get_enable_live()
+{
+    return ( m_enable_live && DBTREE::board_get_live_sec( m_url_article ) );
+}
+
+
 //
 // マウスポインタをポップアップの上に移動する
 // 
@@ -765,7 +827,7 @@ void ArticleViewBase::operate_view( const int& control )
             
         // リロード
         case CONTROL::Reload:
-            slot_push_reload();
+            exec_reload();
             break;
 
             // コピー
@@ -788,11 +850,11 @@ void ArticleViewBase::operate_view( const int& control )
             break;
 
         case CONTROL::SearchNext:
-            slot_push_down_search();
+            down_search();
             break;
 
         case CONTROL::SearchPrev:
-            slot_push_up_search();
+            up_search();
             break;
 
             // 閉じる
@@ -802,7 +864,7 @@ void ArticleViewBase::operate_view( const int& control )
 
             // 書き込み
         case CONTROL::WriteMessage:
-            slot_push_write();
+            write();
             break;
 
             // 削除
@@ -822,7 +884,7 @@ void ArticleViewBase::operate_view( const int& control )
 #endif
             mdiag.set_default_response( Gtk::RESPONSE_YES );
             int ret = mdiag.run();
-            if( ret == Gtk::RESPONSE_YES ) delete_view();
+            if( ret == Gtk::RESPONSE_YES ) exec_delete();
             else if( ret == Gtk::RESPONSE_YES + 100 ) delete_open_view();
             break;
         }
@@ -850,6 +912,15 @@ void ArticleViewBase::operate_view( const int& control )
             ARTICLE::get_admin()->set_command( "tab_right" );
             break;
 
+            // 戻る、進む
+        case CONTROL::PrevView:
+            back_viewhistory( 1 );
+            break;
+
+        case CONTROL::NextView:
+            forward_viewhistory( 1 );
+            break;
+
         // ポップアップメニュー表示
         case CONTROL::ShowPopupMenu:
             show_popupmenu( "", true );
@@ -879,6 +950,11 @@ void ArticleViewBase::operate_view( const int& control )
         case CONTROL::ShowMenuBar:
             CORE::core_set_command( "toggle_menubar" );
             break;
+
+            // 実況モード切り替え
+        case CONTROL::LiveStartStop:
+            ARTICLE::get_admin()->set_command( "live_start_stop", get_url() );
+            break;
     }
 }
 
@@ -923,18 +999,6 @@ void ArticleViewBase::goto_num( int num )
 }
 
 
-//
-// ツールバー表示切り替え
-//
-void ArticleViewBase::toggle_toolbar()
-{
-    if( ! get_articletoolbar() ) return;
-
-    if( SESSION::get_show_article_toolbar() ) get_articletoolbar()->show_toolbar();
-    else get_articletoolbar()->hide_toolbar();
-}
-
-
 //
 // 新着に移動
 //
@@ -951,47 +1015,18 @@ void ArticleViewBase::goto_new()
 //
 void ArticleViewBase::open_searchbar( bool invert )
 {
-    if( ! get_articletoolbar() ) return;
-
-    get_articletoolbar()->show_searchbar(); 
+    ARTICLE::get_admin()->set_command( "open_searchbar", get_url() );
     m_search_invert = invert;
-    get_articletoolbar()->m_entry_search.grab_focus(); 
-}
-
-
-
-//
-// 検索バーを開くボタンを押した
-//
-void ArticleViewBase::slot_push_open_search()
-{
-    if( ! get_articletoolbar() ) return;
-
-    if( ! get_articletoolbar()->m_searchbar_shown ) open_searchbar( false );
-    else slot_push_close_search();
-}
-
-
-
-//
-// 検索バーを隠すボタンを押した
-//
-void ArticleViewBase::slot_push_close_search()
-{
-    if( ! get_articletoolbar() ) return;
-
-    get_articletoolbar()->hide_searchbar();
-    m_drawarea->focus_view();
 }
 
 
 //
 // 前を検索
 //
-void ArticleViewBase::slot_push_up_search()
+void ArticleViewBase::up_search()
 {
     m_search_invert = true;
-    slot_active_search();
+    exec_search();
     redraw_view();
 }
 
@@ -1000,101 +1035,36 @@ void ArticleViewBase::slot_push_up_search()
 //
 // 次を検索
 //
-void ArticleViewBase::slot_push_down_search()
+void ArticleViewBase::down_search()
 {
     m_search_invert = false;
-    slot_active_search();
+    exec_search();
     redraw_view();
 }
 
 
-
-//
-// 別のタブを開いてキーワード抽出 (AND)
-//
-void ArticleViewBase::slot_push_drawout_and()
-{
-    if( ! get_articletoolbar() ) return;
-    if( get_articletoolbar()->m_entry_search.completion() ) return;
-
-    std::string query = get_articletoolbar()->m_entry_search.get_text();
-    if( query.empty() ) return;
-
-    CORE::core_set_command( "open_article_keyword" ,m_url_article, query, "false" );
-}
-
-
-//
-// 別のタブを開いてキーワード抽出 (OR)
-//
-void ArticleViewBase::slot_push_drawout_or()
-{
-    if( ! get_articletoolbar() ) return;
-    if( get_articletoolbar()->m_entry_search.completion() ) return;
-
-    std::string query = get_articletoolbar()->m_entry_search.get_text();
-    if( query.empty() ) return;
-
-    CORE::core_set_command( "open_article_keyword" ,m_url_article, query, "true" );
-}
-
-
 //
 // ハイライト解除
 //
-void ArticleViewBase::slot_push_claar_hl()
+void ArticleViewBase::clear_highlight()
 {
     assert( m_drawarea );
-    if( m_query.empty() ) return;
+    if( get_pre_query().empty() ) return;
 
-    m_query = std::string();
+    set_pre_query( std::string() );
     m_drawarea->clear_highlight();
 }
 
 
-//
-// リロードボタン
-//
-void ArticleViewBase::slot_push_reload()
-{
-    if( CONFIG::get_reload_allthreads() ) ARTICLE::get_admin()->set_command( "reload_all_tabs" );
-    else reload();
-}
-
-
 //
 // メッセージ書き込みボタン
 //
-void ArticleViewBase::slot_push_write()
+void ArticleViewBase::write()
 {
     CORE::core_set_command( "open_message" ,m_url_article, std::string() );
 }
 
 
-
-//
-// 削除ボタン
-//
-void ArticleViewBase::slot_push_delete()
-{
-    show_popupmenu( "popup_menu_delete", false );
-}
-
-
-//
-// 板を開くボタン
-//
-void ArticleViewBase::slot_push_open_board()
-{
-    CORE::core_set_command( "open_board", DBTREE::url_subject( m_url_article ), "true",
-                            "auto" // オートモードで開く
-        );
-}
-
-
-
-
-
 //
 // プロパティ表示
 //
@@ -1125,6 +1095,23 @@ void ArticleViewBase::slot_preferences_image()
 }
 
 
+//
+// 戻る
+//
+void ArticleViewBase::back_viewhistory( const int count )
+{
+    ARTICLE::get_admin()->set_command( "back_viewhistory", get_url(), MISC::itostr( count ) );
+}
+
+
+//
+// 進む
+//
+void ArticleViewBase::forward_viewhistory( const int count )
+{
+    ARTICLE::get_admin()->set_command( "forward_viewhistory", get_url(), MISC::itostr( count ) );
+}
+
 
 
 //
@@ -1214,7 +1201,7 @@ std::string ArticleViewBase::get_html_url4report( std::list< int >& list_resnum
     for( ; it != list_resnum.end(); ++it ){
 
         int num = (*it);
-        std::string time_str = m_article->get_time( num );
+        std::string time_str = m_article->get_time_str( num );
         std::string id_str = m_article->get_id_name( num );
 
         html += url_for_copy() + MISC::itostr( num );
@@ -1284,10 +1271,11 @@ void ArticleViewBase::show_name( const std::string& name, bool show_option )
         if( !m_show_url4report ) comment << " <a href=\"" << PROTO_URL4REPORT << "\">抽出したレスのURLをリスト表示</a>";
         else comment << "<br><br>" + get_html_url4report( list_resnum );
 
-        comment << "<br><br>" << url_for_copy() << MISC::intlisttostr( list_resnum ) << "<br>";
+        comment << "<br><br>" << url_for_copy() << MISC::intlisttostr( list_resnum ) << "<br><hr>";
     }
 
     append_html( comment.str() );
+
     if( ! list_resnum.empty() ) append_res( list_resnum );
 }
 
@@ -1314,10 +1302,11 @@ void ArticleViewBase::show_id( const std::string& id_name, bool show_option )
         if( !m_show_url4report ) comment << " <a href=\"" << PROTO_URL4REPORT << "\">抽出したレスのURLをリスト表示</a>";
         else comment << "<br><br>" + get_html_url4report( list_resnum );
 
-        comment << "<br><br>" << url_for_copy() << MISC::intlisttostr( list_resnum ) << "<br>";
+        comment << "<br><br>" << url_for_copy() << MISC::intlisttostr( list_resnum ) << "<br><hr>";
     }
       
     append_html( comment.str() );
+
     if( ! list_resnum.empty() ) append_res( list_resnum );
 }
 
@@ -1341,6 +1330,53 @@ void ArticleViewBase::show_bm()
 }
 
 
+//
+// 書き込みを抽出して表示
+//
+void ArticleViewBase::show_post()
+{
+    assert( m_article );
+
+#ifdef _DEBUG
+    std::cout << "ArticleViewBase::show_post " << std::endl;
+#endif
+    
+    std::list< int > list_resnum = m_article->get_res_posted();
+
+    if( ! list_resnum.empty() ) append_res( list_resnum );
+    else append_html( "このスレでは書き込みしていません" );
+}
+
+
+//
+// 書き込みログを表示
+//
+void ArticleViewBase::show_postlog( const int num )
+{
+    const int maxno = MESSAGE::get_log_manager()->get_max_num_of_log() + 1;
+
+    std::string html_header;
+    for( int i = 1; i <= maxno; ++i ){
+
+        int no;
+        if( i == 1 ) no = 0;
+        else no = maxno - ( i -1 );
+
+        if( no == num ) html_header += MISC::itostr( i ) + " ";
+        else html_header += std::string( "<a href=\"" ) + PROTO_POSTLOG + MISC::itostr( no ) + "\">" + MISC::itostr( i ) + "</a> ";
+    }
+
+#ifdef _DEBUG
+    std::cout << "ArticleViewBase::show_postlog " << num << " / " << maxno << std::endl
+              << html_header << std::endl;
+#endif
+
+    std::string html = MESSAGE::get_log_manager()->get_postlog( num );
+    if( html.empty() ) html = "書き込みログがありません";
+    else html = html_header + "<br>" + html + "<hr><br>" + html_header;
+
+    append_html( html );
+}
 
 
 //
@@ -1357,7 +1393,7 @@ void ArticleViewBase::show_res_with_url()
     std::list< int > list_resnum = m_article->get_res_with_url();
 
     if( ! list_resnum.empty() ) append_res( list_resnum );
-    else append_html( "リンクを含むスレはありません" );
+    else append_html( "リンクを含むレスはありません" );
 }
 
 
@@ -1407,7 +1443,7 @@ void ArticleViewBase::drawout_keywords( const std::string& query, bool mode_or,
         if( !m_show_url4report ) comment << " <a href=\"" << PROTO_URL4REPORT << "\">抽出したレスのURLをリスト表示</a>";
         else comment << "<br><br>" + get_html_url4report( list_resnum );
 
-        comment << "<br><br>" << url_for_copy() << MISC::intlisttostr( list_resnum ) << "<br>";
+        comment << "<br><br>" << url_for_copy() << MISC::intlisttostr( list_resnum ) << "<br><hr>";
     }
 
     append_html( comment.str() );
@@ -1495,6 +1531,13 @@ bool ArticleViewBase::slot_leave_notify( GdkEventCrossing* event )
 
     focus_out();
 
+    // ステータスバーの表示を戻す
+    if( m_url_show_status )
+    {
+        CORE::core_set_command( "restore_status", m_url_article );
+        m_url_show_status = false;
+    }
+
     return false;
 }
 
@@ -1546,14 +1589,19 @@ bool ArticleViewBase::slot_button_release( std::string url, int res_number, GdkE
 
             // マウスジェスチャ
             if( mg != CONTROL::None && enable_mg() ) operate_view( mg );
-                
-            else if( ! click_url( url, res_number, event ) ){
 
-                if( get_control().button_alloted( event, CONTROL::PopupmenuButton ) ){
-                    show_popupmenu( url, false );
-                }
-                else operate_view( get_control().button_press( event ) );
-            }
+            // リンクをクリック
+            else if( click_url( url, res_number, event ) );
+
+            // コンテキストメニュー表示
+            else if( get_control().button_alloted( event, CONTROL::PopupmenuButton ) ) show_popupmenu( url, false );
+
+            // 実況中の場合は停止
+            else if( get_control().button_alloted( event, CONTROL::ClickButton ) && get_live() )
+                ARTICLE::get_admin()->set_command( "live_start_stop", get_url() );
+
+            // その他
+            else operate_view( get_control().button_press( event ) );
         }
     }
 
@@ -1807,6 +1855,61 @@ void ArticleViewBase::slot_on_url( std::string url, int res_number )
     }
 
     if( view_popup ) show_popup( view_popup, margin_popup );
+
+    // リンクとして扱うURLをステータスバーに表示する
+    if( MISC::is_url_scheme( url.c_str() ) != MISC::SCHEME_NONE )
+    {
+        std::string status_url;
+
+        // デコードが必要な物
+        if( url.find( "%" ) != std::string::npos )
+        {
+            std::string tmp = MISC::url_decode( url );
+
+            const int char_code = MISC::judge_char_code( tmp );
+
+            switch( char_code )
+            {
+                case MISC::CHARCODE_EUC_JP:
+
+                    status_url = MISC::Iconv( tmp, "EUC-JP", "UTF-8" );
+                    break;
+
+                case MISC::CHARCODE_JIS:
+
+                    status_url = MISC::Iconv( tmp, "ISO-2022-JP", "UTF-8" );
+                    break;
+
+                case MISC::CHARCODE_SJIS:
+
+                    status_url = MISC::Iconv( tmp, "MS932", "UTF-8" );
+                    break;
+
+                case MISC::CHARCODE_ASCII:
+                case MISC::CHARCODE_UTF:
+
+                    status_url = tmp;
+                    break;
+
+                default:
+
+                    status_url = url;
+            }
+
+            // 改行はスペースに変えておく
+            status_url = MISC::replace_newlines_to_str( status_url, " " );
+        }
+        // デコードの必要がない物
+        else
+        {
+            status_url = url;
+        }
+
+        // 一時的にステータスバーにURLを表示( 長くても全部表示しちゃう？ )
+        CORE::core_set_command( "set_status_temporary", m_url_article, status_url );
+
+        m_url_show_status = true;
+    }
 }
 
 
@@ -1820,6 +1923,13 @@ void ArticleViewBase::slot_leave_url()
     std::cout << "ArticleViewBase::slot_leave_url\n";
 #endif
 
+    if( m_url_show_status )
+    {
+        // ステータスバーの表示を戻す
+        CORE::core_set_command( "restore_status", m_url_article );
+        m_url_show_status = false;
+    }
+
     hide_popup();
 }
 
@@ -1929,12 +2039,17 @@ bool ArticleViewBase::click_url( std::string url, int res_number, GdkEventButton
     else if( url.find( PROTO_URL4REPORT ) == 0 ){
 
         hide_popup();
+        m_show_url4report = true;
+        relayout();
+    }
 
-        if( control.button_alloted( event, CONTROL::PopupmenuAncButton ) ){
+    /////////////////////////////////////////////////////////////////
+    // 書き込みログ表示クリック
+    else if( url.find( PROTO_POSTLOG ) == 0 ){
 
-            m_show_url4report = true;
-            relayout();
-        }
+        hide_popup();
+
+        CORE::core_set_command( "open_article_postlog" ,"", url.substr( strlen( PROTO_POSTLOG ) ) );
     }
 
     /////////////////////////////////////////////////////////////////
@@ -2251,6 +2366,7 @@ void ArticleViewBase::activate_act_before_popupmenu( const std::string& url )
     if( is_popup_shown() ) popup_article = dynamic_cast< ArticleViewBase* >( m_popup_win->view() );
     if( popup_article && popup_article->is_mouse_on_view() ) return;
     hide_popup();
+
     Glib::RefPtr< Gtk::Action > act, act2;
     act = action_group()->get_action( "CopyURL" );
     act2 = action_group()->get_action( "OpenBrowser" );
@@ -2281,6 +2397,45 @@ void ArticleViewBase::activate_act_before_popupmenu( const std::string& url )
         else m_url_tmp = url;
     }
 
+    // 検索ビューや書き込みログ表示などの場合
+    const bool nourl = DBTREE::url_readcgi( m_url_article, 0, 0 ).empty();
+
+    act = action_group()->get_action( "Drawout_Menu" );
+    if( act ){
+        if( nourl ) act->set_sensitive( false );
+        else act->set_sensitive( true );
+    }
+
+    act = action_group()->get_action( "SearchCacheLocal" );
+    if( act ){
+        if( nourl ) act->set_sensitive( false );
+        else act->set_sensitive( true );
+    }
+
+    act = action_group()->get_action( "SearchCacheAll" );
+    if( act ){
+        if( nourl ) act->set_sensitive( false );
+        else act->set_sensitive( true );
+    }
+
+    act = action_group()->get_action( "QuoteRes" );
+    if( act ){
+        if( nourl ) act->set_sensitive( false );
+        else act->set_sensitive( true );
+    }
+
+    act = action_group()->get_action( "SaveDat" );
+    if( act ){
+        if( nourl ) act->set_sensitive( false );
+        else act->set_sensitive( true );
+    }
+
+    act = action_group()->get_action( "Preference" );
+    if( act ){
+        if( nourl ) act->set_sensitive( false );
+        else act->set_sensitive( true );
+    }
+
 
     // 範囲選択されてない
     const unsigned int max_selection_str = 1024;
@@ -2289,7 +2444,7 @@ void ArticleViewBase::activate_act_before_popupmenu( const std::string& url )
     std::string str_select = m_drawarea->str_selection();
     act = action_group()->get_action( "QuoteSelectionRes" );
     if( act ){
-        if( str_select.empty() || str_select.length() > max_selection_str_quote ) act->set_sensitive( false );
+        if( nourl || str_select.empty() || str_select.length() > max_selection_str_quote ) act->set_sensitive( false );
         else act->set_sensitive( true );
     }
 
@@ -2307,7 +2462,7 @@ void ArticleViewBase::activate_act_before_popupmenu( const std::string& url )
 
     act = action_group()->get_action( "AboneWord_Menu" );
     if( act ){
-        if( str_select.empty() || str_select.length() > max_selection_str ) act->set_sensitive( false );
+        if( nourl || str_select.empty() || str_select.length() > max_selection_str ) act->set_sensitive( false );
         else act->set_sensitive( true );
     }
 
@@ -2359,6 +2514,13 @@ void ArticleViewBase::activate_act_before_popupmenu( const std::string& url )
         else act->set_sensitive( false );
     }
 
+    // 書き込みしていない
+    act = action_group()->get_action( "DrawoutPost" );
+    if( act ){
+        if( m_article->get_num_posted() ) act->set_sensitive( true );
+        else act->set_sensitive( false );
+    }
+
     // 新着移動
     act = action_group()->get_action( "GotoNew" );
     if( act ){
@@ -2366,6 +2528,19 @@ void ArticleViewBase::activate_act_before_popupmenu( const std::string& url )
         else act->set_sensitive( false );
     }
 
+    // 進む、戻る
+    act = action_group()->get_action( "PrevView" );
+    if( act ){
+        if( HISTORY::get_history_manager()->can_back_viewhistory( get_url(), 1 ) ) act->set_sensitive( true );
+        else act->set_sensitive( false );
+    }
+
+    act = action_group()->get_action( "NextView" );
+    if( act ){
+        if( HISTORY::get_history_manager()->can_forward_viewhistory( get_url(), 1 ) ) act->set_sensitive( true );
+        else act->set_sensitive( false );
+    }
+
     // 透明あぼーん
     act = action_group()->get_action( "TranspAbone" );
     if( act ){
@@ -2552,7 +2727,6 @@ void ArticleViewBase::slot_drawout_selection_str()
 
     if( query.empty() ) return;
 
-    CORE::get_completion_manager()->set_query( CORE::COMP_SEARCH, query );
     CORE::core_set_command( "open_article_keyword" ,m_url_article, query, "false" );
 }
 
@@ -2819,7 +2993,7 @@ void ArticleViewBase::slot_copy_res( bool ref )
 //
 // お気に入り登録
 //
-void ArticleViewBase::slot_favorite()
+void ArticleViewBase::set_favorite()
 {
     CORE::DATA_INFO info;
     info.type = TYPE_THREAD;
@@ -2908,6 +3082,14 @@ void ArticleViewBase::slot_drawout_bm()
 }
 
 
+//
+// 別のタブを開いて自分の書き込みを抽出
+//
+void ArticleViewBase::slot_drawout_post()
+{
+    CORE::core_set_command( "open_article_post" ,m_url_article );
+}
+
 
 //
 // 別のタブを開いて参照抽出
@@ -3143,14 +3325,11 @@ void ArticleViewBase::slot_abone_img()
 //
 // 検索entryでenterを押した
 //
-void ArticleViewBase::slot_active_search()
+void ArticleViewBase::exec_search()
 {
-    if( ! get_articletoolbar() ) return;
-    if( get_articletoolbar()->m_entry_search.completion() ) return;
-
-    std::string query = get_articletoolbar()->m_entry_search.get_text();
+    std::string query = get_search_query();
     if( query.empty() ){
-        slot_push_claar_hl();
+        clear_highlight();
         focus_view();
         CORE::core_set_command( "set_info", "", "" );
         return;
@@ -3159,8 +3338,9 @@ void ArticleViewBase::slot_active_search()
     std::list< std::string > list_query;
     list_query = MISC::split_line( query );
 
-    if( m_query != query ){
-        m_query = query;
+    if( get_pre_query() != query ){
+        set_pre_query( query );
+        CORE::get_completion_manager()->set_query( CORE::COMP_SEARCH, query );
         m_drawarea->set_jump_history();
         m_drawarea->search( list_query, m_search_invert );
     }
@@ -3168,7 +3348,7 @@ void ArticleViewBase::slot_active_search()
     int hit = m_drawarea->search_move( m_search_invert );
 
     if( ! hit ){
-        slot_push_claar_hl();
+        clear_highlight();
         CORE::core_set_command( "set_info", "", "検索結果： ヒット無し" );
     }
     else{
@@ -3182,8 +3362,33 @@ void ArticleViewBase::slot_active_search()
 //
 // 検索entryの操作
 //
-void ArticleViewBase::slot_entry_operate( int controlid )
+void ArticleViewBase::operate_search( const std::string& controlid )
 {
-    if( controlid == CONTROL::Cancel ) focus_view();
-    else if( controlid == CONTROL::DrawOutAnd ) slot_push_drawout_and();
+    int id = atoi( controlid.c_str() );
+
+    if( id == CONTROL::Cancel ){
+        focus_view();
+        ARTICLE::get_admin()->set_command( "close_searchbar" );
+    }
+
+    // AND 抽出
+    else if( id == CONTROL::DrawOutAnd ){
+        std::string query = get_search_query();
+        if( query.empty() ) return;
+
+        CORE::core_set_command( "open_article_keyword" ,m_url_article, query, "false" );
+    }
+}
+
+
+//
+// 実況モードのセット
+//
+void ArticleViewBase::set_live( const bool live )
+{
+    if( ! m_enable_live ) return;
+
+    m_live = live;
+    if( m_live ) SESSION::append_live( m_url_article );
+    else SESSION::remove_live( m_url_article );
 }
