@@ -12,6 +12,8 @@ namespace ARTICLE
 {
     class ArticleViewPreview : public ArticleViewBase
     {
+        std::string m_url_messageview;
+
       public:
         ArticleViewPreview( const std::string& url );
         ~ArticleViewPreview();
@@ -19,13 +21,10 @@ namespace ARTICLE
         virtual void operate_view( const int& control );
 
       private:
-        virtual void pack_widget();
 
         virtual bool slot_button_press( std::string url, int res_number, GdkEventButton* event );
 
         virtual void goto_num( int num ){}
-        virtual void slot_drawout_id(){}        
-        virtual void slot_drawout_ref(){}        
     };
 }
 
