@@ -125,6 +125,7 @@ namespace ARTICLE
         SCROLLINFO m_scrollinfo;
         guint32 m_wheel_scroll_time; // 前回ホイールを回した時刻
         int m_goto_num_reserve; // 初期化時のジャンプ予約(レス番号)
+        bool m_goto_bottom_reserve; // 初期化時のジャンプ予約(底)
         int m_pre_pos_y; // ひとつ前のスクロールバーの位置。スクロールした時の差分量計算に使用する
         std::vector< int > m_jump_history;  // ジャンプ履歴
 
@@ -143,6 +144,15 @@ namespace ARTICLE
         // 埋め込み画像のポインタ
         std::list< EmbeddedImage* > m_eimgs;
 
+        // ブックマークアイコン
+        Glib::RefPtr< Gdk::Pixbuf > m_pixbuf_bkmk;
+
+        // 書き込みマークアイコン
+        Glib::RefPtr< Gdk::Pixbuf > m_pixbuf_post;
+
+        // 自分の書き込みに対するレスマークアイコン
+        Glib::RefPtr< Gdk::Pixbuf > m_pixbuf_refer_post;
+
       public:
 
         SIG_BUTTON_PRESS sig_button_press(){ return m_sig_button_press; }
@@ -163,6 +173,7 @@ namespace ARTICLE
         const int& height_client() const { return m_height_client; }
 
         void clock_in();
+        void clock_in_smooth_scroll();
         void focus_view();
         void focus_out();
 
@@ -238,10 +249,15 @@ namespace ARTICLE
         int search_move( bool reverse );
         void clear_highlight();
 
+        // 実況モード
+        void live_start();
+        void live_stop();
+        void update_live_speed( const int sec );
+
       protected:
 
         // バックスクリーン描画
-        bool draw_backscreen( bool redraw_all = false );
+        bool draw_backscreen( const bool redraw_all = false );
 
         // 文字色のID( colorid.h にある ID を指定)
         const int get_colorid_text() const{ return m_colorid_text; }
@@ -294,7 +310,7 @@ namespace ARTICLE
         void draw_one_text_node( LAYOUT* layout, const int width_win, const int pos_y );
         void draw_string( LAYOUT* node, const int pos_y, const int width_view,
                           const int color, const int color_back, const int byte_from, const int byte_to );
-        bool draw_one_img_node( LAYOUT* layout, const int pos_y );
+        bool draw_one_img_node( LAYOUT* layout, const int pos_y, const int upper, const int lower );
 
         // drawarea がリサイズ実行
         void configure_impl();
@@ -312,7 +328,7 @@ namespace ARTICLE
                                  const int x, const int y,
                                  int& pos, int& width_line, int& char_width, int& byte_char );
         LAYOUT* set_caret( CARET_POSITION& caret_pos, int x, int y );
-        bool set_carets_dclick( CARET_POSITION& caret_left, CARET_POSITION& caret_right,  int x, int y );
+        const bool set_carets_dclick( CARET_POSITION& caret_left, CARET_POSITION& caret_right,  const int x, const int y, const bool triple );
 
         // 範囲選択関係
         bool set_selection( CARET_POSITION& caret_left, CARET_POSITION& caret_right, const bool redraw = true );
