@@ -6,10 +6,12 @@
 
 #include "bbslistviewbase.h"
 #include "bbslistadmin.h"
+#include "addetcdialog.h"
 
 #include "skeleton/msgdiag.h"
 
 #include "jdlib/miscutil.h"
+#include "jdlib/miscgtk.h"
 #include "jdlib/jdregex.h"
 
 #include "dbtree/interface.h"
@@ -29,6 +31,7 @@
 #include "command.h"
 #include "global.h"
 #include "httpcode.h"
+#include "controlutil.h"
 #include "controlid.h"
 #include "dndmanager.h"
 #include "sharedbuffer.h"
@@ -38,9 +41,9 @@
 #include "fontid.h"
 #include "updatemanager.h"
 #include "session.h"
+#include "compmanager.h"
 
 #include <sstream>
-//#include <gtk/gtkversion.h> // GTK_CHECK_VERSION
 
 
 #ifndef MAX
@@ -65,18 +68,32 @@ show_popupmenu( url, slot ); \
 }while(0)
 
 
+#define POPUPMENU_BOARD1 \
+    "<menuitem action='OpenTab'/>" \
+    "<menuitem action='OpenBrowser'/>" \
+    "<separator/>" \
+    "<menuitem action='CopyURL'/>" \
+    "<menuitem action='CopyTitleURL'/>" \
+    "<separator/>" \
+    "<menuitem action='AppendFavorite'/>" \
+    "<separator/>"
+
+#define POPUPMENU_BOARD2 \
+    "<menuitem action='SearchCacheBoard'/>" \
+    "<separator/>" \
+    "<menuitem action='PreferenceBoard'/>" \
+    "</popup>" \
+
 
 using namespace BBSLIST;
 
 BBSListViewBase::BBSListViewBase( const std::string& url,const std::string& arg1, const std::string& arg2 )
     : SKELETON::View( url ),
       m_treeview( CONFIG::get_fontname( FONT_BBS ), COLOR_CHAR_BBS, COLOR_BACK_BBS, COLOR_BACK_BBS_EVEN ),
-      m_toolbar( SESSION::get_show_bbslist_toolbar() ),
       m_ready_tree( false ),
       m_jump_y( -1 ),
       m_dnd_counter( 0 ),
       m_search_invert( 0 ),
-      m_cancel_focus( 0 ),
       m_expand_collapse( 0 ),
       m_cancel_expand( false ),
       m_expanding( 0 )
@@ -84,14 +101,6 @@ BBSListViewBase::BBSListViewBase( const std::string& url,const std::string& arg1
     m_scrwin.add( m_treeview );
     m_scrwin.set_policy( Gtk::POLICY_AUTOMATIC, Gtk::POLICY_AUTOMATIC );
 
-    m_toolbar.m_entry_search.signal_activate().connect( sigc::mem_fun( *this, &BBSListViewBase::slot_active_search ) );
-    m_toolbar.m_button_up_search.signal_clicked().connect( sigc::mem_fun( *this, &BBSListViewBase::slot_push_up_search ) );
-    m_toolbar.m_button_down_search.signal_clicked().connect( sigc::mem_fun( *this, &BBSListViewBase::slot_push_down_search ) );
-    m_toolbar.m_entry_search.signal_operate().connect( sigc::mem_fun( *this, &BBSListViewBase::slot_entry_operate ) );
-    m_toolbar.m_button_close.signal_clicked().connect( sigc::mem_fun( *this, &BBSListViewBase::close_view ) );
-    m_toolbar.m_combo.signal_changed().connect( sigc::mem_fun( *this, &BBSListViewBase::slot_combo_changed ) );
-
-    pack_start( m_toolbar, Gtk::PACK_SHRINK );    
     pack_start( m_scrwin );
     show_all_children();    
 
@@ -147,36 +156,39 @@ BBSListViewBase::BBSListViewBase( const std::string& url,const std::string& arg1
     // ポップアップメニューの設定
     // アクショングループを作ってUIマネージャに登録
     action_group() = Gtk::ActionGroup::create();
-    action_group()->add( Gtk::Action::create( "OpenTab", "タブで開く"), sigc::mem_fun( *this, &BBSListViewBase::slot_open_tab ) );
-    action_group()->add( Gtk::Action::create( "OpenBrowser", "ブラウザで開く"), sigc::mem_fun( *this, &BBSListViewBase::slot_open_browser ) );
-    action_group()->add( Gtk::Action::create( "AppendFavorite", "AppendFavorite"), sigc::mem_fun( *this, &BBSListViewBase::slot_append_favorite ) );
-    action_group()->add( Gtk::Action::create( "NewDir", "新規ディレクトリ"), sigc::mem_fun( *this, &BBSListViewBase::slot_newdir ) );
-    action_group()->add( Gtk::Action::create( "NewCom", "コメント挿入"), sigc::mem_fun( *this, &BBSListViewBase::slot_newcomment ) );
-    action_group()->add( Gtk::Action::create( "Rename", "名前変更"), sigc::mem_fun( *this, &BBSListViewBase::slot_rename ) );
+    action_group()->add( Gtk::Action::create( "OpenTab", "タブで開く(_T)"), sigc::mem_fun( *this, &BBSListViewBase::slot_open_tab ) );
+    action_group()->add( Gtk::Action::create( "OpenBrowser", "ブラウザで開く(_W)"), sigc::mem_fun( *this, &BBSListViewBase::slot_open_browser ) );
+    action_group()->add( Gtk::Action::create( "AppendFavorite", "お気に入りに追加(_F)..."), sigc::mem_fun( *this, &BBSListViewBase::slot_append_favorite ) );
+    action_group()->add( Gtk::Action::create( "NewDir", "新規ディレクトリ(_N)"), sigc::mem_fun( *this, &BBSListViewBase::slot_newdir ) );
+    action_group()->add( Gtk::Action::create( "NewCom", "コメント挿入(_I)"), sigc::mem_fun( *this, &BBSListViewBase::slot_newcomment ) );
+    action_group()->add( Gtk::Action::create( "NewEtc", "外部板追加(_E)..."), sigc::mem_fun( *this, &BBSListViewBase::slot_newetcboard ) );
+    action_group()->add( Gtk::Action::create( "MoveEtc", "編集(_E)..."), sigc::mem_fun( *this, &BBSListViewBase::slot_moveetcboard ) );
+    action_group()->add( Gtk::Action::create( "Rename", "名前変更(_R)"), sigc::mem_fun( *this, &BBSListViewBase::slot_rename ) );
     action_group()->add( Gtk::Action::create( "Delete_Menu", "Delete" ) );    
-    action_group()->add( Gtk::Action::create( "Delete", "お気に入りから削除する"), sigc::mem_fun( *this, &BBSListViewBase::delete_view ) );
-    action_group()->add( Gtk::Action::create( "OpenRows", "選択した行を開く"), sigc::mem_fun( *this, &BBSListViewBase::open_selected_rows ) );
+    action_group()->add( Gtk::Action::create( "Delete", "お気に入りから削除する(_D)"), sigc::mem_fun( *this, &BBSListViewBase::delete_view_impl ) );
+    action_group()->add( Gtk::Action::create( "Delete_etc", "外部板を削除する(_D)"), sigc::mem_fun( *this, &BBSListViewBase::delete_view_impl ) );
+    action_group()->add( Gtk::Action::create( "OpenRows", "選択した行を開く(_O)"), sigc::mem_fun( *this, &BBSListViewBase::open_selected_rows ) );
 
-    action_group()->add( Gtk::Action::create( "CheckUpdateRows", "更新チェックのみ"), sigc::mem_fun( *this, &BBSListViewBase::slot_checkupdate_selected_rows ) );
-    action_group()->add( Gtk::Action::create( "CheckUpdateOpenRows", "更新されたスレをタブで開く"),
+    action_group()->add( Gtk::Action::create( "CheckUpdateRows", "更新チェックのみ(_H)"), sigc::mem_fun( *this, &BBSListViewBase::slot_checkupdate_selected_rows ) );
+    action_group()->add( Gtk::Action::create( "CheckUpdateOpenRows", "更新されたスレをタブで開く(_E)"),
                          sigc::mem_fun( *this, &BBSListViewBase::slot_checkupdate_open_selected_rows ) );
 
-    action_group()->add( Gtk::Action::create( "CopyURL", "URLをコピー"), sigc::mem_fun( *this, &BBSListViewBase::slot_copy_url ) );
-    action_group()->add( Gtk::Action::create( "CopyTitleURL", "タイトルとURLをコピー"), sigc::mem_fun( *this, &BBSListViewBase::slot_copy_title_url ) );
-    action_group()->add( Gtk::Action::create( "SelectDir", "全て選択"), sigc::mem_fun( *this, &BBSListViewBase::slot_select_all_dir ) );
+    action_group()->add( Gtk::Action::create( "CopyURL", "URLをコピー(_U)"), sigc::mem_fun( *this, &BBSListViewBase::slot_copy_url ) );
+    action_group()->add( Gtk::Action::create( "CopyTitleURL", "タイトルとURLをコピー(_L)"), sigc::mem_fun( *this, &BBSListViewBase::slot_copy_title_url ) );
+    action_group()->add( Gtk::Action::create( "SelectDir", "全て選択(_A)"), sigc::mem_fun( *this, &BBSListViewBase::slot_select_all_dir ) );
 
-    action_group()->add( Gtk::Action::create( "CheckUpdate_Menu", "更新チェック" ) );
-    action_group()->add( Gtk::Action::create( "CheckUpdateDir", "更新チェックのみ"), sigc::mem_fun( *this, &BBSListViewBase::slot_check_update_dir ) );
-    action_group()->add( Gtk::Action::create( "CheckUpdateOpenDir", "更新されたスレをタブで開く"),
+    action_group()->add( Gtk::Action::create( "CheckUpdate_Menu", "更新チェック(_M)" ) );
+    action_group()->add( Gtk::Action::create( "CheckUpdateDir", "更新チェックのみ(_R)"), sigc::mem_fun( *this, &BBSListViewBase::slot_check_update_dir ) );
+    action_group()->add( Gtk::Action::create( "CheckUpdateOpenDir", "更新されたスレをタブで開く(_A)"),
                          sigc::mem_fun( *this, &BBSListViewBase::slot_check_update_open_dir ) );
-    action_group()->add( Gtk::Action::create( "CancelCheckUpdate", "キャンセル" ),
+    action_group()->add( Gtk::Action::create( "CancelCheckUpdate", "キャンセル(_C)" ),
                          sigc::mem_fun( *this, &BBSListViewBase::slot_cancel_check_update ) );
 
-    action_group()->add( Gtk::Action::create( "SearchCacheBoard", "キャッシュ内ログ検索"), sigc::mem_fun( *this, &BBSListViewBase::slot_search_cache_board ) );
+    action_group()->add( Gtk::Action::create( "SearchCacheBoard", "キャッシュ内ログ検索(_S)"), sigc::mem_fun( *this, &BBSListViewBase::slot_search_cache_board ) );
 
-    action_group()->add( Gtk::Action::create( "PreferenceArticle", "スレのプロパティ..."), sigc::mem_fun( *this, &BBSListViewBase::slot_preferences_article ) );
-    action_group()->add( Gtk::Action::create( "PreferenceBoard", "板のプロパティ..."), sigc::mem_fun( *this, &BBSListViewBase::slot_preferences_board ) );
-    action_group()->add( Gtk::Action::create( "PreferenceImage", "画像のプロパティ..."), sigc::mem_fun( *this, &BBSListViewBase::slot_preferences_image ) );
+    action_group()->add( Gtk::Action::create( "PreferenceArticle", "スレのプロパティ(_P)..."), sigc::mem_fun( *this, &BBSListViewBase::slot_preferences_article ) );
+    action_group()->add( Gtk::Action::create( "PreferenceBoard", "板のプロパティ(_B)..."), sigc::mem_fun( *this, &BBSListViewBase::slot_preferences_board ) );
+    action_group()->add( Gtk::Action::create( "PreferenceImage", "画像のプロパティ(_M)..."), sigc::mem_fun( *this, &BBSListViewBase::slot_preferences_image ) );
 
 
     ui_manager() = Gtk::UIManager::create();    
@@ -187,36 +199,58 @@ BBSListViewBase::BBSListViewBase( const std::string& url,const std::string& arg1
 
     "<ui>"
 
-    // 通常
+    // 板一覧 + 板
     "<popup name='popup_menu'>"
-    "<menuitem action='OpenTab'/>"
-    "<menuitem action='OpenBrowser'/>"
-    "<separator/>"
-    "<menuitem action='CopyURL'/>"
-    "<menuitem action='CopyTitleURL'/>"
-    "<separator/>"
-    "<menuitem action='AppendFavorite'/>"
-    "<separator/>"
-    "<menuitem action='SearchCacheBoard'/>"
-    "<separator/>"
-    "<menuitem action='PreferenceBoard'/>"
-    "</popup>"
+    POPUPMENU_BOARD1
+    POPUPMENU_BOARD2
 
+    // 板一覧 + 外部板
+    "<popup name='popup_menu_etc'>"
+    POPUPMENU_BOARD1
+    "<menuitem action='MoveEtc'/>"
+    "<separator/>"
+    "<menu action='Delete_Menu'>"
+    "<menuitem action='Delete_etc'/>"
+    "</menu>"
+    "<separator/>"
+    POPUPMENU_BOARD2
 
-    // 通常 + 複数
+    // 板一覧 + 複数選択
     "<popup name='popup_menu_mul'>"
     "<menuitem action='OpenRows'/>"
     "<separator/>"
     "<menuitem action='AppendFavorite'/>"
     "</popup>"
 
+    // 板一覧 + 複数選択 + 外部板含む
+    "<popup name='popup_menu_mul_etc'>"
+    "<menuitem action='OpenRows'/>"
+    "<separator/>"
+    "<menuitem action='AppendFavorite'/>"
 
+    "<separator/>"
+    "<menu action='Delete_Menu'>"
+    "<menuitem action='Delete_etc'/>"
+    "</menu>"
 
-    // 通常ディレクトリメニュー
+    "</popup>"
+
+    // 板一覧 + ディレクトリ
     "<popup name='popup_menu_dir'>"
     "<menuitem action='SelectDir'/>"
     "</popup>"
 
+    // 板一覧 + 外部板ディレクトリ
+    "<popup name='popup_menu_etcdir'>"
+    "<menuitem action='SelectDir'/>"
+    "<separator/>"
+    "<menuitem action='NewEtc'/>"
+    "</popup>"
+
+
+    /////////////////////////////////////////
+
+
     // お気に入り
     "<popup name='popup_menu_favorite'>"
     "<menuitem action='OpenTab'/>"
@@ -240,7 +274,7 @@ BBSListViewBase::BBSListViewBase( const std::string& url,const std::string& arg1
     "<menuitem action='PreferenceImage'/>"
     "</popup>"
 
-    // お気に入り+複数選択
+    // お気に入り + 複数選択
     "<popup name='popup_menu_favorite_mul'>"
     "<menuitem action='OpenRows'/>"
     "<separator/>"
@@ -257,14 +291,12 @@ BBSListViewBase::BBSListViewBase( const std::string& url,const std::string& arg1
     "</menu>"
     "</popup>"
 
-
-    // お気に入り+何もないところをクリック
+    // お気に入り + 何もないところをクリック
     "<popup name='popup_menu_favorite_space'>"
     "<menuitem action='NewDir'/>"
     "</popup>"
 
-
-    // お気に入りディレクトリメニュー
+    // お気に入り + ディレクトリ
     "<popup name='popup_menu_favorite_dir'>"
     "<menu action='CheckUpdate_Menu'>"
     "<menuitem action='CheckUpdateDir'/>"
@@ -285,7 +317,7 @@ BBSListViewBase::BBSListViewBase( const std::string& url,const std::string& arg1
     "</menu>"
     "</popup>"
 
-    // お気に入りコメントメニュー
+    // お気に入り + コメント
     "<popup name='popup_menu_favorite_com'>"
     "<menuitem action='Rename'/>"
     "<menuitem action='NewDir'/>"
@@ -296,7 +328,11 @@ BBSListViewBase::BBSListViewBase( const std::string& url,const std::string& arg1
     "</menu>"
     "</popup>"
 
-    // 選択
+
+    //////////////////////////////////////
+
+
+    // 選択(selectlistview)
     "<popup name='popup_menu_select'>"
     "<menuitem action='CopyURL'/>"
     "<menuitem action='CopyTitleURL'/>"
@@ -321,31 +357,37 @@ BBSListViewBase::BBSListViewBase( const std::string& url,const std::string& arg1
     ui_manager()->add_ui_from_string( str_ui );
 
     // ポップアップメニューにキーアクセレータを表示
-    Gtk::Menu* popupmenu = dynamic_cast< Gtk::Menu* >( ui_manager()->get_widget( "/popup_menu" ) );
+    Gtk::Menu* popupmenu = id2popupmenu(  "/popup_menu" );
     CONTROL::set_menu_motion( popupmenu );
 
-    popupmenu = dynamic_cast< Gtk::Menu* >( ui_manager()->get_widget( "/popup_menu_mul" ) );
+    popupmenu = id2popupmenu(  "/popup_menu_etc" );
     CONTROL::set_menu_motion( popupmenu );
 
-    popupmenu = dynamic_cast< Gtk::Menu* >( ui_manager()->get_widget( "/popup_menu_dir" ) );
+    popupmenu = id2popupmenu(  "/popup_menu_mul" );
     CONTROL::set_menu_motion( popupmenu );
 
-    popupmenu = dynamic_cast< Gtk::Menu* >( ui_manager()->get_widget( "/popup_menu_favorite" ) );
+    popupmenu = id2popupmenu(  "/popup_menu_mul_etc" );
     CONTROL::set_menu_motion( popupmenu );
 
-    popupmenu = dynamic_cast< Gtk::Menu* >( ui_manager()->get_widget( "/popup_menu_favorite_mul" ) );
+    popupmenu = id2popupmenu(  "/popup_menu_dir" );
     CONTROL::set_menu_motion( popupmenu );
 
-    popupmenu = dynamic_cast< Gtk::Menu* >( ui_manager()->get_widget( "/popup_menu_favorite_space" ) );
+    popupmenu = id2popupmenu(  "/popup_menu_favorite" );
     CONTROL::set_menu_motion( popupmenu );
 
-    popupmenu = dynamic_cast< Gtk::Menu* >( ui_manager()->get_widget( "/popup_menu_favorite_dir" ) );
+    popupmenu = id2popupmenu(  "/popup_menu_favorite_mul" );
     CONTROL::set_menu_motion( popupmenu );
 
-    popupmenu = dynamic_cast< Gtk::Menu* >( ui_manager()->get_widget( "/popup_menu_favorite_com" ) );
+    popupmenu = id2popupmenu(  "/popup_menu_favorite_space" );
     CONTROL::set_menu_motion( popupmenu );
 
-    popupmenu = dynamic_cast< Gtk::Menu* >( ui_manager()->get_widget( "/popup_menu_select" ) );
+    popupmenu = id2popupmenu(  "/popup_menu_favorite_dir" );
+    CONTROL::set_menu_motion( popupmenu );
+
+    popupmenu = id2popupmenu(  "/popup_menu_favorite_com" );
+    CONTROL::set_menu_motion( popupmenu );
+
+    popupmenu = id2popupmenu(  "/popup_menu_select" );
     CONTROL::set_menu_motion( popupmenu );
 
     // マウスジェスチャ可
@@ -364,6 +406,12 @@ BBSListViewBase::~BBSListViewBase()
 }
 
 
+SKELETON::Admin* BBSListViewBase::get_admin()
+{
+    return BBSLIST::get_admin();
+}
+
+
 //
 // コマンド
 //
@@ -463,6 +511,21 @@ void BBSListViewBase::clock_in()
 
 
 
+//
+// コメント色変更( 再帰用 )
+//
+void BBSListViewBase::set_fgcolor_of_comment( const Gtk::TreeModel::Children& children )
+{
+    Gtk::TreeModel::iterator it = children.begin();
+    for( ; it != children.end(); ++it ){
+        Gtk::TreeModel::Row row = *it;
+
+        const int type = row2type( row );
+        if( type == TYPE_COMMENT ) row[ m_columns.m_fgcolor ] = Gdk::Color( CONFIG::get_color( COLOR_CHAR_BBS_COMMENT ) );
+        else if( type == TYPE_DIR ) set_fgcolor_of_comment( row.children() );
+    }
+}
+
 
 //
 // 再描画
@@ -471,6 +534,8 @@ void BBSListViewBase::relayout()
 {
     m_treeview.init_color( COLOR_CHAR_BBS, COLOR_BACK_BBS, COLOR_BACK_BBS_EVEN );
     m_treeview.init_font( CONFIG::get_fontname( FONT_BBS ) );
+
+    set_fgcolor_of_comment( m_treestore->children() );
 }
 
 
@@ -479,23 +544,14 @@ void BBSListViewBase::relayout()
 //
 void BBSListViewBase::focus_view()
 {
-    // 一回キャンセル
-    if( m_cancel_focus ){
-        m_cancel_focus = false;
-        return;
-    }
+    // セルの文字を編集中なら何もしない
+    if( m_ren_text->property_editable() ) return;
 
 #ifdef _DEBUG
     std::cout << "BBSListViewBase::focus_view url = " << get_url() << std::endl;
 #endif 
 
     m_treeview.grab_focus();
-
-    if( get_url() == URL_BBSLISTVIEW && get_toolbar().get_combo()  != COMBO_BBSLIST )
-        get_toolbar().set_combo( COMBO_BBSLIST );
-
-    else if( get_url() == URL_FAVORITEVIEW && get_toolbar().get_combo() != COMBO_FAVORITE )
-        get_toolbar().set_combo( COMBO_FAVORITE );
 }
 
 
@@ -516,10 +572,36 @@ void BBSListViewBase::focus_out()
 //
 void BBSListViewBase::close_view()
 {
+#ifdef _DEBUG
+    std::cout << "BBSListViewBase::close_view\n";
+#endif 
+
     CORE::core_set_command( "toggle_sidebar" );
 }
 
 
+
+//
+// 削除
+//
+// BBSListViewBaseの場合は選択行の削除
+//
+void BBSListViewBase::delete_view()
+{
+    SKELETON::MsgDiag mdiag( NULL, "削除しますか？", false, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_YES_NO );
+    if( mdiag.run() != Gtk::RESPONSE_YES ) return;
+
+    delete_view_impl();
+}
+
+// BBSListViewBaseの場合は選択行の削除
+void BBSListViewBase::delete_view_impl()
+{
+    delete_selected_rows();
+}
+
+
+
 //
 // 内容更新
 //
@@ -649,12 +731,8 @@ void  BBSListViewBase::operate_view( const int& control )
             break;
             
         case CONTROL::Delete:
-        {
-            SKELETON::MsgDiag mdiag( NULL, "削除しますか？", false, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_OK_CANCEL );
-            if( mdiag.run() != Gtk::RESPONSE_OK ) return;
             delete_view();
             break;
-        }
 
         // ポップアップメニュー表示
         case CONTROL::ShowPopupMenu:
@@ -669,20 +747,20 @@ void  BBSListViewBase::operate_view( const int& control )
         // 検索
         case CONTROL::Search:
             m_search_invert = false;
-            m_toolbar.m_entry_search.grab_focus();
+            BBSLIST::get_admin()->set_command( "focus_toolbar_search" );
             break;
 
         case CONTROL::SearchInvert:
             m_search_invert = true;
-            m_toolbar.m_entry_search.grab_focus();
+            BBSLIST::get_admin()->set_command( "focus_toolbar_search" );
             break;
 
         case CONTROL::SearchNext:
-            slot_push_down_search();
+            down_search();
             break;
     
         case CONTROL::SearchPrev:
-            slot_push_up_search();
+            up_search();
             break;
 
             // サイドバー表示/非表示
@@ -760,6 +838,13 @@ void BBSListViewBase::activate_act_before_popupmenu( const std::string& url )
 }
 
 
+// idからポップアップメニュー取得
+Gtk::Menu* BBSListViewBase::id2popupmenu( const std::string& id )
+{
+    return dynamic_cast< Gtk::Menu* >( ui_manager()->get_widget( id ) );
+}
+
+
 //
 // 先頭に戻る
 //
@@ -818,16 +903,6 @@ void BBSListViewBase::page_down()
 } 
 
 
-//
-// ツールバー表示切り替え
-//
-void BBSListViewBase::toggle_toolbar()
-{
-    if( SESSION::get_show_bbslist_toolbar() ) m_toolbar.show_toolbar();
-    else m_toolbar.hide_toolbar();
-}
-
-
 //
 // 他のviewのtreestoreをcopyして表示
 //
@@ -951,7 +1026,7 @@ bool BBSListViewBase::slot_motion_notify( GdkEventMotion* event )
 
             m_treeview.hide_tooltip();
 
-            if( DBIMG::is_loadable( url ) && DBIMG::get_code( url ) != HTTP_INIT ){
+            if( DBIMG::get_type_ext( url ) != DBIMG::T_UNKNOWN && DBIMG::get_code( url ) != HTTP_INIT ){
 
                 if( m_treeview.pre_popup_url() != url ){
 
@@ -989,6 +1064,9 @@ bool BBSListViewBase::slot_motion_notify( GdkEventMotion* event )
 //
 bool BBSListViewBase::slot_key_press( GdkEventKey* event )
 {
+    // セルの文字を編集中なら何もしない
+    if( m_ren_text->property_editable() ) return true;
+
     int key = get_control().key_press( event );
 
     // キー入力でboardを開くとkey_pressイベントがboadviewに送られて
@@ -1012,7 +1090,10 @@ bool BBSListViewBase::slot_key_release( GdkEventKey* event )
 
     std::cout << "BBSListViewBase::slot_key_release key = " << event->keyval << " ctrl = " << ctrl << " shift = " << shift << std::endl;
 #endif
-    
+
+    // セルの文字を編集中なら何もしない
+    if( m_ren_text->property_editable() ) return true;
+
     // キー入力でboardを開くとkey_pressイベントがboadviewに送られて
     // 一番上のスレが開くので、open_row() は slot_key_release() で処理する
     int key = get_control().key_press( event );
@@ -1127,7 +1208,7 @@ void BBSListViewBase::slot_newdir()
 {
     // これは m_path_selected が空でも実行する
 
-    Gtk::TreeModel::Path path = append_row( std::string(), "New Directory", TYPE_DIR, m_path_selected, true );
+    Gtk::TreeModel::Path path = append_row( std::string(), "新規ディレクトリ", TYPE_DIR, m_path_selected, true );
     m_treeview.set_cursor( path );
     show_status();
     m_path_selected = path;
@@ -1143,7 +1224,7 @@ void BBSListViewBase::slot_newcomment()
 {
     if( m_path_selected.empty() ) return;
 
-    Gtk::TreeModel::Path path = append_row( std::string(), "Comment", TYPE_COMMENT, m_path_selected, true );
+    Gtk::TreeModel::Path path = append_row( std::string(), "コメント", TYPE_COMMENT, m_path_selected, true );
     m_treeview.set_cursor( path );
     m_path_selected = path;
     slot_rename();
@@ -1151,6 +1232,180 @@ void BBSListViewBase::slot_newcomment()
 
 
 
+//
+// メニューで外部板追加を選択
+//
+void BBSListViewBase::slot_newetcboard()
+{
+    add_newetcboard( false, "", "", "", "" );
+}
+
+
+//
+// メニューで外部板編集を選択
+//
+void BBSListViewBase::slot_moveetcboard()
+{
+    add_newetcboard( true, "", "", "", "" );
+}
+
+
+// 外部板追加
+void BBSListViewBase::add_newetcboard( const bool move, // true なら編集モード
+                                       const std::string& _url, const std::string& _name, const std::string& _id, const std::string& _passwd )
+{
+    if( m_path_selected.empty() ) return;
+
+    std::string url_old;
+    std::string name_old;
+
+    std::string url = _url;
+    std::string name = _name;
+    std::string id = _id;
+    std::string passwd = _passwd;
+    std::string basicauth;
+
+#ifdef _DEBUG
+        std::cout << "BBSListViewBase::add_newetcboard\n"
+                  << "move = " << move << std::endl;
+#endif
+
+    if( move ){
+        url_old = path2url( m_path_selected );
+        name_old = path2name( m_path_selected );
+
+#ifdef _DEBUG
+        std::cout << "url_old = " << url_old << std::endl
+                  << "name_old = " << name_old << std::endl
+                  << "board_name = " << DBTREE::board_name( url_old ) << std::endl;
+#endif
+
+        if( DBTREE::board_name( url_old ) != name_old ) return;
+
+        if( url.empty() ) url = url_old;
+        if( name.empty() ) name = name_old;
+
+        basicauth = DBTREE::board_basicauth( url_old );
+        size_t i = basicauth.find( ":" );
+
+        if( id.empty() && i != std::string::npos ){
+
+            id = basicauth.substr( 0, i );
+            passwd = basicauth.substr( i+1 );
+        }
+
+#ifdef _DEBUG
+        std::cout << "basicauth = " << basicauth << " i = " << i << " id = " << id
+                  << "passwd = " << passwd << std::endl;
+#endif
+    }
+
+    BBSLIST::AddEtcDialog diag( move, url, name, id, passwd );
+    if( diag.run() == Gtk::RESPONSE_OK ){
+
+        diag.hide();
+
+        std::string url_org = MISC::remove_space( diag.get_url() );
+        name = MISC::remove_space( diag.get_name() );
+        url = url_org;
+        id = MISC::remove_space( diag.get_id() );
+        passwd = MISC::remove_space( diag.get_passwd() );
+        if( ! id.empty() && ! passwd.empty() ) basicauth = id + ":" + passwd; 
+
+        if( name.empty() || url.empty() ){
+            SKELETON::MsgDiag mdiag( NULL, "板名またはアドレスが空白です", false, Gtk::MESSAGE_ERROR );
+            mdiag.run();
+            mdiag.hide();
+            add_newetcboard( move, url_org, name, id, passwd );
+            return;
+        }
+
+        // http が無ければ付ける
+        if( url.find( "http://" ) != 0 ) url = "http://" + url;
+
+        // .htmlを取り除く
+        JDLIB::Regex regex;
+        if( regex.exec( "(.*)/[^/]+\\.html?$" , url ) ) url = regex.str( 1 );
+
+        // 末尾の / を取り除く
+        while( url.rfind( "/" ) == url.length() -1 ) url = url.substr( 0, url.length() -1 );
+
+        // url の最後に/を付ける
+        url += "/";
+
+        // boardid 取得
+        if( ! regex.exec( "(http://.*)/([^/]*)/$" , url ) ){
+            SKELETON::MsgDiag mdiag( NULL, "アドレスが不正な形式になっています", false, Gtk::MESSAGE_ERROR );
+            mdiag.run();
+            mdiag.hide();
+            add_newetcboard( move, url_org, name, id, passwd );
+            return;
+        }
+
+#ifdef _DEBUG
+        std::cout << "url_old = " << url_old << std::endl
+                  << "name_old = " << name_old << std::endl
+                  << "url = " << url << std::endl
+                  << "name = " << name << std::endl
+                  << "basicauth = " << basicauth << std::endl;
+#endif
+
+        std::string boardid = regex.str( 2 );
+
+        if( boardid.empty() ){
+            SKELETON::MsgDiag mdiag( NULL, "板IDを取得出来ません", false, Gtk::MESSAGE_ERROR );
+            mdiag.run();
+            mdiag.hide();
+            add_newetcboard( move, url_org, name, id, passwd );
+            return;
+        }
+
+#ifdef _DEBUG
+        std::cout << "boardid = " << boardid << std::endl;
+#endif
+
+        // 既に登録されているか確認
+        if( ! move && ! DBTREE::board_name( url ).empty() ){
+            SKELETON::MsgDiag mdiag( NULL, name + "\n" + url + "\n\nは既に登録されています", false, Gtk::MESSAGE_ERROR );
+            mdiag.run();
+            mdiag.hide();
+            add_newetcboard( move, url_org, name,  id, passwd );
+            return;
+        }
+
+        // データベースに登録してツリーに表示
+        if( ! move && DBTREE::add_etc( url, name, basicauth, boardid ) ){
+
+            Gtk::TreeModel::Path path = append_row( url, name, TYPE_BOARD, m_path_selected, true );
+            m_path_selected = path;
+
+            // etc.txt保存
+            DBTREE::save_etc();
+        }
+
+        // 編集
+        else if( move && DBTREE::move_etc( url_old, url, name_old, name, basicauth, boardid ) ){
+
+            Gtk::TreeModel::Row row = m_treeview.get_row( m_path_selected );
+            if( row ){
+                row[ m_columns.m_col_url ] = url;
+                row[ m_columns.m_col_name ] = name;
+            }
+        }
+
+        else{
+
+            SKELETON::MsgDiag mdiag( NULL, "外部板の登録に失敗しました。アドレスを確認してください", false, Gtk::MESSAGE_ERROR );
+            mdiag.run();
+            mdiag.hide();
+            add_newetcboard( move, url_org, name, id, passwd );
+            return;
+        }
+    }
+}
+
+
+
 //
 // 名前変更
 //
@@ -1162,12 +1417,9 @@ void BBSListViewBase::slot_rename()
     std::cout << "BBSListViewBase::slot_rename\n";
 #endif
 
-    m_ren_text->property_editable() = true;     // edit可
-    m_treeview.set_cursor( m_path_selected, *m_treeview.get_column( COL_NAME ), true );
-
-    // メニューが消えるとfocus_viewが呼ばれて名前変更モードが終了するのでfocus_viewをキャンセルする
-    m_cancel_focus = true;
-    m_ren_text->property_editable() = false;
+    // edit可 slot_ren_text_on_edited() と slot_ren_text_on_canceled で false にする
+    m_ren_text->property_editable() = true;
+    m_treeview.set_cursor( m_path_selected, *m_treeview.get_column( 0 ), true );
 }
 
 
@@ -1179,7 +1431,7 @@ void BBSListViewBase::slot_copy_url()
     if( m_path_selected.empty() ) return;
 
     std::string url = path2url( m_path_selected );
-    COPYCLIP( url );
+    MISC::CopyClipboard( url );
 }
 
 
@@ -1195,7 +1447,7 @@ void BBSListViewBase::slot_copy_title_url()
     ss << name << std::endl
        << url << std::endl;
 
-    COPYCLIP( ss.str() );
+    MISC::CopyClipboard( ss.str() );
 }
 
 
@@ -1318,6 +1570,12 @@ void BBSListViewBase::slot_check_update_dir()
 {
     if( m_path_selected.empty() ) return;
 
+    if( ! SESSION::is_online() ){
+        SKELETON::MsgDiag mdiag( NULL, "オフラインです" );
+        mdiag.run();
+        return;
+    }
+
 #ifdef _DEBUG
     std::cout << "BBSListViewBase::slot_check_check_update_dir path = " << m_path_selected.to_string() << std::endl;
 #endif
@@ -1329,6 +1587,12 @@ void BBSListViewBase::slot_check_update_dir()
 // 全更新チェックして開く
 void BBSListViewBase::slot_check_update_open_dir()
 {
+    if( ! SESSION::is_online() ){
+        SKELETON::MsgDiag mdiag( NULL, "オフラインです" );
+        mdiag.run();
+        return;
+    }
+
     if( m_path_selected.empty() ) return;
 
 #ifdef _DEBUG
@@ -1393,7 +1657,7 @@ void BBSListViewBase::slot_search_cache_board()
     if( m_path_selected.empty() ) return;
     std::string url = path2url( m_path_selected );
 
-    CORE::core_set_command( "open_article_searchcache", url , "", "false" );
+    CORE::core_set_command( "open_article_searchlog", url );
 }
 
 
@@ -1481,13 +1745,30 @@ void BBSListViewBase::slot_row_col( const Gtk::TreeModel::iterator&, const Gtk::
 //
 void BBSListViewBase::slot_ren_text_on_edited( const Glib::ustring& path, const Glib::ustring& text )
 {
+#ifdef _DEBUG    
+    std::cout << "BBSListViewBase::slot_ren_text_on_edited\n"
+              << "path = " << path << std::endl
+              << "text = " << text << std::endl;
+#endif
+
     Gtk::TreeModel::Row row = m_treeview.get_row( Gtk::TreePath( path ) );
     if( row ) row[ m_columns.m_col_name ] = text;
+
+    m_ren_text->property_editable() = false;
 }
 
 
+//
+// 名前をキャンセルしたときにCellRendererTextから呼ばれるslot
+//
+void BBSListViewBase::slot_ren_text_on_canceled()
+{
+#ifdef _DEBUG    
+    std::cout << "BBSListViewBase::slot_ren_text_on_canceld\n";
+#endif
 
-
+    m_ren_text->property_editable() = false;
+}
 
 
 //
@@ -1623,6 +1904,7 @@ Gtk::TreeViewColumn* BBSListViewBase::create_column()
 
     m_ren_text = Gtk::manage( new Gtk::CellRendererText() );
     m_ren_text->signal_edited().connect( sigc::mem_fun( *this, &BBSListViewBase::slot_ren_text_on_edited ) );
+    m_ren_text->signal_editing_canceled().connect( sigc::mem_fun( *this, &BBSListViewBase::slot_ren_text_on_canceled ) );
     m_ren_text->property_underline() = Pango::UNDERLINE_SINGLE;
 
     // 行間スペース
@@ -1631,6 +1913,7 @@ Gtk::TreeViewColumn* BBSListViewBase::create_column()
     col->pack_start( *m_ren_text, true );
     col->add_attribute( *m_ren_text, "text", COL_NAME );
     col->add_attribute( *m_ren_text, "underline", COL_UNDERLINE );
+    col->add_attribute( *m_ren_text, "foreground_gdk", COL_FGCOLOR );
     col->set_sizing( Gtk::TREE_VIEW_COLUMN_FIXED );
 
     col->set_cell_data_func( *col->get_first_cell_renderer(), sigc::mem_fun( m_treeview, &SKELETON::JDTreeView::slot_cell_data ) );    
@@ -1663,9 +1946,10 @@ const bool BBSListViewBase::open_row( Gtk::TreePath& path, const bool tab )
             CORE::core_set_command( "open_board", DBTREE::url_subject( url ), str_tab, "" );
             break;
 
+        case TYPE_THREAD_OLD:
+            toggle_icon( url ); // break;しない
         case TYPE_THREAD:
         case TYPE_THREAD_UPDATE:
-        case TYPE_THREAD_OLD:
             CORE::core_set_command( "open_article", DBTREE::url_dat( url ), str_tab, "" );
             break;
 
@@ -1791,6 +2075,16 @@ void BBSListViewBase::slot_checkupdate_open_selected_rows()
 //
 // path -> url 変換
 //
+
+Glib::ustring BBSListViewBase::path2rawurl( const Gtk::TreePath& path )
+{
+    Gtk::TreeModel::Row row = m_treeview.get_row( path );
+    if( !row ) return Glib::ustring();
+    Glib::ustring url =  row[ m_columns.m_col_url ];
+    return url;
+}
+
+// 移転をチェックするバージョン
 Glib::ustring BBSListViewBase::path2url( const Gtk::TreePath& path )
 {
     Gtk::TreeModel::Row row = m_treeview.get_row( path );
@@ -1900,6 +2194,40 @@ bool BBSListViewBase::is_dir( const Gtk::TreePath& path )
 
 
 
+//
+// 外部板のディレクトリか
+//
+bool BBSListViewBase::is_etcdir( Gtk::TreePath path )
+{
+    std::string name = path2name( path );
+
+#ifdef _DEBUG
+    std::cout << "BBSListViewBase:is_etcdir path = " << path.to_string() << " name = " << name << std::endl;
+#endif
+
+    if( name == SUBDIR_ETCLIST ) return true;
+
+    return false;
+}
+
+
+//
+// 外部板か
+//
+bool BBSListViewBase::is_etcboard( Gtk::TreeModel::iterator& it )
+{
+    Gtk::TreePath path = get_treestore()->get_path( *it );
+    return is_etcboard( path );
+}
+
+
+bool BBSListViewBase::is_etcboard( Gtk::TreePath path )
+{
+    path.up();
+    return is_etcdir( path );
+}
+
+
 
 //
 // 行追加
@@ -2207,22 +2535,36 @@ void BBSListViewBase::delete_selected_rows()
 
         if( is_dir( (*it ) ) ){
             SKELETON::MsgDiag mdiag( NULL, "ディレクトリを削除するとディレクトリ内の行も全て削除されます。削除しますか？",
-                                      false, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_OK_CANCEL );
-            if( mdiag.run() != Gtk::RESPONSE_OK ) return;
-
+                                      false, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_YES_NO );
+            if( mdiag.run() != Gtk::RESPONSE_YES ) return;
             break;
         }
     }
 
-    // カーソルを一番最後の列の次に移動する
+    // カーソルを一番最後の行の次の行に移動する
     it = list_it.end();
-    Gtk::TreePath next = m_treeview.next_path( GET_PATH( *(--it) ), true );
-    m_treeview.set_cursor( next );
+    --it;
+
+    // ディレクトリを閉じないとそのディレクトリの先頭の列が next になり、ディレクトリが削除されるため
+    // キーボードフォーカスが外れる
+    if( is_dir( *it ) ) m_treeview.collapse_row( GET_PATH( *it ) ); 
+    Gtk::TreePath next = m_treeview.next_path( GET_PATH( *it ), true );
+
+    // もしnextが存在しなかったら全ての行を削除してから一番下に移動
+    bool gotobottom = ( ! m_treeview.get_row( next ) );
+    if( ! gotobottom ) m_treeview.set_cursor( next );
+
+#ifdef _DEBUG
+    std::cout << " BBSListViewBase::delete_selected_rows : ";
+    std::cout << GET_PATH( *it ).to_string() << " -> " << next.to_string() << std::endl;
+#endif
 
     // まとめて削除
-    // ディレクトリ内の列を同時に選択している場合があるので後から消す
+    // ディレクトリ内の行を同時に選択している場合があるので後から消す
     it = list_it.end();
     while( it != list_it.begin() ) m_treestore->erase( ( *(--it) ) );
+
+    if( gotobottom ) m_treeview.goto_bottom();
 }
 
 
@@ -2255,7 +2597,13 @@ void BBSListViewBase::set_expanded_row( const Gtk::TreeModel::Children& children
 //
 void BBSListViewBase::tree2xml( const std::string& root_name )
 {
-    if( ! m_ready_tree || m_treestore->children().empty() ) return;
+    if( ! m_ready_tree ) return;
+
+    if( m_treestore->children().empty() )
+    {
+        m_document.clear();
+        return;
+    }
 
 #ifdef _DEBUG
     std::cout << "BBSListViewBase::tree2xml\n";
@@ -2512,16 +2860,14 @@ void BBSListViewBase::toggle_icon( const std::string& url )
 //
 // m_search_invert = true なら前方検索
 //
-void BBSListViewBase::slot_active_search()
+void BBSListViewBase::exec_search()
 {
-    if( m_toolbar.m_entry_search.completion() ) return;
-
     JDLIB::Regex regex_name;
     JDLIB::Regex regex_url;
 
     CORE::core_set_command( "set_info", "", "" );
 
-    std::string query = m_toolbar.m_entry_search.get_text();
+    std::string query = get_search_query();
     if( query.empty() ){
         focus_view();
         return;
@@ -2538,12 +2884,13 @@ void BBSListViewBase::slot_active_search()
         if( !m_search_invert ) path = m_treeview.prev_path( path, false );
         else path = m_treeview.next_path( path, false );
         m_pre_query = query;
+        CORE::get_completion_manager()->set_query( CORE::COMP_SEARCH, query );
     } 
 
     Gtk::TreePath path_start = path;
 
 #ifdef _DEBUG
-    std::cout << "BBSListViewBase::slot_active_search() path = " << path.to_string() << " query = " << query << std::endl;
+    std::cout << "BBSListViewBase::exec_search() path = " << path.to_string() << " query = " << query << std::endl;
 #endif
 	
     regex_name.compile( query, true, true, true );
@@ -2602,54 +2949,33 @@ void BBSListViewBase::slot_active_search()
 
 
 // 前検索
-void BBSListViewBase::slot_push_up_search()
+void BBSListViewBase::up_search()
 {
     m_search_invert = true;
-    slot_active_search();
+    exec_search();
 }
 
 
 
 // 後検索
-void BBSListViewBase::slot_push_down_search()
+void BBSListViewBase::down_search()
 {
     m_search_invert = false;
-    slot_active_search();
+    exec_search();
 }
 
 
 //
 // 検索entryの操作
 //
-void BBSListViewBase::slot_entry_operate( int controlid )
+void BBSListViewBase::operate_search( const std::string& controlid )
 {
-    if( controlid == CONTROL::Cancel ) focus_view();
+    int id = atoi( controlid.c_str() );
+
+    if( id == CONTROL::Cancel ) focus_view();
 }
 
 
-
-// ラベルのコンボボックスの表示が変わった
-void BBSListViewBase::slot_combo_changed()
-{
-#ifdef _DEBUG
-    std::cout << "BBSListViewBase::slot_combo_changed url = " << get_url()
-              << " combo = " << get_toolbar().get_combo() << std::endl;
-#endif
-
-    switch( get_toolbar().get_combo() ){
-
-        case COMBO_BBSLIST:
-            if( get_url() != URL_BBSLISTVIEW ) CORE::core_set_command( "switch_sidebar", URL_BBSLISTVIEW );
-            break;
-
-        case COMBO_FAVORITE:
-            if( get_url() != URL_FAVORITEVIEW ) CORE::core_set_command( "switch_sidebar", URL_FAVORITEVIEW );
-            break;
-    }
-}
-
-
-
 //
 // お気に入りにアイテム追加
 //
