@@ -15,6 +15,7 @@ namespace BBSLIST
     enum
     {
         COL_NAME = 0,
+        COL_IMAGE,
 
         COL_VISIBLE_END,
 
@@ -22,9 +23,10 @@ namespace BBSLIST
 
         COL_UNDERLINE = COL_VISIBLE_END,
         COL_URL,
-        COL_IMAGE,
         COL_TYPE,
-            
+        COL_EXPAND,
+        COL_FGCOLOR,
+
         COL_NUM_COL
     };
 
@@ -39,16 +41,13 @@ namespace BBSLIST
         Gtk::TreeModelColumn< Glib::ustring > m_col_url;
         Gtk::TreeModelColumn< Glib::RefPtr< Gdk::Pixbuf > >  m_col_image;
         Gtk::TreeModelColumn< int > m_type;
-        
-        TreeColumns(){
-            add( m_col_name );
-            add( m_underline );
-            add( m_col_url );
-            add( m_col_image );
-            add( m_type );
-        }
+        Gtk::TreeModelColumn< bool > m_expand; // Dom::parse() で使用
+        Gtk::TreeModelColumn< Gdk::Color > m_fgcolor;
 
-        ~TreeColumns(){}
+        TreeColumns();
+        ~TreeColumns();
+
+        void setup_row( Gtk::TreeModel::Row& row, const Glib::ustring url, const Glib::ustring name, const int type );
     };
 }
 
