@@ -19,10 +19,10 @@ FavoriteListView::FavoriteListView( const std::string& url,
                                     const std::string& arg1, const std::string& arg2 )
     : BBSListViewBase( url, arg1, arg2 )
 {
+    set_label( "お気に入り" );
+
     // D&D可
     get_treeview().set_reorderable_view( true );
-
-    if( get_bbslisttoolbar() ) get_bbslisttoolbar()->set_combo( COMBO_FAVORITE );
 }
  
 
@@ -76,18 +76,18 @@ void FavoriteListView::show_view()
 Gtk::Menu* FavoriteListView::get_popupmenu( const std::string& url )
 {
     Gtk::Menu* popupmenu;
-    if( url.empty() ) popupmenu = dynamic_cast< Gtk::Menu* >( ui_manager()->get_widget( "/popup_menu_favorite_space" ) );
+    if( url.empty() ) popupmenu = id2popupmenu(  "/popup_menu_favorite_space" );
     else{
         std::list< Gtk::TreeModel::iterator > list_it = get_treeview().get_selected_iterators();
         if( list_it.size() == 1 ){
 
             int type = path2type( *( get_treeview().get_selection()->get_selected_rows().begin() ) );
 
-            if( type == TYPE_DIR ) popupmenu = dynamic_cast< Gtk::Menu* >( ui_manager()->get_widget( "/popup_menu_favorite_dir" ) );
-            else if( type == TYPE_COMMENT ) popupmenu = dynamic_cast< Gtk::Menu* >( ui_manager()->get_widget( "/popup_menu_favorite_com" ) );
-            else popupmenu = dynamic_cast< Gtk::Menu* >( ui_manager()->get_widget( "/popup_menu_favorite" ) );
+            if( type == TYPE_DIR ) popupmenu = id2popupmenu(  "/popup_menu_favorite_dir" );
+            else if( type == TYPE_COMMENT ) popupmenu = id2popupmenu(  "/popup_menu_favorite_com" );
+            else popupmenu = id2popupmenu(  "/popup_menu_favorite" );
         }
-        else popupmenu = dynamic_cast< Gtk::Menu* >( ui_manager()->get_widget( "/popup_menu_favorite_mul" ) );
+        else popupmenu = id2popupmenu(  "/popup_menu_favorite_mul" );
     }
 
     return popupmenu;
