@@ -4,6 +4,7 @@
 #include "jddebug.h"
 
 #include "boardadmin.h"
+#include "toolbar.h"
 
 #include "dbtree/interface.h"
 
@@ -42,8 +43,9 @@ void BOARD::delete_admin()
 using namespace BOARD;
 
 BoardAdmin::BoardAdmin( const std::string& url )
-    : SKELETON::Admin( url )
+    : SKELETON::Admin( url ) , m_toolbar( NULL )
 {
+    set_use_viewhistory( true );
     get_notebook()->set_dragable( true );
     get_notebook()->set_fixtab( false );
     if( ! SESSION::get_show_board_tab() ) get_notebook()->set_show_tabs( false );
@@ -58,6 +60,8 @@ BoardAdmin::~BoardAdmin()
     std::cout << "BoardAdmin::~BoardAdmin\n";
 #endif
 
+    if( m_toolbar ) delete m_toolbar;
+
     // 開いているURLを保存
     SESSION::set_board_URLs( get_URLs() );
     SESSION::set_board_locked( get_locked() );
@@ -67,42 +71,52 @@ BoardAdmin::~BoardAdmin()
 
 
 // 前回開いていたURLを復元
-void BoardAdmin::restore()
+void BoardAdmin::restore( const bool only_locked )
 {
-    bool online = SESSION::is_online();
+    int set_page_num = 0;
+    const bool online = SESSION::is_online();
     SESSION::set_online( false );
 
-    std::list< std::string > list_url = SESSION::board_URLs();
+    std::list< std::string >& list_url = SESSION::get_board_URLs();
     std::list< std::string >::iterator it_url = list_url.begin();
 
     std::list< bool > list_locked = SESSION::get_board_locked();
     std::list< bool >::iterator it_locked = list_locked.begin();
 
-    for( ; it_url != list_url.end(); ++it_url ){
-
-        COMMAND_ARGS command_arg;
-        command_arg.command = "open_view";
+    for( int page = 0; it_url != list_url.end(); ++it_url, ++page ){
 
         // タブのロック状態
-        std::string lock;
+        bool lock = false;
         if( it_locked != list_locked.end() ){
-            if( (*it_locked ) ) lock = "lock";
+            if( (*it_locked ) ) lock = true;
             ++it_locked;
         }
 
-        if( !( *it_url ).empty() ){
+        // ロックされているものだけ表示
+        if( only_locked && ! lock ) continue;
 
-            command_arg.url = ( *it_url );
-            command_arg.arg1 = "true";
-            command_arg.arg2 = "false";
-            command_arg.arg3 = lock;
+        if( page == SESSION::board_page() ) set_page_num = get_tab_nums();
 
-            open_view( command_arg );
-        }
+        COMMAND_ARGS command_arg = url_to_openarg( *it_url, true, lock );
+        if( ! command_arg.url.empty() ) open_view( command_arg );
     }
 
     SESSION::set_online( online );
-    set_command( "set_page", std::string(), MISC::itostr( SESSION::board_page() ) );
+    if( get_tab_nums() ) set_command( "set_page", std::string(), MISC::itostr( set_page_num ) );
+}
+
+
+COMMAND_ARGS BoardAdmin::url_to_openarg( const std::string& url, const bool tab, const bool lock )
+{
+    COMMAND_ARGS command_arg;
+
+    command_arg.command = "open_view";
+    command_arg.url = url;
+    if( tab ) command_arg.arg1 = "true";  // タブで開く
+    command_arg.arg2 = "false";           // 既に開いているかチェック
+    if( lock ) command_arg.arg3 = "lock";
+
+    return command_arg;
 }
 
 
@@ -125,6 +139,34 @@ COMMAND_ARGS BoardAdmin::get_open_list_args( const std::string& url )
 }
 
 
+//
+// ツールバー表示
+//
+void BoardAdmin::show_toolbar()
+{
+    // まだ作成されていない場合は作成する
+    if( ! m_toolbar ){
+        m_toolbar = new BoardToolBar();
+        get_notebook()->append_toolbar( *m_toolbar );
+
+        if( SESSION::get_show_board_toolbar() ) m_toolbar->show_toolbar();
+    }
+
+    get_notebook()->show_toolbar();
+}
+
+
+//
+// ツールバー表示切り替え
+//
+void BoardAdmin::toggle_toolbar()
+{
+    if( ! m_toolbar ) return;
+
+    if( SESSION::get_show_board_toolbar() ) m_toolbar->show_toolbar();
+    else m_toolbar->hide_toolbar();
+}
+
 
 SKELETON::View* BoardAdmin::create_view( const COMMAND_ARGS& command )
 {
