@@ -5,7 +5,6 @@
 
 #include "boardadmin.h"
 #include "boardview.h"
-#include "toolbar.h"
 
 #include "skeleton/msgdiag.h"
 
@@ -18,6 +17,8 @@
 
 #include "config/globalconf.h"
 
+#include "sound/soundmanager.h"
+
 #include "command.h"
 #include "session.h"
 #include "dndmanager.h"
@@ -29,6 +30,7 @@
 #include "controlutil.h"
 #include "colorid.h"
 #include "fontid.h"
+#include "compmanager.h"
 
 #include "icons/iconmanager.h"
 
@@ -125,23 +127,6 @@ BoardView::BoardView( const std::string& url,const std::string& arg1, const std:
     m_scrwin.add( m_treeview );
     m_scrwin.set_policy( Gtk::POLICY_AUTOMATIC, Gtk::POLICY_ALWAYS );
 
-    set_toolbar( Gtk::manage( new BoardToolBar() ) );
-
-    get_boardtoolbar()->get_close_button().signal_clicked().connect( sigc::mem_fun( *this, &BoardView::close_view ) );
-    get_boardtoolbar()->m_entry_search.signal_changed().connect( sigc::mem_fun( *this, &BoardView::slot_changed_search ) );
-    get_boardtoolbar()->m_entry_search.signal_activate().connect( sigc::mem_fun( *this, &BoardView::slot_active_search ) );
-    get_boardtoolbar()->m_button_reload.signal_clicked().connect( sigc::mem_fun( *this, &BoardView::reload ) );
-    get_boardtoolbar()->m_button_stop.signal_clicked().connect( sigc::mem_fun( *this, &BoardView::stop ) );
-    get_boardtoolbar()->m_button_new_article.signal_clicked().connect( sigc::mem_fun( *this, &BoardView::slot_new_article ) );
-    get_boardtoolbar()->m_button_delete.signal_clicked().connect( sigc::mem_fun( *this, &BoardView::slot_push_delete ) );
-    get_boardtoolbar()->m_button_favorite.signal_clicked().connect( sigc::mem_fun( *this, &BoardView::slot_push_favorite ) );
-    get_boardtoolbar()->m_button_up_search.signal_clicked().connect( sigc::mem_fun( *this, &BoardView::slot_push_up_search ) );
-    get_boardtoolbar()->m_button_down_search.signal_clicked().connect( sigc::mem_fun( *this, &BoardView::slot_push_down_search ) );
-    get_boardtoolbar()->m_entry_search.signal_operate().connect( sigc::mem_fun( *this, &BoardView::slot_entry_operate ) );
-
-    if( SESSION::get_show_board_toolbar() ) get_boardtoolbar()->show_toolbar();
-
-    pack_start( *get_boardtoolbar(), Gtk::PACK_SHRINK );    
     pack_start( m_scrwin );
     show_all_children();    
 
@@ -207,7 +192,7 @@ BoardView::BoardView( const std::string& url,const std::string& arg1, const std:
     action_group()->add( Gtk::Action::create( "GotoTop", "一番上に移動(_T)" ), sigc::mem_fun( *this, &BoardView::goto_top ) );
     action_group()->add( Gtk::Action::create( "GotoBottom", "一番下に移動(_M)" ), sigc::mem_fun( *this, &BoardView::goto_bottom ) );
     action_group()->add( Gtk::Action::create( "Delete_Menu", "Delete" ) );
-    action_group()->add( Gtk::Action::create( "Delete", "選択した行のログを削除する(_D)" ), sigc::mem_fun( *this, &BoardView::delete_view ) );
+    action_group()->add( Gtk::Action::create( "Delete", "選択した行のログを削除する(_D)" ), sigc::mem_fun( *this, &BoardView::slot_delete_logs ) );
     action_group()->add( Gtk::Action::create( "OpenRows", "選択した行を開く(_O)" ), sigc::mem_fun( *this, &BoardView::open_selected_rows ) );
     action_group()->add( Gtk::Action::create( "CopyURL", "URLをコピー(_C)" ), sigc::mem_fun( *this, &BoardView::slot_copy_url ) );
     action_group()->add( Gtk::Action::create( "CopyTitleURL", "タイトルとURLをコピー(_U)" ), sigc::mem_fun( *this, &BoardView::slot_copy_title_url ) );
@@ -310,6 +295,12 @@ BoardView::~BoardView()
 }
 
 
+SKELETON::Admin* BoardView::get_admin()
+{
+    return BOARD::get_admin();
+}
+
+
 // アイコンのID取得
 const int BoardView::get_icon( const std::string& iconname )
 {
@@ -578,10 +569,10 @@ void BoardView::slot_cell_data( Gtk::CellRenderer* cell, const Gtk::TreeModel::i
     Gtk::TreePath path = m_liststore->get_path( row );
 
 #ifdef _DEBUG
-    std::cout << "BoardView::slot_cell_data path = " << path.to_string() << std::endl;
+//    std::cout << "BoardView::slot_cell_data path = " << path.to_string() << std::endl;
 #endif
 
-    // ハイライト色
+    // ハイライト色 ( 抽出状態 )
     if( row[ m_columns.m_col_drawbg ] ){
         cell->property_cell_background() = CONFIG::get_color( COLOR_BACK_HIGHLIGHT_TREE );
         cell->property_cell_background_set() = true;
@@ -869,12 +860,7 @@ void BoardView::show_view()
         return;
     }
 
-    // タイトル表示
-    set_title( DBTREE::board_name( get_url() ) );
-    BOARD::get_admin()->set_command( "set_title", get_url(), get_title() );
-
-    // タブに名前をセット
-    BOARD::get_admin()->set_command( "set_tablabel", get_url(), DBTREE::board_name( get_url() ) );
+    update_boardname();
 
 #if GTKMMVER >= 280
     m_treeview.unset_model();
@@ -937,13 +923,22 @@ void BoardView::relayout()
 //
 void BoardView::update_view()
 {
-#ifdef _DEBUG
-    std::cout << "BoardView::update_view " << get_url() << std::endl;
-#endif    
-
+    const int code = DBTREE::board_code( get_url() );
     m_updated = false;
     m_loading = false;
 
+#ifdef _DEBUG
+    std::cout << "BoardView::update_view " << get_url()
+              << " code = " << code << std::endl;
+#endif    
+
+    // 音を鳴らす
+    if( SESSION::is_online() && code != HTTP_INIT ){
+        if( code == HTTP_OK ) SOUND::play( SOUND::SOUND_RES );
+        else if( code == HTTP_NOT_MODIFIED ) SOUND::play( SOUND::SOUND_NO );
+        else SOUND::play( SOUND::SOUND_ERR );
+    }
+
     // 画面消去
 #if GTKMMVER >= 280
     m_treeview.unset_model();
@@ -1033,7 +1028,7 @@ void BoardView::close_view()
 //
 // 選択した行のログをまとめて削除
 //
-void BoardView::delete_view()
+void BoardView::slot_delete_logs()
 {
     std::list< Gtk::TreeModel::iterator > list_it = m_treeview.get_selected_iterators();
     std::list< Gtk::TreeModel::iterator >::iterator it = list_it.begin();
@@ -1128,6 +1123,15 @@ void BoardView::operate_view( const int& control )
             BOARD::get_admin()->set_command( "tab_right" );
             break;
 
+            // 戻る、進む
+        case CONTROL::PrevView:
+            back_viewhistory( 1 );
+            break;
+
+        case CONTROL::NextView:
+            forward_viewhistory( 1 );
+            break;
+
         case CONTROL::Quit:
             close_view();
             break;
@@ -1141,7 +1145,7 @@ void BoardView::operate_view( const int& control )
             break;
 
         case CONTROL::NewArticle:
-            slot_new_article();
+            write();
             break;
 
         case CONTROL::Delete:
@@ -1149,7 +1153,7 @@ void BoardView::operate_view( const int& control )
             SKELETON::MsgDiag mdiag( NULL, "選択した行のログを削除しますか？", false, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_YES_NO );
             mdiag.set_default_response( Gtk::RESPONSE_YES );
             if( mdiag.run() != Gtk::RESPONSE_YES ) return;
-            delete_view();
+            slot_delete_logs();
             break;
         }
 
@@ -1160,25 +1164,21 @@ void BoardView::operate_view( const int& control )
 
         // 検索
         case CONTROL::Search:
-            if( get_boardtoolbar() ){
-                m_search_invert = false;
-                get_boardtoolbar()->m_entry_search.grab_focus();
-            }
+            m_search_invert = false;
+            BOARD::get_admin()->set_command( "focus_toolbar_search" );
             break;
 
         case CONTROL::SearchInvert:
-            if( get_boardtoolbar() ){
-                m_search_invert = true;
-                get_boardtoolbar()->m_entry_search.grab_focus();
-            }
+            m_search_invert = true;
+            BOARD::get_admin()->set_command( "focus_toolbar_search" );
             break;
 
         case CONTROL::SearchNext:
-            slot_push_down_search();
+            down_search();
             break;
     
         case CONTROL::SearchPrev:
-            slot_push_up_search();
+            up_search();
             break;
 
             // サイドバー表示/非表示
@@ -1265,19 +1265,6 @@ void BoardView::scroll_right()
 }
 
 
-
-//
-// ツールバー表示切り替え
-//
-void BoardView::toggle_toolbar()
-{
-    if( ! get_boardtoolbar() ) return;
-
-    if( SESSION::get_show_board_toolbar() ) get_boardtoolbar()->show_toolbar();
-    else get_boardtoolbar()->hide_toolbar();
-}
-
-
 //
 // 上へ移動
 //
@@ -1314,12 +1301,6 @@ void BoardView::page_down()
 } 
    
 
-BoardToolBar* BoardView::get_boardtoolbar()
-{
-    return dynamic_cast< BoardToolBar* >( get_toolbar() );
-}
-
-
 //
 // ポップアップメニュー取得
 //
@@ -1774,7 +1755,7 @@ void BoardView::slot_favorite_board()
 //
 // 新スレをたてる
 //
-void BoardView::slot_new_article()
+void BoardView::write()
 {
     CORE::core_set_command( "create_new_thread", get_url() );
 }
@@ -1783,7 +1764,7 @@ void BoardView::slot_new_article()
 //
 // ツールバーの削除ボタン
 //
-void BoardView::slot_push_delete()
+void BoardView::delete_view()
 {
     show_popupmenu( "popup_menu_delete", false );
 }
@@ -1792,7 +1773,7 @@ void BoardView::slot_push_delete()
 //
 // ツールバーのお気に入りボタン
 //
-void BoardView::slot_push_favorite()
+void BoardView::set_favorite()
 {
     show_popupmenu( "popup_menu_favorite", false );
 }
@@ -1914,12 +1895,10 @@ std::string BoardView::path2daturl( const Gtk::TreePath& path )
 //
 bool BoardView::drawout()
 {
-    if( ! get_boardtoolbar() ) return false;
-
     int hit = 0;
     bool reset = false;
 
-    std::string query = get_boardtoolbar()->m_entry_search.get_text();
+    std::string query = get_search_query();
 
     // 空の時はリセット
     if( query.empty() ) reset = true;
@@ -1969,8 +1948,14 @@ bool BoardView::drawout()
 //
 // 検索ボックスの文字列が変わった
 //
-void BoardView::slot_changed_search()
+void BoardView::set_search_query( const std::string& query )
 {
+    SKELETON::View::set_search_query( query );
+
+#ifdef _DEBUG
+    std::cout << "BoardView::set_search_query query = " << get_search_query() << std::endl;
+#endif
+
     if( CONFIG::get_inc_search_board() ){
         drawout();
         m_pre_query = std::string();
@@ -1979,18 +1964,16 @@ void BoardView::slot_changed_search()
 
 
 //
-// 検索移動
+// 検索実行
 //
-void BoardView::slot_active_search()
+void BoardView::exec_search()
 {
-    if( ! get_boardtoolbar() ) return;
-    if( get_boardtoolbar()->m_entry_search.completion() ) return;
-
-    std::string query = get_boardtoolbar()->m_entry_search.get_text();
+    std::string query = get_search_query();
     if( m_pre_query != query ){
         drawout();
         focus_view();
         m_pre_query = query;
+        CORE::get_completion_manager()->set_query( CORE::COMP_SEARCH, query );
         return;
     }
 
@@ -2042,40 +2025,31 @@ void BoardView::slot_active_search()
 
 
 // 前検索
-void BoardView::slot_push_up_search()
+void BoardView::up_search()
 {
     m_search_invert = true;
-    slot_active_search();
+    exec_search();
 }
 
 
 
 // 後検索
-void BoardView::slot_push_down_search()
+void BoardView::down_search()
 {
     m_search_invert = false;
-    slot_active_search();
-}
-
-
-// キャッシュ内のログ検索
-void BoardView::search_cache()
-{
-    if( ! get_boardtoolbar() ) return;
-    if( get_boardtoolbar()->m_entry_search.completion() ) return;
-
-    std::string query = get_boardtoolbar()->m_entry_search.get_text();
-    CORE::core_set_command( "open_article_searchlog", get_url() , query );
+    exec_search();
 }
 
 
 //
 // 検索entryの操作
 //
-void BoardView::slot_entry_operate( int controlid )
+void BoardView::operate_search( const std::string& controlid )
 {
-    if( controlid == CONTROL::Cancel ) focus_view();
-    else if( controlid == CONTROL::SearchCache ) search_cache();
+    int id = atoi( controlid.c_str() );
+
+    if( id == CONTROL::Cancel ) focus_view();
+    else if( id == CONTROL::SearchCache ) CORE::core_set_command( "open_article_searchlog", get_url() , get_search_query() );
 }
 
 
@@ -2104,6 +2078,39 @@ void BoardView::slot_preferences_article()
 }
 
 
+//
+// 板名更新
+//
+void BoardView::update_boardname()
+{
+    // タイトル表示
+    set_title( DBTREE::board_name( get_url() ) );
+    BOARD::get_admin()->set_command( "set_title", get_url(), get_title() );
+
+    // タブに名前をセット
+    BOARD::get_admin()->set_command( "set_tablabel", get_url(), DBTREE::board_name( get_url() ) );
+}
+
+
+//
+// 戻る
+//
+void BoardView::back_viewhistory( const int count )
+{
+    BOARD::get_admin()->set_command( "back_viewhistory", get_url(), MISC::itostr( count ) );
+}
+
+
+//
+// 進む
+//
+void BoardView::forward_viewhistory( const int count )
+{
+    BOARD::get_admin()->set_command( "forward_viewhistory", get_url(), MISC::itostr( count ) );
+}
+
+
+
 //
 // datを保存
 //
