@@ -8,7 +8,10 @@
 #include "dbtree/interface.h"
 #include "dbtree/boardbase.h"
 
+#include "skeleton/msgdiag.h"
+
 #include "jdlib/miscutil.h"
+#include "jdlib/misctime.h"
 
 #include "cache.h"
 #include "command.h"
@@ -27,10 +30,12 @@ Preferences::Preferences( Gtk::Window* parent, const std::string& url )
       m_frame_cookie( "クッキー＆Hana" ),
       m_button_cookie( "削除" ) ,
 
+      m_check_live( "実況する" ),
+
       m_proxy_frame( "読み込み用" ),
       m_proxy_frame_w( "書き込み用" ),
 
-      m_label_name( "板タイトル：" + DBTREE::board_name( get_url() ), Gtk::ALIGN_LEFT ),
+      m_label_name( false, "板タイトル：", DBTREE::board_name( get_url() ) ),
       m_label_url( false, "板のURL：", DBTREE::url_boardbase( get_url() ) ),
       m_label_cache( false, "ローカルキャッシュのルートパス", CACHE::path_board_root( DBTREE::url_boardbase( get_url() ) ) ),
 
@@ -38,6 +43,9 @@ Preferences::Preferences( Gtk::Window* parent, const std::string& url )
       m_label_noname( false, "デフォルト名無し：", DBTREE::default_noname( get_url() ) ),
       m_label_line( false, "1レスの最大改行数：" ),
       m_label_byte( false, "1レスの最大バイト数：" ),
+      m_entry_max_res( false, "最大レス数：" ),
+      m_label_modified( false, "最終更新日時 ：" ),
+      m_button_clearmodified( "日時クリア" ),
       m_label_samba( false, "書き込み規制秒数 (Samba24) ：" ),
       m_button_clearsamba( "秒数クリア" ),
       m_localrule( NULL )
@@ -88,17 +96,49 @@ Preferences::Preferences( Gtk::Window* parent, const std::string& url )
 
     m_frame_cookie.add( m_hbox_cookie );
 
+    // 実況
+    const int live_sec = DBTREE::board_get_live_sec( get_url() );
+    m_label_live.set_text( "実況時の更新間隔(秒)：" );
+
+    m_spin_live.set_range( MIN_LIVE_RELOAD_SEC, 1200 );
+    m_spin_live.set_increments( 1, 1 );
+    m_spin_live.set_value( MAX( live_sec, MIN_LIVE_RELOAD_SEC ) );
+    if( live_sec ){
+        m_check_live.set_active( true );
+        m_spin_live.set_sensitive( true );
+    }
+    else{
+        m_check_live.set_active( false );
+        m_spin_live.set_sensitive( false );
+    }
+    m_check_live.signal_toggled().connect( sigc::mem_fun(*this, &Preferences::slot_check_live ) );
+
+    m_hbox_live.set_spacing( 4 );
+    m_hbox_live.pack_start( m_label_live, Gtk::PACK_SHRINK );
+    m_hbox_live.pack_start( m_spin_live, Gtk::PACK_SHRINK );
+    m_hbox_live.pack_start( m_check_live, Gtk::PACK_SHRINK );
 
     // 一般ページのパッキング
     m_label_line.set_text( MISC::itostr( DBTREE::line_number( get_url() ) * 2 ) );
     m_label_byte.set_text( MISC::itostr( DBTREE::message_count( get_url() ) ) );
 
-    int samba_sec = DBTREE::board_samba_sec( get_url() );
+    int max_res = DBTREE::board_get_number_max_res( get_url() );
+    if( ! max_res ) m_entry_max_res.set_text( "未設定 " );
+    else m_entry_max_res.set_text( MISC::itostr( max_res ) );
+
+    if( DBTREE::board_date_modified( get_url() ).empty() ) m_label_modified.set_text( "未取得" );
+    else m_label_modified.set_text( MISC::timettostr( DBTREE::board_time_modified( get_url() ) ) );
+
+    m_button_clearmodified.signal_clicked().connect( sigc::mem_fun(*this, &Preferences::slot_clear_modified ) );
+    m_hbox_modified.pack_start( m_label_modified );
+    m_hbox_modified.pack_start( m_button_clearmodified, Gtk::PACK_SHRINK );    
+
+    const int samba_sec = DBTREE::board_samba_sec( get_url() );
     if( ! samba_sec ) m_label_samba.set_text( "未取得" );
     else m_label_samba.set_text( MISC::itostr( samba_sec ) );
 
     m_button_clearsamba.signal_clicked().connect( sigc::mem_fun(*this, &Preferences::slot_clear_samba ) );
-    m_hbox_samba.pack_start( m_label_samba, Gtk::PACK_SHRINK );
+    m_hbox_samba.pack_start( m_label_samba );
     m_hbox_samba.pack_start( m_button_clearsamba, Gtk::PACK_SHRINK );    
 
     m_vbox.set_border_width( 16 );
@@ -110,6 +150,9 @@ Preferences::Preferences( Gtk::Window* parent, const std::string& url )
     m_vbox.pack_start( m_label_noname, Gtk::PACK_SHRINK );
     m_vbox.pack_start( m_label_line, Gtk::PACK_SHRINK );
     m_vbox.pack_start( m_label_byte, Gtk::PACK_SHRINK );
+    m_vbox.pack_start( m_entry_max_res, Gtk::PACK_SHRINK );
+    m_vbox.pack_start( m_hbox_modified, Gtk::PACK_SHRINK );
+    m_vbox.pack_start( m_hbox_live, Gtk::PACK_SHRINK );
     m_vbox.pack_start( m_hbox_samba, Gtk::PACK_SHRINK );
     m_vbox.pack_end( m_frame_cookie, Gtk::PACK_SHRINK );
     m_vbox.pack_end( m_frame_write, Gtk::PACK_SHRINK );
@@ -251,10 +294,22 @@ Preferences::~Preferences()
 }
 
 
+void Preferences::slot_clear_modified()
+{
+    DBTREE::board_set_date_modified( get_url(), "" );
+
+    if( DBTREE::board_date_modified( get_url() ).empty() ) m_label_modified.set_text( "未取得" );
+    else m_label_modified.set_text( MISC::timettostr( DBTREE::board_time_modified( get_url() ) ) );
+}
+
+
 void Preferences::slot_clear_samba()
 {
     DBTREE::board_set_samba_sec( get_url(), 0 );
-    m_label_samba.set_text( MISC::itostr( DBTREE::board_samba_sec( get_url() ) ) );
+
+    const int samba_sec = DBTREE::board_samba_sec( get_url() );
+    if( ! samba_sec ) m_label_samba.set_text( "未取得" );
+    else m_label_samba.set_text( MISC::itostr( samba_sec ) );
 }
 
 
@@ -267,6 +322,17 @@ void Preferences::slot_delete_cookie()
 }
 
 
+void Preferences::slot_check_live()
+{
+    if( m_check_live.get_active() ){
+        m_spin_live.set_sensitive( true );
+        SKELETON::MsgDiag mdiag( NULL, "実況を許された板以外では実況しないようにして下さい。\n\n実況状態のまま閉じたスレはJD終了時に削除されます。詳しくはマニュアルの実況の項目を参照して下さい。",
+                                 false, Gtk::MESSAGE_WARNING );
+        mdiag.run();
+    }
+    else m_spin_live.set_sensitive( false );
+}
+
 
 void Preferences::slot_switch_page( GtkNotebookPage*, guint page )
 {
@@ -321,6 +387,12 @@ void Preferences::slot_ok_clicked()
     if( tmpmail.empty() ) tmpmail = JD_MAIL_BLANK; // 空白の場合 JD_MAIL_BLANK をセットする
     DBTREE::board_set_write_mail( get_url(), tmpmail );
 
+    // 実況間隔
+    int live_sec = 0;
+    if( m_check_live.get_active() ) live_sec = m_spin_live.get_value_as_int();
+    DBTREE::board_set_live_sec( get_url(), live_sec );
+    CORE::core_set_command( "redraw_article_toolbar" );
+
     DBTREE::board_save_info( get_url() );
 }
 
