@@ -13,8 +13,8 @@ namespace CORE
     char browsers[ BROWSER_NUM ][ 2 ][ MAX_TEXT ]={
 
         { "ユーザ設定", "" },
-        { "RedHat系標準ブラウザ",    "xdg-open \"%LINK\"" },
-        { "firefox 1.5/2.0 以降", "firefox \"%LINK\"" },
+        { "標準ブラウザ",    "xdg-open \"%LINK\"" },
+        { "firefox 1.5/2.0/3.0 以降", "firefox \"%LINK\"" },
         { "firefox 1.0*", "firefox -remote \"openURL(%LINK,new-tab)\"" },
         { "opera 9.*",    "opera -remote \"openURL(%LINK,new-tab)\"" }
     };
