@@ -10,6 +10,12 @@
 #include <list>
 #include <vector>
 
+namespace JDLIB
+{
+    class ConfLoader;
+}
+
+
 namespace CONFIG
 {
     class ConfigItems
@@ -22,6 +28,9 @@ namespace CONFIG
         bool restore_article;
         bool restore_image;
 
+        // 自前でウィンドウ配置を管理する
+        bool manage_winpos;
+
         // フォント
         std::vector< std::string > fontname;
 
@@ -30,6 +39,7 @@ namespace CONFIG
 
         // ref_prefix の後のスペースの数
         int ref_prefix_space;
+        std::string ref_prefix_space_str;
 
         // キャッシュのルートディレクトリ
         // 旧バージョンとの互換のため残しているだけで使用していない
@@ -149,6 +159,9 @@ namespace CONFIG
         // ツリービューの行間スペース
         int tree_ypad;
 
+        // 各ビューと枠との間の余白
+        int view_margin;
+
         // スレ一覧で古いスレも表示
         bool show_oldarticle;
 
@@ -158,21 +171,33 @@ namespace CONFIG
         // スレ一覧でインクリメント検索をする
         bool inc_search_board;
 
-        // ツリービューのスクロール量(行数)
+        // ツリービューのスクロール量(マウスホイール上下・行数)
         int tree_scroll_size;
 
-        // スレビューのスクロール量
+        // スレビューのスクロール量(マウスホイール上下・行数)
         int scroll_size;
 
-        // スレビューのスクロール量(キー上下)
+        // スレビューのスクロール量(キー上下・行数)
         int key_scroll_size;
 
+        // スレビューの高速スクロール量(キー上下・ ページ高 - 行高 * key_fastscroll_size )
+        int key_fastscroll_size;
+
         // スレビューでリロード後に一番下までスクロール
         bool jump_after_reload;
 
         // スレビューでリロード後に新着までスクロール
         bool jump_new_after_reload;
 
+        // 実況モード
+        int live_mode;
+
+        // 実況速度
+        int live_speed;
+
+        // 実況のスクロールモードを切り替えるしきい値
+        int live_threshold;
+
         // 板一覧でカテゴリを常にひとつだけ開く
         bool open_one_category;
 
@@ -182,6 +207,9 @@ namespace CONFIG
         // 書き込みログを保存
         bool save_postlog;
 
+        // 書き込みログの最大サイズ
+        int maxsize_postlog;
+
         // 「書き込み中」のダイアログを表示しない
         bool hide_writing_dialog;
 
@@ -255,6 +283,12 @@ namespace CONFIG
         // タブにアイコンを表示するか
         bool show_tab_icon;
 
+        // スレビューに書き込みマークを表示するか
+        bool show_post_mark;
+
+        // ボタンをフラットにするか
+        bool flat_button;
+
         // スレ あぼーん word
         std::list< std::string > list_abone_word_thread;
 
@@ -300,9 +334,14 @@ namespace CONFIG
         // 保存
         void save();
 
+        // 色のリセット
+        void reset_colors();
+
       private:
 
         void save_impl( const std::string& path );
+
+        void set_colors( JDLIB::ConfLoader& cf );
     };
     
 }
