@@ -16,6 +16,7 @@ namespace CONFIG
         CONF_RESTORE_BOARD = 0,     // スレ一覧を復元
         CONF_RESTORE_ARTICLE = 0,   // スレを復元
         CONF_RESTORE_IMAGE = 0,     // 画像を復元
+        CONF_MANAGE_WINPOS = 1,    // 自前でウィンドウ配置を管理する
         CONF_REF_PREFIX_SPACE = 1, // 参照文字( CONF_REF_PREFIX ) の後のスペースの数
         CONF_USE_PROXY_FOR2CH = 0, // 2ch 読み込み用プロクシを使用するか
         CONF_PROXY_PORT_FOR2CH = 8080, // 2ch 読み込み用プロクシポート番号
@@ -35,17 +36,22 @@ namespace CONFIG
         CONF_IDPOPUP_BY_MO = 0,     // IDの上にマウスオーバーしたときにIDをポップアップ表示する
         CONF_USE_TREE_GTKRC = 0,    // ツリービューでgtkrcの設定を使用するか
         CONF_TREE_YPAD = 1,         // ツリービューの行間スペース
+        CONF_VIEW_MARGIN = 0,       // 各ビューと枠との間の余白
         CONF_SHOW_OLDARTICLE = 0,   // スレ一覧で古いスレも表示
         CONF_NEWTHREAD_HOUR = 24,   // スレ一覧で指定した値(時間)よりも後に立てられたスレを新着とみなす
         CONF_INC_SEARCH_BOARD = 0,  // スレ一覧でインクリメント検索をする
         CONF_TREE_SCROLL_SIZE = 4,  // ツリービューのスクロール量(行数)
         CONF_SCROLL_SIZE = 3,       // スレビューのスクロール量
         CONF_KEY_SCROLL_SIZE = 2,   // スレビューのスクロール量(キー上下)
+        CONF_KEY_FASTSCROLL_SIZE = 2,  // スレビューの高速スクロール量(キー上下・ ページ高 - 行高 * key_fastscroll_size )
         CONF_JUMP_AFTER_RELOAD = 0, // スレビューでリロード後に一番下までスクロール
         CONF_JUMP_NEW_AFTER_RELOAD = 0, // スレビューでリロード後に新着までスクロール
+        CONF_LIVE_SPEED = 2,        // 実況速度
+        CONF_LIVE_THRESHOLD = 10,   // 実況のスクロールモードを切り替えるしきい値
         CONF_OPEN_ONE_CATEGORY = 0, // 板一覧でカテゴリを常にひとつだけ開く
         CONF_ALWAYS_WRITE_OK = 0,   // 書き込み時に書き込み確認ダイアログを出さない
         CONF_SAVE_POSTLOG = 0,      //書き込みログを保存
+        CONF_MAXSIZE_POSTLOG = ( 256 * 1024 ), // 書き込みログの最大サイズ
         CONF_HIDE_WRITING_DIALOG = 0, // 「書き込み中」のダイアログを表示しない
         CONF_FOLD_MESSAGE = 0,      // 非アクティブ時に書き込みビューを折りたたむ
         CONF_MARGIN_POPUP = 30,     // レスアンカーとポップアップの間のマージン
@@ -71,6 +77,8 @@ namespace CONFIG
         CONF_RELOAD_ALLTHREAD = 0,  // スレビューで再読み込みボタンを押したときに全タブを更新する
         CONF_TAB_MIN_STR = 4, // タブに表示する文字列の最小値
         CONF_SHOW_TAB_ICON = 1, // タブにアイコンを表示するか
+        CONF_SHOW_POST_MARK = 1, // スレビューに書き込みマークを表示するか
+        CONF_FLAT_BUTTON = 1,    // ボタンをフラットにするか
         CONF_IMGPOPUP_WIDTH = 320,  // 画像ポップアップ幅
         CONF_IMGPOPUP_HEIGHT = 240, // 画像ポップアップ高さ
         CONF_USE_IMAGE_POPUP = 1,    // 画像ポップアップを使用する
@@ -82,7 +90,7 @@ namespace CONFIG
         CONF_DEL_IMGABONE_DAY = 20, // 画像あぼーん削除の日数
         CONF_MAX_IMG_SIZE = 16,     // ダウンロードする画像の最大サイズ(Mbyte)
         CONF_MAX_IMG_PIXEL = 20,     // 画像の最大サイズ(Mピクセル)
-        CONF_LINK_AS_BOARD = 0,     // bbsmenu.html内にあるリンクは全て板とみなす
+        CONF_USE_LINK_AS_BOARD = 0,     // bbsmenu.html内にあるリンクは全て板とみなす
         CONF_ABONE_NUMBER_THREAD = 0, // スレあぼーん( レス数 )
         CONF_ABONE_HOUR_THREAD = 0,   // スレあぼーん( スレ立てからの経過時間 )
         CONF_ABONE_TRANSPARENT = 0, // デフォルトで透明あぼーんをする
@@ -101,32 +109,32 @@ namespace CONFIG
 #define CONF_PATH_CACHEROOT "~/.jd/"
 
 // 2ch にアクセスするときのエージェント名
-#define AGENT_FOR2CH "Monazilla/1.00 JD"
+#define CONF_AGENT_FOR2CH "Monazilla/1.00 JD"
 
 // 2ch外にアクセスするときのエージェント名
-#define AGENT_FOR_DATA "Mozilla/5.0 (Windows; U; Windows NT 5.0; ja; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11"
+#define CONF_AGENT_FOR_DATA "Mozilla/5.0 (Windows; U; Windows NT 5.0; ja; rv:1.9) Gecko/2008052906 Firefox/3.0"
 
 // 2ch にログインするときのX-2ch-UA
 #define CONF_X_2CH_UA "Navigator for 2ch 1.7.5"
 
 // JD ホームページのアドレス
-#define CONF_JDHP "http://jd4linux.sourceforge.jp/"
+#define CONF_URL_JDHP "http://jd4linux.sourceforge.jp/"
 
 // 2chの認証サーバ
 #define CONF_LOGIN2CH "https://2chv.tora3.net/futen.cgi"
 
 // bbsmenu.htmlのURL
-#define CONF_BBSMENU "http://menu.2ch.net/bbsmenu.html"
+#define CONF_URL_BBSMENU "http://menu.2ch.net/bbsmenu.html"
 
 // スレタイ検索用メニュータイトルアドレス
-#define CONF_MENU_SEARCH_TITLE  "スレタイ検索(find2ch)"
+#define CONF_MENU_SEARCH_TITLE  "スレタイ検索 (find2ch)"
 #define CONF_URL_SEARCH_TITLE "http://find.2ch.net/?STR=$TEXTX&COUNT=50&TYPE=TITLE&BBS=ALL"
 
 // スレタイ検索用正規表現
 #define CONF_REGEX_SEARCH_TITLE "<a href=\"(http[^\"]*)\">(.+?)</a> \\(([0-9]{1,4})\\)"
 
 // WEB検索用メニュータイトルアドレス
-#define CONF_MENU_SEARCH_WEB  "WEB検索(google)"
+#define CONF_MENU_SEARCH_WEB  "WEB検索 (google)"
 #define CONF_URL_SEARCH_WEB "http://www.google.co.jp/search?hl=ja&q=$TEXTU&btnG=Google+%E6%A4%9C%E7%B4%A2&lr="
 
 // 色
@@ -137,7 +145,6 @@ namespace CONFIG
 #define CONF_COLOR_CHAR_AGE "#fde800000000"    // ageの時のメール欄の文字色
 #define CONF_COLOR_CHAR_SELECTION "#ffffffffffff"  // 選択範囲の文字色
 #define CONF_COLOR_CHAR_HIGHLIGHT str_color[ COLOR_CHAR ] // ハイライトの文字色
-#define CONF_COLOR_CHAR_BOOKMARK str_color[ COLOR_CHAR_AGE ] // ブックマークの文字色
 #define CONF_COLOR_CHAR_LINK "#00000000ffff" //リンク(通常)の文字色
 #define CONF_COLOR_CHAR_LINK_LOW "#ffff0000ffff" // リンク(複数)の文字色
 #define CONF_COLOR_CHAR_LINK_HIGH str_color[ COLOR_CHAR_AGE ] // リンク(多数)の文字色
@@ -165,6 +172,7 @@ namespace CONFIG
 #define CONF_COLOR_MARKER str_color[ COLOR_CHAR ] // オートスクロールマーカー色    
 
 #define CONF_COLOR_CHAR_BBS   str_color[ COLOR_CHAR ] // 板一覧の文字
+#define CONF_COLOR_CHAR_BBS_COMENT  str_color[ COLOR_CHAR ] // 板一覧のコメント
 #define CONF_COLOR_CHAR_BOARD str_color[ COLOR_CHAR ] // スレ一覧の文字
 
 #define CONF_COLOR_BACK_BBS   str_color[ COLOR_BACK ] // 板一覧の背景色
