@@ -65,11 +65,14 @@ void CONFIG::restore_conf()
 
 
 const bool CONFIG::get_restore_board(){ return get_confitem()->restore_board; }
-void CONFIG::set_restore_board( bool restore ){ get_confitem()->restore_board = restore; }
+void CONFIG::set_restore_board( const bool restore ){ get_confitem()->restore_board = restore; }
 const bool CONFIG::get_restore_article(){ return get_confitem()->restore_article; }
-void CONFIG::set_restore_article( bool restore ){ get_confitem()->restore_article = restore; }
+void CONFIG::set_restore_article( const bool restore ){ get_confitem()->restore_article = restore; }
 const bool CONFIG::get_restore_image(){ return get_confitem()->restore_image; }
-void CONFIG::set_restore_image( bool restore ){ get_confitem()->restore_image = restore; }
+void CONFIG::set_restore_image( const bool restore ){ get_confitem()->restore_image = restore; }
+
+const bool CONFIG::get_manage_winpos(){ return get_confitem()->manage_winpos; }
+void CONFIG::set_manage_winpos( const bool manage ){ get_confitem()->manage_winpos = manage; }
 
 
 // 色
@@ -83,10 +86,13 @@ void CONFIG::set_color( int id, const std::string& color )
     get_confitem()->str_color[ id ] = color;
 }
 
+void CONFIG::reset_colors(){ get_confitem()->reset_colors(); }
+
 const bool CONFIG::get_use_tree_gtkrc(){ return get_confitem()->use_tree_gtkrc; }
 
 const int CONFIG::get_tree_ypad(){ return get_confitem()->tree_ypad; }
 
+const int CONFIG::get_view_margin(){ return get_confitem()->view_margin; }
 
 // フォント
 const std::string& CONFIG::get_fontname( int id )
@@ -99,7 +105,8 @@ void CONFIG::set_fontname( int id, const std::string& fontname )
     get_confitem()->fontname[ id ] = fontname;
 }
 
-const std::string&  CONFIG::get_ref_prefix(){ return get_confitem()->ref_prefix; }
+const std::string CONFIG::get_ref_prefix(){ return get_confitem()->ref_prefix + get_confitem()->ref_prefix_space_str; }
+const int CONFIG::ref_prefix_space(){ return get_confitem()->ref_prefix_space; }
 
 const std::string& CONFIG::get_url_jdhp() { return get_confitem()->url_jdhp; }
 
@@ -197,17 +204,28 @@ const bool CONFIG::get_inc_search_board(){ return get_confitem()->inc_search_boa
 const int CONFIG::get_tree_scroll_size(){ return get_confitem()->tree_scroll_size; }
 const int CONFIG::get_scroll_size(){ return get_confitem()->scroll_size; }
 const int CONFIG::get_key_scroll_size(){ return get_confitem()->key_scroll_size; }
+const int CONFIG::get_key_fastscroll_size(){ return get_confitem()->key_fastscroll_size; }
 
 const bool CONFIG::get_jump_after_reload(){ return get_confitem()->jump_after_reload; }
 void CONFIG::set_jump_after_reload( bool set ){ get_confitem()->jump_after_reload = set; }
 const bool CONFIG::get_jump_new_after_reload(){ return get_confitem()->jump_new_after_reload; }
 void CONFIG::set_jump_new_after_reload( bool set ){ get_confitem()->jump_new_after_reload = set; }
 
+const int CONFIG::get_live_mode(){ return get_confitem()->live_mode; }
+void CONFIG::set_live_mode( const int mode ) { get_confitem()->live_mode = mode; }
+const int CONFIG::get_live_speed(){ return get_confitem()->live_speed; }
+void CONFIG::set_live_speed( const int speed ){ get_confitem()->live_speed = speed; }
+const int CONFIG::get_live_threshold(){ return get_confitem()->live_threshold; }
+void CONFIG::set_live_threshode( const int th ){ get_confitem()->live_threshold = th; }
+
 const bool CONFIG::get_open_one_category(){ return get_confitem()->open_one_category; }
 const bool CONFIG::get_always_write_ok() { return get_confitem()->always_write_ok; }
 void CONFIG::set_always_write_ok( bool write_ok ){ get_confitem()->always_write_ok = write_ok; }
+
 const bool CONFIG::get_save_postlog(){ return get_confitem()->save_postlog; }
 void CONFIG::set_save_postlog( bool save ){ get_confitem()->save_postlog = save; }
+const size_t CONFIG::get_maxsize_postlog(){ return get_confitem()->maxsize_postlog; }
+
 const bool CONFIG::get_hide_writing_dialog(){ return get_confitem()->hide_writing_dialog; }
 const bool CONFIG::get_fold_message(){ return get_confitem()->fold_message; }
 void CONFIG::set_fold_message( bool fold ){ get_confitem()->fold_message = fold; }
@@ -277,6 +295,11 @@ const bool CONFIG::get_reload_allthreads(){ return get_confitem()->reload_allthr
 const int CONFIG::get_tab_min_str(){ return get_confitem()->tab_min_str; }
 
 const bool CONFIG::get_show_tab_icon(){ return get_confitem()->show_tab_icon; }
+const bool CONFIG::get_show_post_mark(){ return get_confitem()->show_post_mark; }
+void CONFIG::set_show_post_mark( const bool show ){ get_confitem()->show_post_mark = show; }
+
+const bool CONFIG::get_flat_button(){ return get_confitem()->flat_button; }
+void CONFIG::set_flat_button( const bool set ){ get_confitem()->flat_button = set; }
 
 std::list< std::string >& CONFIG::get_list_abone_word_thread(){ return get_confitem()->list_abone_word_thread; }
 std::list< std::string >& CONFIG::get_list_abone_regex_thread(){ return get_confitem()->list_abone_regex_thread; }
