@@ -42,6 +42,9 @@ namespace CONTROL
 
         PreBookMark,
         NextBookMark,
+
+        PrevView,
+        NextView,
         
         ToggleArticle,
 
@@ -68,6 +71,7 @@ namespace CONTROL
         SelectAll,
         AppendFavorite,
         Property,
+        Lock,
     
         Search,
         CloseSearchBar,
@@ -80,6 +84,7 @@ namespace CONTROL
 
         ClickButton, // 以下、マウスボタン専用の設定
         DblClickButton,
+        TrpClickButton,
         CloseTabButton,
         ReloadTabButton,
         AutoScrollButton,
@@ -136,6 +141,8 @@ namespace CONTROL
         OpenParentBoard,
         WriteMessage,
 
+        LiveStartStop,
+
         PopupWarpButton, // 以下、マウスボタン専用の設定
         ReferResButton, 
         BmResButton,
@@ -190,7 +197,7 @@ namespace CONTROL
         CancelWrite,
         ExecWrite,
         InsertText,
-        NotClose,
+        LockMessage,
         Preview,
 
         FocusWrite,
