@@ -30,6 +30,16 @@
 using namespace DBTREE;
 
 
+// 情報ファイルのパスをセット
+// デストラクタの中でCACHE::path_article_ext_info()などを呼ぶとabortするので
+// メンバ変数としてパスを取得しておく
+#define SET_INFOPATH() \
+do{ \
+m_path_article_info = CACHE::path_article_info( m_url, m_id ); \
+m_path_article_ext_info = CACHE::path_article_ext_info( m_url, m_id ); \
+} while( false )
+
+
 // 情報ファイルから値を読み込み
 // JDLIB::ConfLoader では遅いので別に作成。オプションの順番に注意すること
 #define GET_INFOVALUE(target,targetname) \
@@ -52,6 +62,7 @@ ArticleBase::ArticleBase( const std::string& datbase, const std::string& id, boo
       m_key( std::string() ),
       m_since_time( 0 ),
       m_since_date( std::string() ),
+      m_code( HTTP_INIT ),
       m_str_code( std::string() ),
       m_status( STATUS_UNKNOWN ),
       m_subject( std::string() ),
@@ -172,12 +183,12 @@ std::list< int > ArticleBase::get_res_name( const std::string& name )
 
 
 //
-// number番のレスの時刻
+// number番のレスの時刻を文字列で取得
 // 内部で regex　を使っているので遅い
 //
-const std::string ArticleBase::get_time( int number )
+const std::string ArticleBase::get_time_str( int number )
 {
-    return get_nodetree()->get_time( number );
+    return get_nodetree()->get_time_str( number );
 }
 
 
@@ -218,6 +229,8 @@ std::list< int > ArticleBase::get_res_id_name( const std::string& id_name )
 // list_jointは出力で true のスレは前のスレに連結される (例) "3+4" なら 4が3に連結
 std::list< int > ArticleBase::get_res_str_num( const std::string& str_num, std::list< bool >& list_joint )
 {
+    if( empty() ){ std::list< int > tmp; return tmp; }
+
     return get_nodetree()->get_res_str_num( str_num, list_joint );
 }
 
@@ -235,6 +248,19 @@ std::list< int > ArticleBase::get_res_bm()
 }
 
 
+// 書き込みしたレス番号をリストにして取得
+std::list< int > ArticleBase::get_res_posted()
+{
+    std::list< int > list_resnum;          
+    for( int i = 1; i <= m_number_load ; ++i ){
+        if( is_posted( i ) ) list_resnum.push_back( i );
+    }
+
+    // あぼーんしていてもリストから取り除かない
+    return list_resnum;
+}
+
+
 //
 // number番のレスを参照しているレス番号をリストにして取得
 //
@@ -249,6 +275,8 @@ std::list< int > ArticleBase::get_res_reference( int number )
 //
 std::list< int > ArticleBase::get_res_with_url()
 {
+    if( empty() ){ std::list< int > tmp; return tmp; }
+
     return get_nodetree()->get_res_with_url();
 }
 
@@ -260,6 +288,8 @@ std::list< int > ArticleBase::get_res_with_url()
 //
 std::list< int > ArticleBase::get_res_query( const std::string& query, bool mode_or )
 {
+    if( empty() ){ std::list< int > tmp; return tmp; }
+
     return get_nodetree()->get_res_query( query, mode_or );
 }
 
@@ -320,10 +350,7 @@ void ArticleBase::update_datbase( const std::string& datbase )
     m_url = datbase + m_id;
 
     // info ファイルのパスも更新
-    if( ! m_path_article_info.empty() ){
-        m_path_article_info = CACHE::path_article_info( m_url, m_id );  // info
-        m_path_article_ext_info = CACHE::path_article_ext_info( m_url, m_id ); // 拡張info
-    }
+    if( ! m_path_article_info.empty() ) SET_INFOPATH();
 
 #ifdef _DEBUG
     if( !old_url.empty() ) std::cout << "ArticleBase::update_datbase from "  << old_url
@@ -462,6 +489,19 @@ const time_t ArticleBase::get_write_pass()
 }
 
 
+//
+// 書き込み数
+//
+const int ArticleBase::get_num_posted()
+{
+    if( ! m_vec_posted.size() ) return 0;
+
+    int ret = 0;
+    for( int i = 1; i < MAX_RESNUMBER; ++i ) if( is_posted( i ) ) ++ret;
+    return ret;
+}
+
+
 //
 // スレ自体のスレ一覧でのブックマーク
 //
@@ -708,7 +748,7 @@ void ArticleBase::set_abone_chain( bool set )
 //
 // ブックマークの数
 //
-int ArticleBase::get_num_bookmark()
+const int ArticleBase::get_num_bookmark()
 {
     if( ! m_vec_bookmark.size() ) return 0;
 
@@ -721,7 +761,7 @@ int ArticleBase::get_num_bookmark()
 //
 // ブックマークされているか
 //
-bool ArticleBase::is_bookmarked( int number )
+const bool ArticleBase::is_bookmarked( const int number )
 {
     if( number <= 0 || number > m_number_load ) return false;
 
@@ -737,7 +777,7 @@ bool ArticleBase::is_bookmarked( int number )
 //
 // ブックマークセット
 //
-void ArticleBase::set_bookmark( int number, bool set )
+void ArticleBase::set_bookmark( const int number, const bool set )
 {
     if( ! m_vec_bookmark.size() ) get_nodetree();
     if( number <= 0 || number > MAX_RESNUMBER ) return;
@@ -749,6 +789,27 @@ void ArticleBase::set_bookmark( int number, bool set )
 }
 
 
+//
+// 自分が書き込んだレスか
+//
+const bool ArticleBase::is_posted( const int number )
+{
+    if( number <= 0 || number > m_number_load ) return false;
+
+    // まだnodetreeが作られてなくて情報が得られてないのでnodetreeを作って情報取得
+    if( ! m_vec_posted.size() ) get_nodetree();
+
+    if( ! m_vec_posted.size() ) return false;
+
+    return ( m_vec_posted[ number ] );
+}
+
+
+// 自分の書き込みにレスしたか
+const bool ArticleBase::is_refer_posted( const int number )
+{
+    return get_nodetree()->is_refer_posted( number );
+}
 
 
 //
@@ -765,7 +826,7 @@ JDLIB::ConstPtr< NodeTreeBase >& ArticleBase::get_nodetree()
     if( ! m_nodetree ){
 
 #ifdef _DEBUG
-    std::cout << "ArticleBase::get_nodetree create " << m_url << std::endl;
+        std::cout << "ArticleBase::get_nodetree create " << m_url << std::endl;
 #endif
     
         m_nodetree = create_nodetree();
@@ -775,6 +836,9 @@ JDLIB::ConstPtr< NodeTreeBase >& ArticleBase::get_nodetree()
         m_nodetree->copy_abone_info( m_list_abone_id, m_list_abone_name, m_list_abone_word, m_list_abone_regex, m_vec_abone_res,
                                      m_abone_transparent, m_abone_chain );
 
+        // 書き込み情報のコピー
+        m_nodetree->copy_post_info( m_vec_posted );
+
         m_nodetree->sig_updated().connect( sigc::mem_fun( *this, &ArticleBase::slot_node_updated ) );
         m_nodetree->sig_finished().connect( sigc::mem_fun( *this, &ArticleBase::slot_load_finished ) );
 
@@ -801,6 +865,7 @@ void ArticleBase::unlock_impl()
     std::cout << "ArticleBase::unlock_impl  url = " << m_url << std::endl;
 #endif
 
+    m_nodetree->terminate_load(); // deleteする前にスレッド停止
     m_nodetree.clear();
 
     // スレ情報保存
@@ -871,8 +936,15 @@ void ArticleBase::download_dat( const bool check_update )
     if( SESSION::is_online() && tv.tv_sec ) m_check_update_time = tv;
 
     // DAT落ちしていてログイン中で無い時はロードしない
-    if( ( m_status & STATUS_OLD ) && ! LOGIN::get_login2ch()->login_now() ){
+    if( ( m_status & STATUS_OLD ) && ! CORE::get_login2ch()->login_now() ){
+#ifdef _DEBUG
+        std::cout << "old !\n";
+#endif       
         CORE::core_set_command( "toggle_favorite_icon", m_url );
+
+        // update_article_finish コマンドを送らないとキャッシュが無くて
+        // dat落ちしているスレのタブが空白になる
+        CORE::core_set_command( "update_article_finish", m_url );
         return;
     }
 
@@ -982,9 +1054,26 @@ void ArticleBase::slot_load_finished()
     // nodetreeから情報取得
     m_str_code = m_nodetree->get_str_code();
     std::string m_old_modified = m_date_modified;
-    m_date_modified = m_nodetree->date_modified();
+    m_date_modified = m_nodetree->get_date_modified();
     if( m_number_before_load < m_number_load ) m_number_new = m_number_load - m_number_before_load;
     else m_number_new = 0;
+
+    // 書き込み情報
+    if( m_number_new && m_nodetree->get_vec_posted().size() ){
+
+        if( ! m_vec_posted.size() ) m_vec_posted.resize( MAX_RESNUMBER );
+
+        for( int i = m_number_before_load +1; i <= m_number_load; ++i ){
+
+            if( m_nodetree->get_vec_posted()[ i ] ) m_vec_posted[ i ] = true;
+            else m_vec_posted[ i ] = false;
+
+#ifdef _DEBUG
+            if( m_vec_posted[ i ] ) std::cout << "posted no = " << i << std::endl;
+#endif
+        }
+    }
+
     m_number_before_load = m_number_load;
     m_ext_err = m_nodetree->get_ext_err();
 
@@ -1003,13 +1092,15 @@ void ArticleBase::slot_load_finished()
             if( gettimeofday( &tv, &tz ) == 0 ) m_access_time = tv;
 
             if( m_number < m_number_load ) m_number = m_number_load;
-            m_number_seen = m_number_load;
 
             m_cached = true;
             m_read_info = true;
             m_save_info = true;
             m_enable_load = false;
 
+            // 情報ファイルのパスをセット
+            if( m_path_article_info.empty() ) SET_INFOPATH();
+
             show_updateicon( false );
         }
     }
@@ -1046,7 +1137,7 @@ void ArticleBase::slot_load_finished()
 void ArticleBase::show_updateicon( const bool update )
 {
 #ifdef _DEBUG
-    std::cout << "ArticleBase::show_updateicon update = " << update << " status = " << m_status << std::endl;
+    std::cout << "ArticleBase::show_updateicon url = " << m_url << " update = " << update << " status = " << m_status << std::endl;
 #endif
 
     struct timeval tv;
@@ -1084,7 +1175,7 @@ void ArticleBase::delete_cache( const bool cache_only )
     if( empty() ) return;
 
     if( ! cache_only && m_bookmarked_thread ){
-        SKELETON::MsgDiag mdiag( NULL, "「" + get_subject() + "」はブックマークされています。\n\nスレを削除しますか？"
+        SKELETON::MsgDiag mdiag( NULL, "「" + get_subject() + "」にはしおりが付けられています。\n\nスレを削除しますか？\n\nしおりを解除するにはスレの上で右クリックしてしおり解除を選択してください。"
                                   ,false, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_YES_NO );
         mdiag.set_default_response( Gtk::RESPONSE_YES );
         if( mdiag.run() == Gtk::RESPONSE_NO ) return;
@@ -1102,12 +1193,16 @@ void ArticleBase::delete_cache( const bool cache_only )
         memset( &m_write_time, 0, sizeof( struct timeval ) );
         m_write_time_date.clear();
 
+        m_code =  HTTP_INIT;
+        m_str_code =  std::string();
+
         m_write_name.clear();
         m_write_mail.clear();
         m_write_fixname = false;
         m_write_fixmail = false;
 
         m_vec_bookmark.clear();
+        m_vec_posted.clear();
         m_list_abone_id.clear();
         m_list_abone_name.clear();
         m_list_abone_word.clear();
@@ -1176,24 +1271,21 @@ bool ArticleBase::save_dat( const std::string& path_to )
 //
 void ArticleBase::read_info()
 {
-    // 情報ファイルのパス
-    // デストラクタの中でCACHE::path_article_ext_info()などを呼ぶとabortするので
-    // パスを取得しておく
-    if(  m_path_article_info.empty() ){
-        m_path_article_info = CACHE::path_article_info( m_url, m_id );  // info
-        m_path_article_ext_info = CACHE::path_article_ext_info( m_url, m_id ); // 拡張info
-    }
-
+    if( m_read_info ) return; // 一度読んだら2度読みしない
     if( empty() ) return;
     if( ! m_cached ) return;  // キャッシュがないなら読まない
-    if( m_read_info ) return; // 一度読んだら2度読みしない
-    m_read_info = true;
 
 #ifdef _DEBUG
     std::cout << "ArticleBase::read_info :  url = " << m_url << std::endl;
 #endif
 
-    if( CACHE::file_exists( m_path_article_ext_info ) == CACHE::EXIST_FILE ){
+    m_read_info = true;
+
+    // 情報ファイルのパスをセット
+    if( m_path_article_info.empty() ) SET_INFOPATH();
+
+    int ret = CACHE::file_exists( m_path_article_ext_info );
+    if( ret == CACHE::EXIST_FILE ){
 
         std::string str_info, str_tmp;
         std::list< std::string > list_tmp;
@@ -1334,6 +1426,21 @@ void ArticleBase::read_info()
         m_bookmarked_thread = false;
         GET_INFOVALUE( str_tmp, "bkmark_thread = " );
         if( ! str_tmp.empty() ) m_bookmarked_thread = atoi( str_tmp.c_str() );
+
+        // 書き込みしたレス番号
+        GET_INFOVALUE( str_tmp, "posted = " );
+        if( ! str_tmp.empty() ){
+
+            if( ! m_vec_posted.size() ) m_vec_posted.resize( MAX_RESNUMBER );
+
+            list_tmp = MISC::split_line( str_tmp );
+            it_tmp = list_tmp.begin();
+            for( ; it_tmp != list_tmp.end(); ++it_tmp ){
+                int number = atoi( (*it_tmp).c_str() );
+                if( !(*it_tmp).empty() ) m_vec_posted[ number ] = true;
+                else m_vec_posted[ number ] = false;
+            }
+        }
     }
 
     // キャッシュはあるけど情報ファイルが無い場合
@@ -1343,6 +1450,8 @@ void ArticleBase::read_info()
 #ifdef _DEBUG
         std::cout << "ArticleBase::read_info : update info " << m_url << std::endl;
         std::cout << "load = " << m_number_load << " subject = " << m_subject << std::endl;
+        std::cout << "ret = " << ret << std::endl;
+        std::cout << "path = " << m_path_article_ext_info << std::endl;
 #endif
 
         CORE::core_set_command( "set_status","", "スレ情報更新中・・・しばらくお待ち下さい" );
@@ -1354,6 +1463,7 @@ void ArticleBase::read_info()
         if( !m_number_load ){
             m_number_load = 1;
             m_status |= STATUS_BROKEN;
+            MISC::MSG( "updating failed" );
         }
         
         m_number_before_load = m_number_load;
@@ -1405,8 +1515,13 @@ void ArticleBase::read_info()
         for( int i = 1; i <= m_number_load; ++i ) if( m_vec_bookmark[ i ] ) std::cout << " " << i;
         std::cout << std::endl;
     }
-#endif
 
+    if( m_vec_posted.size() ){
+        std::cout << "posted =";
+        for( int i = 1; i <= m_number_load; ++i ) if( m_vec_posted[ i ] ) std::cout << " " << i;
+        std::cout << std::endl;
+    }
+#endif
 }
 
 
@@ -1427,6 +1542,12 @@ void ArticleBase::save_info( bool force )
 
     if( m_path_article_ext_info.empty() ) return;
 
+#ifdef _DEBUG
+    std::cout << "ArticleBase::save_info force = " << force << std::endl;
+    std::cout << "path_article_info = " << m_path_article_info << std::endl;
+    std::cout << "path_article_ext_info = " << m_path_article_ext_info << std::endl;
+#endif
+
     // 書き込み時間
     std::ostringstream ss_write;
     ss_write << ( m_write_time.tv_sec >> 16 ) << " " << ( m_write_time.tv_sec & 0xffff ) << " " << m_write_time.tv_usec;
@@ -1449,6 +1570,12 @@ void ArticleBase::save_info( bool force )
         for( int i = 1; i <= m_number_load; ++i ) if( m_vec_bookmark[ i ] ) ss_bookmark << " " << i;
     }
 
+    // 書き込み
+    std::ostringstream ss_posted;
+    if( m_vec_posted.size() ){
+        for( int i = 1; i <= m_number_load; ++i ) if( m_vec_posted[ i ] ) ss_posted << " " << i;
+    }
+
     std::ostringstream sstr;
     sstr << "subject = " << m_subject << std::endl
          << "org_host = " << m_org_host << std::endl
@@ -1471,6 +1598,7 @@ void ArticleBase::save_info( bool force )
          << "abonechain = " << m_abone_chain << std::endl
          << "aboneres = " << ss_abone_res.str() << std::endl
          << "bkmark_thread = " << m_bookmarked_thread << std::endl
+         << "posted = " << ss_posted.str() << std::endl
     ;
 
 #ifdef _DEBUG
