@@ -80,6 +80,9 @@ namespace DBTREE
         // 「レス」のブックマーク
         std::vector< char > m_vec_bookmark; // ブックマーク判定キャッシュ
 
+        // 自分が書き込んだレスか
+        std::vector< char > m_vec_posted;
+
         // HDDにキャッシュされているか
         bool m_cached;
 
@@ -145,9 +148,9 @@ namespace DBTREE
         // 指定した発言者の名前のレス番号をリストにして取得
         std::list< int > get_res_name( const std::string& name );
 
-        // number番のレスの時刻
+        // number番のレスの時刻を文字列で取得
         // 内部で regex　を使っているので遅い
-        const std::string get_time( int number );
+        const std::string get_time_str( int number );
 
         // number番のレスの発言者ID( スレIDではなくて名前の横のID )
         const std::string get_id_name( int number );
@@ -170,6 +173,9 @@ namespace DBTREE
         // ブックマークをつけたレス番号をリストにして取得
         std::list< int > get_res_bm();
 
+        // 書き込みしたレス番号をリストにして取得
+        std::list< int > get_res_posted();
+
         // number番のレスを参照しているレス番号をリストにして取得
         std::list< int > get_res_reference( int number );
 
@@ -216,6 +222,13 @@ namespace DBTREE
         const std::string& get_write_date() const { return m_write_time_date; } // string型
         const time_t get_write_pass(); // 経過時間(秒)
 
+        // 書き込みしたレス番号
+        const int get_num_posted();  // 書き込み数
+        const bool is_posted( const int number );
+
+        // 自分の書き込みにレスしたか
+        const bool is_refer_posted( const int number );
+
         // スレ立て時刻
         const time_t& get_since_time() const { return m_since_time; };
         const std::string& get_since_date() const { return m_since_date; }
@@ -301,9 +314,9 @@ namespace DBTREE
         const bool is_bookmarked_thread() const { return m_bookmarked_thread; }
 
         // 「レス」のブックマーク
-        int get_num_bookmark();
-        bool is_bookmarked( int number );
-        void set_bookmark( int number, bool set );
+        const int get_num_bookmark();
+        const bool is_bookmarked( const int number );
+        void set_bookmark( const int number, const bool set );
 
         // 情報ファイル読み込み
         void read_info();
