@@ -3,7 +3,6 @@
 //#define _DEBUG
 #include "jddebug.h"
 
-#include "root.h"
 #include "boardbase.h"
 #include "articlebase.h"
 #include "interface.h"
@@ -43,6 +42,7 @@ BoardBase::BoardBase( const std::string& root, const std::string& path_board, co
     , m_path_board( path_board )
     , m_name( name )
     , m_samba_sec( 0 )
+    , m_live_sec( 0 )
     , m_number_max_res( 0 )
     , m_rawdata( 0 )
     , m_read_info( 0 )
@@ -108,6 +108,21 @@ bool BoardBase::equal( const std::string& url )
 }
 
 
+//
+// 名前を変更
+//
+void BoardBase::update_name( const std::string& name )
+{
+    if( m_name != name ){
+
+        m_name = name;
+
+       // 表示中のviewの板名表示更新
+        CORE::core_set_command( "update_boardname", url_boardbase() );
+    }
+}
+
+
 // user agent
 const std::string& BoardBase::get_agent()
 {
@@ -302,11 +317,23 @@ void BoardBase::read_info()
 
 
 //
-// 移転などで板のルートを変更する
+// 移転などで板のルートやパスを変更する
 //
-void BoardBase::update_root( const std::string& root )
+void BoardBase::update_url( const std::string& root, const std::string& path_board )
 {
+#ifdef _DEBUG
+    std::cout << "BoardBase::update_url\n"
+              << m_root << " -> " << root << std::endl
+              << m_path_board << " -> " << path_board << std::endl;
+#endif
+
     m_root = root;
+    m_path_board = path_board;
+
+    // modified 時刻をリセット
+    // 自動移転処理後に bbsmenu.html を読み込んだときに、bbsmenu.html の
+    // アドレスが古いと二度と自動移転処理しなくなる
+    set_date_modified( std::string() );
 
     // 配下の ArticleBase にも知らせてあげる
     std::list< ArticleBase* >::iterator it;
@@ -332,7 +359,7 @@ const std::string BoardBase::url_dat( const std::string& url, int& num_from, int
     std::string id; // スレッドのID
 
 #ifdef _DEBUG
-    std::cout << "BoardBase::::url_dat : url = " << url << std::endl;
+    std::cout << "BoardBase::url_dat : url = " << url << std::endl;
 #endif
     
     num_from = num_to = 0;
@@ -381,7 +408,37 @@ const std::string BoardBase::url_dat( const std::string& url, int& num_from, int
     }
 
     // どちらでもない(スレのURLでない)場合
-    else return std::string();
+    else{
+
+        // 外部板の移転の場合は path_board も変わるときがあるので
+        // 移転した場合はurlを置換してからもう一度試す
+        std::string old_root;
+        std::string old_path_board;
+        std::string new_root;
+        std::string new_path_board;
+        std::string new_url = DBTREE::is_board_moved( url, old_root, old_path_board, new_root, new_path_board );
+
+#ifdef _DEBUG
+        std::cout << "old_root = " << old_root << " new_root = " << new_root << std::endl;
+        std::cout << "old_path_board = " << old_path_board << " new_path_board = " << new_path_board << std::endl;
+#endif
+
+        if( ! new_url.empty() ){
+
+            std::string url_tmp = MISC::replace_str( url, old_root, new_root );
+            url_tmp = MISC::replace_str( url_tmp, old_path_board + "/", new_path_board + "/" );
+
+#ifdef _DEBUG
+            std::cout << "moved -> " << url_tmp << std::endl;
+#endif
+            return url_dat( url_tmp, num_from, num_to );
+        }
+
+#ifdef _DEBUG
+        std::cout << "not found\n";
+#endif
+        return std::string();
+    }        
 
 #ifdef _DEBUG
     std::cout << "BoardBase::url_dat result : " << url << " ->\n";
@@ -389,6 +446,7 @@ const std::string BoardBase::url_dat( const std::string& url, int& num_from, int
 #endif
 
     // もしurl(スレッドのURL)が移転前の旧URLのものだったら対応するarticlebaseクラスに旧ホスト名を教えてあげる
+    // ( offlaw による dat落ちスレの読み込み時に使用する )
     if( m_root.find( MISC::get_hostname( url ) ) != 0 ){
 #ifdef _DEBUG
         std::cout << "org_host : " << MISC::get_hostname( url ) << std::endl;
@@ -500,7 +558,7 @@ const std::string BoardBase::url_datbase()
 //
 // dat ファイルのURLのパスを返す
 //
-// (例) "/hogeboreadcgipath(ard/dat/"  (最初と最後に '/' がつく)
+// (例) "/hogeboard/dat/"  (最初と最後に '/' がつく)
 //
 const std::string BoardBase::url_datpath()
 {
@@ -656,10 +714,12 @@ ArticleBase* BoardBase::get_article_fromURL( const std::string& url )
 #endif
 
     // urlをdat型に変換してからID取得
-    // 変換できないなら板がDBに登録されてないってことなので NULL クラスを返す
     int num_from, num_to;
     std::string urldat = url_dat( url, num_from, num_to );
+
+    // 板がDBに登録されてないので NULL クラスを返す
     if( urldat.empty() ){
+
 #ifdef _DEBUG
         std::cout << "could not convert url to daturl\nreturn Article_Null\n";
 #endif
@@ -746,7 +806,7 @@ void BoardBase::create_loaderdata( JDLIB::LOADERDATA& data )
     data.size_buf = CONFIG::get_loader_bufsize();
     data.timeout = CONFIG::get_loader_timeout();
     data.basicauth = get_basicauth();
-    data.modified = date_modified();
+    data.modified = get_date_modified();
 }
 
 
@@ -805,13 +865,15 @@ void BoardBase::receive_finish()
                 mdiag.set_default_response( Gtk::RESPONSE_YES );
                 if( mdiag.run() == Gtk::RESPONSE_YES ){
 
-                    DBTREE::update_board( new_url, get_name() );
+                    DBTREE::move_board( url_boardbase(), new_url );
+
+                    // 再読み込み
                     CORE::core_set_command( "open_board", url_subject() );
                 }
             }
         }
         else{
-            SKELETON::MsgDiag mdiag( NULL, "移転しました\n\n板リストを更新しますか？", false, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_YES_NO );
+            SKELETON::MsgDiag mdiag( NULL, "移転しました\n\n板一覧を更新しますか？", false, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_YES_NO );
             mdiag.set_default_response( Gtk::RESPONSE_YES );
             if( mdiag.run() == Gtk::RESPONSE_YES ) CORE::core_set_command( "reload_bbsmenu" );
         }
@@ -1433,6 +1495,9 @@ void BoardBase::read_board_info()
     // samba24
     m_samba_sec = cf.get_option( "samba_sec", 0 );
 
+    // 実況の秒数
+    m_live_sec = cf.get_option( "live_sec", 0 );
+
 #ifdef _DEBUG
     std::cout << "modified = " << date_modified() << std::endl;
 #endif
@@ -1478,7 +1543,7 @@ void BoardBase::save_jdboard_info()
     std::string str_abone_regex_thread = MISC::listtostr( m_list_abone_regex_thread );
     
     std::ostringstream sstr;
-    sstr << "modified = " << date_modified() << std::endl
+    sstr << "modified = " << get_date_modified() << std::endl
          << "modified_localrule = " << m_modified_localrule << std::endl
          << "modified_setting = " << m_modified_setting << std::endl
          << "view_sort_column = " << m_view_sort_column << std::endl
@@ -1508,6 +1573,7 @@ void BoardBase::save_jdboard_info()
          << "write_name = " << m_write_name << std::endl
          << "write_mail = " << m_write_mail << std::endl
          << "samba_sec = " << m_samba_sec << std::endl
+         << "live_sec = " << m_live_sec << std::endl
     ;
 
     CACHE::save_rawdata( path_info, sstr.str() );
@@ -1579,7 +1645,7 @@ void BoardBase::save_board_info()
     // time だけ更新する(他の情報は使わない)
     std::string bookmark = "nil";
     std::string hide = "nil";
-    std::string time = "(time . \"" + date_modified() + "\")";
+    std::string time = "(time . \"" + get_date_modified() + "\")";
     std::string logo = "nil";
 
     // board.info 読み込み
