@@ -123,6 +123,9 @@ namespace DBTREE
         // samba(秒)
         time_t m_samba_sec;
 
+        // 実況時の更新間隔(秒)
+        time_t m_live_sec;
+
         // 最大レス数
         int m_number_max_res;
 
@@ -207,8 +210,8 @@ namespace DBTREE
         // url がこの板のものかどうか
         virtual bool equal( const std::string& url );
 
-        // 移転などで板のルートを変更する
-        void update_root( const std::string& root );
+        // 移転などで板のルートやパスを変更する
+        void update_url( const std::string& root, const std::string& path_board );
 
         const std::string& get_root() const{ return m_root; }
         const std::string& get_path_board() const { return m_path_board; }
@@ -216,6 +219,7 @@ namespace DBTREE
         const std::string& get_id() const { return m_id; }
         const std::string& get_charset() const { return m_charset; }
         const std::string& get_name() const { return m_name; }
+        void update_name( const std::string& name );
         const std::string& get_subjecttxt() const { return m_subjecttxt; }
 
         // ダウンロード、書き込み時のエージェント名やプロキシ
@@ -303,9 +307,9 @@ namespace DBTREE
 
         // article クラスのポインタ取得
         // それぞれの違いはソースのコメントを参照
-        ArticleBase* get_article( const std::string id );
-        ArticleBase* get_article_create( const std::string id );
-        ArticleBase* get_article_fromURL( const std::string url );
+        ArticleBase* get_article( const std::string& id );
+        ArticleBase* get_article_create( const std::string& id );
+        ArticleBase* get_article_fromURL( const std::string& url );
 
         void download_subject();
 
@@ -384,6 +388,10 @@ namespace DBTREE
         void set_samba_sec( time_t sec ){ m_samba_sec = sec; }
         time_t get_write_leftsec(); // 書き込み可能までの残り秒
 
+        // 実況の秒数
+        const time_t get_live_sec() const{ return m_live_sec; }
+        void set_live_sec( time_t sec ){ m_live_sec = sec; }
+
         // 最大レス数
         const int get_number_max_res() const{ return m_number_max_res; }
         void set_number_max_res( const int number ){ m_number_max_res = number; }
