@@ -19,7 +19,8 @@
 using namespace CORE;
 
 FontColorPref::FontColorPref( Gtk::Window* parent, const std::string& url )
-    : SKELETON::PrefDiag( parent, url )
+    : SKELETON::PrefDiag( parent, url ),
+      m_reset_colorbutton( "全てリセット(_R)", true )
 {
     CONFIG::bkup_conf();
 
@@ -38,7 +39,6 @@ FontColorPref::FontColorPref( Gtk::Window* parent, const std::string& url )
     set_color_settings( "文字: メール欄(非sage)", COLOR_CHAR_AGE, "sage でないメール欄の文字色" );
     set_color_settings( "文字: 選択範囲", COLOR_CHAR_SELECTION, "選択範囲の文字色" );
     set_color_settings( "文字: ハイライト", COLOR_CHAR_HIGHLIGHT, "検索結果などのハイライトの文字色" );
-    set_color_settings( "文字: しおり", COLOR_CHAR_BOOKMARK, "レスのしおりの文字色" );
     set_color_settings( "文字: リンク(通常)", COLOR_CHAR_LINK, "通常のリンクや参照されていないレス番号、複数発言したIDの文字色" );
     set_color_settings( "文字: リンク(参照)", COLOR_CHAR_LINK_LOW, "他のレスから参照されたレス番号の文字色" );
     set_color_settings( "文字: リンク(多数)", COLOR_CHAR_LINK_HIGH, "参照された数が多いレス番号や多く発言したIDの文字色" );
@@ -49,6 +49,7 @@ FontColorPref::FontColorPref( Gtk::Window* parent, const std::string& url )
     set_color_settings( "文字: 画像(ロード中)", COLOR_IMG_LOADING, "画像として扱うリンクのうち、ロード中の物の文字色" );
     set_color_settings( "文字: 画像(エラー)", COLOR_IMG_ERR, "画像として扱うリンクのうち、エラーになっている物の文字色" );
     set_color_settings( "文字: 板一覧／お気に入り", COLOR_CHAR_BBS, "板一覧／お気に入りの文字色" );
+    set_color_settings( "文字: 板一覧のコメント", COLOR_CHAR_BBS_COMMENT, "板一覧のコメントの文字色" );
     set_color_settings( "文字: スレ一覧", COLOR_CHAR_BOARD, "スレ一覧の文字色" );
     set_color_settings( "特殊: 新着しおり", COLOR_SEPARATOR_NEW, "新着しおりの色" );
     set_color_settings( "特殊: ポップアップフレーム", COLOR_FRAME, "ポップアップのフレーム色" );
@@ -153,6 +154,7 @@ void FontColorPref::pack_widget()
     m_hbox_color.set_border_width( mrg );
     m_hbox_color.pack_start( m_event_color, Gtk::PACK_SHRINK );
     m_hbox_color.pack_start( m_colorbutton, Gtk::PACK_SHRINK, mrg );
+    m_hbox_color.pack_start( m_reset_colorbutton, Gtk::PACK_SHRINK, mrg );
 
     m_vbox_color.pack_start( m_hbox_color, Gtk::PACK_EXPAND_WIDGET, mrg );
 
@@ -163,6 +165,7 @@ void FontColorPref::pack_widget()
 
     m_combo_color.signal_changed().connect( sigc::mem_fun( *this, &FontColorPref::slot_combo_color_changed ) );
     m_colorbutton.signal_color_set().connect( sigc::mem_fun( *this, &FontColorPref::slot_colorbutton_on_set ) );
+    m_reset_colorbutton.signal_clicked().connect( sigc::mem_fun( *this, &FontColorPref::slot_reset_color ) );
 
     // 全体
     get_vbox()->set_spacing( mrg );
@@ -301,3 +304,12 @@ void FontColorPref::slot_colorbutton_on_set()
     CONFIG::set_color( m_color_tbl[ num ] , result );
 }
 
+
+//
+// 色のリセット
+//
+void FontColorPref::slot_reset_color()
+{
+    CONFIG::reset_colors();
+    slot_combo_color_changed();
+}
