@@ -83,39 +83,39 @@ ImageAdmin::~ImageAdmin()
 
 
 // 前回開いていたURLを復元
-void ImageAdmin::restore()
+void ImageAdmin::restore( const bool only_locked )
 {
 #ifdef _DEBUG
     std::cout << "ImageAdmin::restore\n";
 #endif
 
+    int set_page_num = 0;
+
     std::list< std::string > list_url = SESSION::image_URLs();
     std::list< std::string >::iterator it_url= list_url.begin();
 
     std::list< bool > list_locked = SESSION::get_image_locked();
     std::list< bool >::iterator it_locked = list_locked.begin();
 
-    for( ; it_url != list_url.end(); ++it_url ){
-
-        COMMAND_ARGS command_arg;
-        command_arg.command = "open_view";
+    for( int page = 0; it_url != list_url.end(); ++it_url, ++page ){
 
         // タブのロック状態
-        std::string lock;
+        bool lock = false;
         if( it_locked != list_locked.end() ){
-            if( (*it_locked ) ) lock = "lock";
+            if( (*it_locked ) ) lock = true;
             ++it_locked;
         }
 
-        if( !(*it_url).empty() ){
-            command_arg.url = (*it_url);
-            command_arg.arg3 = lock;
+        // ロックされているものだけ表示
+        if( only_locked && ! lock ) continue;
 
-            open_view( command_arg );
-        }
+        if( page == SESSION::image_page() ) set_page_num = get_tab_nums();
+
+        COMMAND_ARGS command_arg = url_to_openarg( *it_url, true, lock );
+        if( ! command_arg.url.empty() ) open_view( command_arg );        
     }
 
-    SKELETON::View* view = get_nth_icon( SESSION::image_page() );
+    SKELETON::View* view = get_nth_icon( set_page_num );
     if( view ){
         switch_img( view->get_url() );
         switch_admin();
@@ -123,6 +123,18 @@ void ImageAdmin::restore()
 }
 
 
+COMMAND_ARGS ImageAdmin::url_to_openarg( const std::string& url, const bool tab, const bool lock )
+{
+    COMMAND_ARGS command_arg;
+    command_arg.command = "open_view";
+    command_arg.url = url;
+    if( lock ) command_arg.arg3 = "lock";
+
+    return command_arg;
+}
+
+
+
 void ImageAdmin::switch_admin()
 {
     if( ! has_focus() ) CORE::core_set_command( "switch_image" );
