@@ -5,6 +5,7 @@
 
 #include <string>
 #include <vector>
+#include <regex.h>
 
 namespace JDLIB
 {
@@ -12,14 +13,21 @@ namespace JDLIB
     {
         std::vector< int > m_pos;
         std::vector< std::string > m_results;
+        regex_t m_reg;
+        bool m_compiled;
 
     public:
 
         Regex();
         ~Regex();
 
+        void dispose();
+        
         // icase : true なら大小無視
         // newline : true なら . に改行をマッチさせない
+        bool compile( const std::string reg
+                   , bool icase = false, bool newline = true, bool usemigemo = false );
+        bool exec( const std::string& target, unsigned int offset = 0 );
         bool exec( const std::string reg, const std::string& target, unsigned int offset = 0
                    , bool icase = false, bool newline = true, bool usemigemo = false );
         const int pos( unsigned int num );
