@@ -27,8 +27,14 @@ using namespace MESSAGE;
     setup_view();
     set_message( msg );
 
-    // タイトルセット
+    // ツールバーのスレタイトルを編集不可にする
+    MESSAGE::get_admin()->show_entry_new_subject( false );
+
+    // メインウィンドウのタイトルに表示する文字
     set_title( "[ 書き込み ] " + DBTREE::article_subject( get_url() ) );
+
+    // ツールバーにスレ名を表示
+    set_label( DBTREE::article_subject( get_url() ) );
 }
 
 
@@ -43,7 +49,7 @@ MessageViewMain::~MessageViewMain()
 //
 std::string MessageViewMain::create_message()
 {
-    const std::string msg = get_text_message().get_text();
+    const Glib::ustring msg = get_text_message().get_text();
     const std::string name = get_entry_name().get_text();
     const std::string mail = get_entry_mail().get_text();
 
@@ -52,7 +58,41 @@ std::string MessageViewMain::create_message()
         mdiag.run();
         return std::string();
     }
+/*    else
+    {
+        // 終端スペース/改行チェック
+        const size_t end_pos = msg.find_last_not_of( "　 \n" );
+        const size_t msg_length = msg.length();
 
+        // 最後がスペース/改行である
+        if( end_pos != msg_length - 1 )
+        {
+            SKELETON::MsgDiag mdiag( MESSAGE::get_admin()->get_win(),
+                                     "メッセージがスペースまたは改行で終わっています。\n\n"
+                                     "このまま書き込みますか？ (または、改行等を削除)",
+                                     false, Gtk::MESSAGE_WARNING, Gtk::BUTTONS_NONE );
+
+            mdiag.set_title( "確認" );
+            mdiag.add_button( Gtk::Stock::CANCEL, Gtk::RESPONSE_CANCEL );
+            mdiag.add_button( Gtk::Stock::REMOVE, Gtk::RESPONSE_DELETE_EVENT );
+            mdiag.add_button( Gtk::Stock::YES, Gtk::RESPONSE_YES );
+
+            switch( mdiag.run() )
+            {
+                // スペース/改行を取り除いた物に置き換える(書き込まない)
+                case Gtk::RESPONSE_DELETE_EVENT:
+
+                    get_text_message().set_text( msg.substr( 0, end_pos + 1 ) );
+                    return std::string();
+
+                // キャンセル
+                case Gtk::RESPONSE_CANCEL:
+
+                    return std::string();
+            }
+        }
+    }
+*/
     // 誤爆を警告
     if( SESSION::get_article_current_url().find( get_url() ) == std::string::npos ){
 
@@ -82,7 +122,7 @@ std::string MessageViewMain::create_message()
 //
 // 書き込みが終わったら MessageViewBase::post_fin()が呼ばれる
 //
-void MessageViewMain::write()
+void MessageViewMain::write_impl()
 {
     std::string msg = create_message();
     if( msg.empty() ) return;
@@ -107,13 +147,10 @@ void MessageViewMain::reload()
 
     set_message( msg );
 
-    if( get_entry_subject() ){
-        get_entry_subject()->set_editable( true );
-        get_entry_subject()->set_text( std::string() );
-        get_entry_subject()->grab_focus();
-    }
+    // ツールバーのスレタイトルを編集可能にする
+    MESSAGE::get_admin()->show_entry_new_subject( true );
 
-    // タイトルセット
+    // メインウィンドウのタイトルに表示する文字
     set_title( "[ 新スレ作成 ] " + DBTREE::article_subject( get_url() ) );
 }
 
@@ -125,8 +162,7 @@ void MessageViewMain::reload()
 //
 std::string MessageViewNew::create_message()
 {
-    std::string subject;
-    if( get_entry_subject() ) subject = get_entry_subject()->get_text();
+    std::string subject = MESSAGE::get_admin()->get_new_subject();
     std::string msg = get_text_message().get_text();
     std::string name = get_entry_name().get_text();
     std::string mail = get_entry_mail().get_text();
@@ -154,7 +190,7 @@ std::string MessageViewNew::create_message()
 //
 // 書き込みが終わったら MessageViewBase::post_fin()が呼ばれる
 //
-void MessageViewNew::write()
+void MessageViewNew::write_impl()
 {
     std::string msg = create_message();
     if( msg.empty() ) return;
