@@ -7,9 +7,10 @@
 #include "messageadmin.h"
 #include "messageviewbase.h"
 #include "post.h"
-#include "toolbar.h"
+#include "logmanager.h"
 
 #include "skeleton/msgdiag.h"
+#include "skeleton/label_entry.h"
 
 #include "jdlib/miscutil.h"
 #include "jdlib/misctime.h"
@@ -20,10 +21,7 @@
 
 #include "config/globalconf.h"
 
-#include "icons/iconmanager.h"
-
 #include "httpcode.h"
-#include "command.h"
 #include "viewfactory.h"
 #include "controlutil.h"
 #include "controlid.h"
@@ -32,6 +30,7 @@
 #include "session.h"
 #include "colorid.h"
 #include "global.h"
+#include "compmanager.h"
 
 #include <sstream>
 #include <sys/time.h>
@@ -61,7 +60,6 @@ MessageViewBase::MessageViewBase( const std::string& url )
     : SKELETON::View( url ),
       m_post( 0 ),
       m_preview( 0 ),
-      m_enable_menuslot( true ),
       m_enable_focus( true ),
       m_counter( 0 )
 {
@@ -81,6 +79,9 @@ MessageViewBase::MessageViewBase( const std::string& url )
     if( ! m_lng_iconv ) m_lng_iconv = MAX_STR_ICONV;
 
     m_str_iconv = ( char* ) malloc( m_lng_iconv + 1024 );
+
+    if( SESSION::get_close_mes() ) unlock();
+    else lock();
 }
 
 
@@ -88,13 +89,23 @@ MessageViewBase::MessageViewBase( const std::string& url )
 MessageViewBase::~MessageViewBase()
 {
 #ifdef _DEBUG
-    std::cout << "MessageViewBase::~MessageViewBase " << get_url() << std::endl;
+    std::cout << "MessageViewBase::~MessageViewBase " << get_url() << std::endl
+              << "lock = " << is_locked() << std::endl;
 #endif
 
+    // 名前、メール履歴保存
+    std::string name = m_entry_name.get_text();
+    std::string mail = m_entry_mail.get_text();
+    CORE::get_completion_manager()->set_query( CORE::COMP_NAME, name );
+    CORE::get_completion_manager()->set_query( CORE::COMP_MAIL, mail );
+
     if( m_preview ) delete m_preview;
     m_preview = NULL;
 
-    if( m_post ) delete m_post;
+    if( m_post ){
+        m_post->terminate_load();
+        delete m_post;
+    }
     m_post = NULL;
 
     if( m_iconv ) delete m_iconv;
@@ -102,19 +113,14 @@ MessageViewBase::~MessageViewBase()
 
     if( m_str_iconv ) free( m_str_iconv );
     m_str_iconv = NULL;
+
+    SESSION::set_close_mes( ! is_locked() );
 }
 
 
-MessageToolBar* MessageViewBase::get_messagetoolbar()
+SKELETON::Admin* MessageViewBase::get_admin()
 {
-    return dynamic_cast< MessageToolBar* >( get_toolbar() );
-}
-
-
-SKELETON::LabelEntry* MessageViewBase::get_entry_subject()
-{
-    if( ! get_messagetoolbar() ) return NULL;
-    return &get_messagetoolbar()->m_entry_subject;
+    return MESSAGE::get_admin();
 }
 
 
@@ -190,6 +196,18 @@ void MessageViewBase::init_color()
 
 
 
+//
+// ロード中
+//
+// virtual
+const bool MessageViewBase::is_loading()
+{
+    if( ! m_post ) return false;
+
+    return m_post->is_loading();
+}
+
+
 //
 // コマンド
 //
@@ -197,15 +215,12 @@ bool MessageViewBase::set_command( const std::string& command, const std::string
 {
     if( command == "empty" ) return get_message().empty();
 
-    else if( command == "loading" ){
-        if( !m_post ) return false;
-        return m_post->is_loading();
-    }
+    else if( command == "toggle_preview" ) toggle_preview();
+    else if( command == "undo_text" ) m_text_message.undo();
+    else if( command == "insert_draft" ) insert_draft();
 
-    else if( command == "exec_Write" ) slot_write_clicked();
     else if( command == "tab_left" ) tab_left();
     else if( command == "tab_right" ) tab_right();
-    else if( command == "focus_write" ) focus_writebutton();
 
     // メッセージをクリア
     else if( command == "clear_message" ){
@@ -299,23 +314,6 @@ void MessageViewBase::save_name()
 //
 void MessageViewBase::pack_widget()
 {
-    // ツールバー
-    set_toolbar( Gtk::manage( new MessageToolBar( DBTREE::board_name( get_url() ) ) ) );
-    get_messagetoolbar()->m_entry_subject.set_text( DBTREE::article_subject( get_url() ) );
-    get_messagetoolbar()->m_button_not_close.set_active( ! SESSION::get_close_mes() );
-
-    get_messagetoolbar()->m_button_write.signal_clicked().connect( sigc::mem_fun( *this, &MessageViewBase::slot_write_clicked ) );
-    get_messagetoolbar()->get_close_button().signal_clicked().connect( sigc::mem_fun( *this, &MessageViewBase::slot_close_clicked ) );
-    get_messagetoolbar()->m_button_open.signal_clicked().connect( sigc::mem_fun( *this, &MessageViewBase::slot_draft_open ) );
-    get_messagetoolbar()->m_button_undo.signal_clicked().connect( sigc::mem_fun( *this, &MessageViewBase::slot_undo_clicked ) );
-    get_messagetoolbar()->m_button_not_close.signal_clicked().connect( sigc::mem_fun( *this, &MessageViewBase::slot_not_close_clicked ) );
-    get_messagetoolbar()->m_button_preview.signal_clicked().connect( sigc::mem_fun( *this, &MessageViewBase::slot_preview_clicked ) );
-    
-    get_messagetoolbar()->show_toolbar();
-
-    if( SESSION::get_close_mes() ) get_messagetoolbar()->get_close_button().set_sensitive( true );
-    else get_messagetoolbar()->get_close_button().set_sensitive( false );
-
     // 書き込みビュー
     m_label_name.set_alignment( Gtk::ALIGN_LEFT, Gtk::ALIGN_CENTER );
     m_label_mail.set_alignment( Gtk::ALIGN_LEFT, Gtk::ALIGN_CENTER );
@@ -353,14 +351,27 @@ void MessageViewBase::pack_widget()
     }
     else m_entry_mail.set_text( "sage" );
 
-    m_hbox_name_mail.pack_start( m_label_name, Gtk::PACK_SHRINK );
-    m_hbox_name_mail.pack_start( m_check_fixname, Gtk::PACK_SHRINK );
-    m_hbox_name_mail.pack_start( m_entry_name );
-    m_hbox_name_mail.pack_start( m_label_mail, Gtk::PACK_SHRINK );
-    m_hbox_name_mail.pack_start( m_check_fixmail, Gtk::PACK_SHRINK );
-    m_hbox_name_mail.pack_start( m_entry_mail );
+    m_tool_name.add( m_label_name );
+    m_tool_mail.add( m_label_mail );
+    m_tool_fixname.add( m_check_fixname );
+    m_tool_fixmail.add( m_check_fixmail );
+    m_tool_entry_name.add( m_entry_name );
+    m_tool_entry_mail.add( m_entry_mail );
+    m_tool_entry_name.set_expand( true );
+    m_tool_entry_mail.set_expand( true );
 
-    m_msgview.pack_start( m_hbox_name_mail, Gtk::PACK_SHRINK );    
+#if GTKMMVER >= 2120
+    m_toolbar_name_mail.set_icon_size( Gtk::ICON_SIZE_MENU );
+#endif
+    m_toolbar_name_mail.set_toolbar_style( Gtk::TOOLBAR_ICONS );
+    m_toolbar_name_mail.append( m_tool_name );
+    m_toolbar_name_mail.append( m_tool_fixname );
+    m_toolbar_name_mail.append( m_tool_entry_name );
+    m_toolbar_name_mail.append( m_tool_mail );
+    m_toolbar_name_mail.append( m_tool_fixmail );
+    m_toolbar_name_mail.append( m_tool_entry_mail );
+
+    m_msgview.pack_start( m_toolbar_name_mail, Gtk::PACK_SHRINK );    
     m_msgview.pack_start( m_text_message );
 
     m_text_message.set_accepts_tab( false );
@@ -372,13 +383,14 @@ void MessageViewBase::pack_widget()
     m_preview = CORE::ViewFactory( CORE::VIEW_ARTICLEPREVIEW, get_url() );
 
     m_notebook.set_show_tabs( false );
+    m_notebook.set_show_border( false );
     m_notebook.append_page( m_msgview, "メッセージ" );
     m_notebook.append_page( *m_preview, "プレビュー" );
     m_notebook.signal_switch_page().connect( sigc::mem_fun( *this, &MessageViewBase::slot_switch_page ) );
     m_notebook.set_current_page( PAGE_MESSAGE );
 
-    pack_start( *get_messagetoolbar(), Gtk::PACK_SHRINK );
     pack_start( m_notebook );
+    set_size_request( 1, 1 );
 
     // フォントセット
     init_font( CONFIG::get_fontname( FONT_MESSAGE ) );
@@ -404,7 +416,7 @@ void MessageViewBase::redraw_view()
 void MessageViewBase::focus_view()
 {
 #ifdef _DEBUG
-    std::cout << "MessageViewBase::focus_view page = " << m_notebook.get_current_page() << std::endl;
+//    std::cout << "MessageViewBase::focus_view page = " << m_notebook.get_current_page() << std::endl;
 #endif
 
     if( m_notebook.get_current_page() == PAGE_MESSAGE ) m_text_message.focus_view();
@@ -428,7 +440,7 @@ void MessageViewBase::operate_view( const int& control )
 
             // 書き込み実行
         case CONTROL::ExecWrite:
-            MESSAGE::get_admin()->set_command( "exec_Write" );
+            MESSAGE::get_admin()->set_command( "toolbar_write", get_url() );
             break;
 
         case CONTROL::TabLeft:
@@ -441,7 +453,7 @@ void MessageViewBase::operate_view( const int& control )
 
             // 書き込みボタンにフォーカスを移す
         case CONTROL::FocusWrite:
-            focus_writebutton();
+            MESSAGE::get_admin()->set_command( "focus_writebutton" );
             break;
     }
 }
@@ -449,10 +461,14 @@ void MessageViewBase::operate_view( const int& control )
 
 
 //
-// 書き込むボタン押した
+// 書き込み実行
 //
-void MessageViewBase::slot_write_clicked()
+void MessageViewBase::write()
 {
+#ifdef _DEBUG
+    std::cout << "MessageViewBase::write\n";
+#endif
+
     time_t left = DBTREE::board_write_leftsec( get_url() );
     if( left ){
         SKELETON::MsgDiag mdiag( MESSAGE::get_admin()->get_win(), "書き込み規制中です ( 残り " + MISC::itostr( left ) + " 秒 )\n\nもう暫くお待ち下さい。規制秒数が短くなった場合は板のプロパティからリセットできます。" );
@@ -501,14 +517,14 @@ void MessageViewBase::slot_write_clicked()
         }
     }
 
-    write();
+    write_impl();
 }
 
 
 //
-// ファイル挿入
+// 下書きファイル挿入
 //
-void MessageViewBase::slot_draft_open()
+void MessageViewBase::insert_draft()
 {
     std::string open_path = CACHE::open_load_diag( MESSAGE::get_admin()->get_win(), SESSION::get_dir_draft(), CACHE::FILE_TYPE_TEXT );
 
@@ -524,51 +540,12 @@ void MessageViewBase::slot_draft_open()
 
 
 //
-// closeボタンを押した
+// プレビュー切り替え
 //
-void MessageViewBase::slot_close_clicked()
+void MessageViewBase::toggle_preview()
 {
-    if( !SESSION::get_close_mes() ){
-        SKELETON::MsgDiag mdiag( MESSAGE::get_admin()->get_win(), "「ビューを閉じない」ボタンが押されています。" );
-        mdiag.run();
-    }
-    else close_view();
-}
-
-
-//
-// undoボタンを押した
-//
-void MessageViewBase::slot_undo_clicked()
-{
-    m_text_message.undo();
-}
-
-
-//
-// ビューを閉じないボタンを押した
-//
-void MessageViewBase::slot_not_close_clicked()
-{
-    if( ! m_enable_menuslot ) return;
-    if( ! get_messagetoolbar() ) return;
-
-    SESSION::set_close_mes( ! SESSION::get_close_mes() );
-
-    if( SESSION::get_close_mes() ) get_messagetoolbar()->get_close_button().set_sensitive( true );
-    else get_messagetoolbar()->get_close_button().set_sensitive( false );
-}
-
-
-//
-// プレビューボタンを押した
-//
-void MessageViewBase::slot_preview_clicked()
-{
-    if( ! m_enable_menuslot ) return;
-
 #ifdef _DEBUG
-    std::cout << "MessageViewBase::slot_preview_clicked page = " << m_notebook.get_current_page() << std::endl;
+    std::cout << "MessageViewBase::toggle_preview page = " << m_notebook.get_current_page() << std::endl;
 #endif
 
     if( m_notebook.get_current_page() == PAGE_MESSAGE ) tab_right();
@@ -639,7 +616,6 @@ void MessageViewBase::close_view()
 }
 
 
-
 //
 // タブ左移動
 //
@@ -674,26 +650,26 @@ void MessageViewBase::tab_right()
 }
 
 
-
-//
-// 書き込みボタンをフォーカス
-//
-void MessageViewBase::focus_writebutton()
-{
-    if( ! get_messagetoolbar() ) return;
-    get_messagetoolbar()->m_button_write.grab_focus();
-}
-
-
 //
 // 書き込み
 //
 void MessageViewBase::post_msg( const std::string& msg, bool new_article )
 {
-    if( m_post ) delete m_post;
+    push_logitem();
+
+    if( m_post ){
+        m_post->terminate_load();
+        delete m_post;
+    }
     m_post = new Post( this, get_url(),  msg, new_article );
     m_post->sig_fin().connect( sigc::mem_fun( *this, &MessageViewBase::post_fin ) );
     m_post->post_msg();
+
+    // 名前、メール履歴保存
+    std::string name = m_entry_name.get_text();
+    std::string mail = m_entry_mail.get_text();
+    CORE::get_completion_manager()->set_query( CORE::COMP_NAME, name );
+    CORE::get_completion_manager()->set_query( CORE::COMP_MAIL, mail );
 }
 
 
@@ -721,7 +697,7 @@ void MessageViewBase::post_fin()
 
         close_view();
 
-        reload();
+        if( ! SESSION::is_live( get_url() ) ) reload();
     }
 
     // タイムアウト
@@ -751,19 +727,18 @@ void MessageViewBase::slot_switch_page( GtkNotebookPage*, guint page )
     std::cout << "MessageViewBase::slot_switch_page : " << get_url() << " page = " << page << std::endl;
 #endif
 
-    // toggle　アクションを activeにするとスロット関数が呼ばれるので処理しないようにする
-    m_enable_menuslot = false;
-
     // プレビュー表示
-    if( get_messagetoolbar() && m_preview && page == PAGE_PREVIEW ){
+    if( m_preview && page == PAGE_PREVIEW ){
 
-        // 各ボタンの状態更新
-        get_messagetoolbar()->m_button_undo.set_sensitive( false );
-        get_messagetoolbar()->m_button_open.set_sensitive( false );
-        get_messagetoolbar()->m_button_preview.set_active( true );
+        // ツールバー切り替え
+        MESSAGE::get_admin()->set_command( "switch_toolbar_preview" );
+
+        std::string new_subject = MESSAGE::get_admin()->get_new_subject();
+        if( ! new_subject.empty() ) set_label( new_subject );
 
         // URLを除外してエスケープ
-        std::string msg = MISC::html_escape( m_text_message.get_text(), false );
+        const bool include_url = false;
+        std::string msg = MISC::html_escape( m_text_message.get_text(), include_url );
         msg = MISC::replace_str( msg, "\n", " <br> " );
         
         std::stringstream ss;
@@ -807,20 +782,16 @@ void MessageViewBase::slot_switch_page( GtkNotebookPage*, guint page )
     }
 
     // メッセージビュー
-    else if( get_messagetoolbar() && page == PAGE_MESSAGE ){
+    else if( page == PAGE_MESSAGE ){
 
-        // 各ボタンの状態更新
-        get_messagetoolbar()->m_button_undo.set_sensitive( true );
-        get_messagetoolbar()->m_button_open.set_sensitive( true );
-        get_messagetoolbar()->m_button_preview.set_active( false );
+        // ツールバー切り替え
+        MESSAGE::get_admin()->set_command( "switch_toolbar_message" );
     }
 
     if( m_enable_focus ){
         MESSAGE::get_admin()->set_command( "switch_admin" );
         MESSAGE::get_admin()->set_command( "focus_current_view" );
     }
-
-    m_enable_menuslot = true;
 }
 
 
@@ -855,34 +826,31 @@ void MessageViewBase::show_status()
 }
 
 
+//
+// 自分の書き込みの判定用データの保存
+//
+// 実況中など post_fin() がコールされる前に自分のスレが表示されてしまう時があるので
+//  m_post->post_msg() する前に情報を保存しておく
+//
+void MessageViewBase::push_logitem()
+{
+    const bool newthread = ! ( MESSAGE::get_admin()->get_new_subject().empty() );
+    const std::string msg = get_text_message().get_text();
 
+    MESSAGE::get_log_manager()->push_logitem( get_url(), newthread, msg );
+}
+
+
+//
 // 書き込みログ保存
+//
 void MessageViewBase::save_postlog()
 {
-    if( ! CONFIG::get_save_postlog() ) return;
+    std::string subject = MESSAGE::get_admin()->get_new_subject();
+    if( subject.empty() ) subject = DBTREE::article_subject( get_url() );
+    const std::string msg = get_text_message().get_text();
+    const std::string name = get_entry_name().get_text();
+    const std::string mail = get_entry_mail().get_text();
 
-    std::string subject;
-    if( get_entry_subject() ) subject = get_entry_subject()->get_text();
-    std::string msg = get_text_message().get_text();
-    std::string name = get_entry_name().get_text();
-    std::string mail = get_entry_mail().get_text();
-
-    struct timeval tv;
-    struct timezone tz;
-    gettimeofday( &tv, &tz );
-    std::string date = MISC::timettostr( tv.tv_sec );
-
-    std::stringstream ss;
-    ss << "---------------" << std::endl
-       << get_url() << std::endl
-       << "[ " << DBTREE::board_name( get_url() ) << " ] " << subject << std::endl
-       << "名前：" << name << " [" << mail << "]：" << date << std::endl
-       << msg << std::endl;
-
-#ifdef _DEBUG
-    std::cout << ss.str() << std::endl;
-#endif 
-
-
-    CACHE::save_rawdata( CACHE::path_postlog(), ss.str(), true );
+    MESSAGE::get_log_manager()->save( get_url(), subject, msg, name, mail );
 }
