@@ -23,6 +23,8 @@ namespace CORE
         PREFDIAG_GLOBALABONETHREAD,
         PREFDIAG_GLOBALABONE,
         PREFDIAG_FONTCOLOR,
+        PREFDIAG_LIVE,
+
         PREFDIAG_MAINITEM,
         PREFDIAG_SIDEBARITEM,
         PREFDIAG_BOARDITEM,
@@ -36,6 +38,8 @@ namespace CORE
         PREFDIAG_ARTICLE,
         PREFDIAG_IMAGE,
 
+        PREFDIAG_ABOUTCONFIG,
+
         PREFDIAG_NONE
     };
     
