@@ -7,6 +7,10 @@
 #include "cache.h"
 #include "global.h"
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include "jdlib/confloader.h"
 #include "jdlib/miscutil.h"
 
@@ -14,6 +18,12 @@
 #include "article/articleadmin.h"
 
 #include <sstream>
+#include <cstring>
+#include <vector>
+
+#ifdef HAVE_SYS_UTSNAME_H
+#include <sys/utsname.h> // uname()
+#endif
 
 bool booting = true;
 bool quitting = false;
@@ -23,7 +33,7 @@ bool mode_online;
 bool mode_login2ch;
 bool mode_loginbe;
 
-std::string distribution;
+std::string distribution_name;
 
 int win_manager;
 
@@ -138,6 +148,9 @@ std::string dir_draft;
 
 bool popupmenu_shown;
 
+std::vector< std::string > delete_list;
+
+std::vector< std::string > live_urls;
 
 
 /////////////////////////////////////
@@ -178,6 +191,10 @@ std::vector< int > parse_items( const std::string& items_str )
         if( *it == ITEM_NAME_FAVORITE ) items.push_back( ITEM_FAVORITE );
         if( *it == ITEM_NAME_DELETE ) items.push_back( ITEM_DELETE );
         if( *it == ITEM_NAME_QUIT ) items.push_back( ITEM_QUIT );
+        if( *it == ITEM_NAME_PREVVIEW ) items.push_back( ITEM_PREVVIEW );
+        if( *it == ITEM_NAME_NEXTVIEW ) items.push_back( ITEM_NEXTVIEW );
+        if( *it == ITEM_NAME_LOCK ) items.push_back( ITEM_LOCK );
+        if( *it == ITEM_NAME_LIVE ) items.push_back( ITEM_LIVE );
 
         if( *it == ITEM_NAME_NEWARTICLE ) items.push_back( ITEM_NEWARTICLE );
         if( *it == ITEM_NAME_SEARCHBOX ) items.push_back( ITEM_SEARCHBOX );
@@ -185,7 +202,7 @@ std::vector< int > parse_items( const std::string& items_str )
         if( *it == ITEM_NAME_SEARCH_PREV ) items.push_back( ITEM_SEARCH_PREV );
 
         if( *it == ITEM_NAME_INSERTTEXT ) items.push_back( ITEM_INSERTTEXT );
-        if( *it == ITEM_NAME_NOTCLOSE ) items.push_back( ITEM_NOTCLOSE );
+        if( *it == ITEM_NAME_LOCK_MESSAGE ) items.push_back( ITEM_LOCK_MESSAGE );
         if( *it == ITEM_NAME_PREVIEW ) items.push_back( ITEM_PREVIEW );
         if( *it == ITEM_NAME_UNDO ) items.push_back( ITEM_UNDO );
     }
@@ -221,6 +238,153 @@ void read_list_urls( JDLIB::ConfLoader& cf, const std::string& id_urls, const st
 }
 
 
+// ファイル等からディストリ名を取得
+std::string get_distribution_name_from_environment()
+{
+#ifdef _DEBUG
+    std::cout << "SESSION::get_distribution_name_from_environment\n";
+#endif
+
+    std::string tmp;
+    std::string text_data;
+
+    // LSB系 ( Ubuntu ..etc )
+    if( CACHE::load_rawdata( "/etc/lsb-release", text_data ) )
+    {
+        std::list< std::string > lines = MISC::get_lines( text_data );
+        std::list< std::string >::reverse_iterator it = lines.rbegin();
+        while( it != lines.rend() )
+        {
+            std::string lsb_name, lsb_data;
+
+            size_t e;
+            if( ( e = (*it).find( "=" ) ) != std::string::npos )
+            {
+                lsb_name = MISC::remove_spaces( (*it).substr( 0, e ) );
+                lsb_data = MISC::remove_spaces( (*it).substr( e + 1 ) );
+            }
+
+            // 「DISTRIB_DESCRIPTION="Ubuntu 7.10"」などから「Ubuntu 7.10」を取得
+            if( lsb_name == "DISTRIB_DESCRIPTION" && ! lsb_data.empty() )
+            {
+                tmp = MISC::cut_str( lsb_data, "\"", "\"" );
+                break;
+            }
+
+            ++it;
+        }
+    }
+    // KNOPPIX (LSB？)
+    else if( CACHE::load_rawdata( "/etc/knoppix-version", text_data ) )
+    {
+        tmp = "KNOPPIX ";
+        tmp.append( text_data );
+    }
+    // Debian
+    else if( CACHE::load_rawdata( "/etc/debian_version", text_data ) )
+    {
+        tmp = "Debian GNU/Linux ";
+        tmp.append( text_data );
+    }
+    // Solaris系
+    else if( CACHE::load_rawdata( "/etc/release", text_data ) )
+    {
+        std::list< std::string > lines = MISC::get_lines( text_data );
+        std::list< std::string >::iterator it = lines.begin();
+        while( it != lines.end() )
+        {
+            // 名前が含まれている行を取得
+            if( (*it).find( "BeleniX" ) != std::string::npos
+                || (*it).find( "Nexenta" ) != std::string::npos
+                || (*it).find( "SchilliX" ) != std::string::npos
+                || (*it).find( "Solaris" ) != std::string::npos )
+            {
+                tmp = *it;
+                break;
+            }
+
+            ++it;
+        }
+    }
+    // ファイルの中身がそのままディストリ名として扱える物
+    else
+    {
+        // ディストリ名が書かれているファイル
+        std::string dist_files[] =
+        {
+            "/etc/arch-release",
+            "/etc/fedora-release",
+            "/etc/gentoo-release",
+            "/etc/lfs-release",
+            "/etc/mandriva-release",
+            "/etc/momonga-release",
+            "/usr/lib/setup/plamo-version",
+            "/etc/puppyversion",
+            "/etc/redhat-release", // Redhat, CentOS, WhiteBox, PCLinuxOS
+            "/etc/sabayon-release",
+            "/etc/slackware-version",
+            "/etc/SuSE-release",
+            "/etc/turbolinux-release",
+            "/etc/vine-release",
+            "/etc/zenwalk-version"
+        };
+
+        unsigned int i;
+        for( i = 0; i < sizeof( dist_files ) / sizeof( std::string ); ++i )
+        {
+            if( CACHE::load_rawdata( dist_files[i], text_data ) )
+            {
+                tmp = text_data;
+                break;
+            }
+        }
+    }
+
+    // 文字列両端のスペースなどを削除する
+    std::string dist_name = MISC::remove_spaces( tmp );
+
+    // 取得した文字が異常に長い場合は空にする
+    if( dist_name.length() > 50 ) dist_name.clear();
+
+#ifdef HAVE_SYS_UTSNAME_H
+
+    char *sysname = 0, *release = 0, *machine = 0;
+
+    // システムコール uname() 準拠：SVr4, POSIX.1-2001.
+    struct utsname* uts;
+    uts = (struct utsname*)malloc( sizeof( struct utsname ) );
+    if( uname( uts ) != -1 )
+    {
+        sysname = uts->sysname;
+        release = uts->release;
+        machine = uts->machine;
+    }
+
+    // FreeBSD等やディストリ名が取得できなかった場合は"$ uname -rs"と同じ様式
+    if( dist_name.empty() && sysname && release )
+    {
+        dist_name = std::string( sysname ) + " " + std::string( release );
+    }
+
+    // アーキテクチャがx86でない場合
+    if( machine &&
+        ( strlen( machine ) != 4
+          || ! ( machine[0] == 'i'
+               && machine[1] >= '3' && machine[1] <= '6'
+               && machine[2] == '8' && machine[3] == '6' ) ) )
+    {
+        dist_name.append( " (" + std::string( machine ) + ")" );
+    }
+
+    free( uts );
+    uts = NULL;
+
+#endif
+
+    return dist_name;
+}
+
+
 // セッション情報読み込み
 void SESSION::init_session()
 {
@@ -344,7 +508,7 @@ void SESSION::init_session()
                                  ITEM_NAME_NAME + std::string ( " " ) +
                                  ITEM_NAME_UNDO + std::string ( " " ) +
                                  ITEM_NAME_INSERTTEXT + std::string ( " " ) +
-                                 ITEM_NAME_NOTCLOSE + std::string ( " " ) +
+                                 ITEM_NAME_LOCK_MESSAGE + std::string ( " " ) +
                                  ITEM_NAME_QUIT + std::string ( " " ) );
 
     items_msg_toolbar =  parse_items( items_msg_toolbar_str );
@@ -381,29 +545,20 @@ void SESSION::init_session()
 
     popupmenu_shown = false;
 
-    // ディストリ判定( "/etc/issue.net"の一行目を読む )
-    std::string issue_net;
-    if( CACHE::load_rawdata( CACHE::path_issue_net(), issue_net ) )
-    {
-    	const size_t lf_pos = issue_net.find( "\n" );
-    	distribution = MISC::remove_spaces( issue_net.substr( 0, lf_pos ) );
-    }
-
     // WM 判定
     // TODO: 環境変数で判定できない場合の判定方法を考える
     win_manager = WM_UNKNON;
-    std::string str_wm;
+    const std::string str_wm = MISC::getenv_limited( "DESKTOP_SESSION", 5 );
 
-    if( getenv( "DESKTOP_SESSION" ) ) str_wm = getenv( "DESKTOP_SESSION" );
     if( str_wm.find( "xfce" ) != std::string::npos ) win_manager = WM_XFCE;
     else if( str_wm.find( "gnome" ) != std::string::npos ) win_manager = WM_GNOME;
     else if( str_wm.find( "kde" ) != std::string::npos ) win_manager = WM_KDE;
 
     if( win_manager == WM_UNKNON ){
-        if( getenv( "GNOME_DESKTOP_SESSION_ID" ) ) win_manager = WM_GNOME;
+        if( ! MISC::getenv_limited( "GNOME_DESKTOP_SESSION_ID" ).empty() ) win_manager = WM_GNOME;
         else{
 
-            if( getenv( "KDE_FULL_SESSION" ) ) str_wm = getenv( "KDE_FULL_SESSION" );
+            const std::string str_wm = MISC::getenv_limited( "KDE_FULL_SESSION", 4 );
             if( str_wm == "true" ) win_manager = WM_KDE;
         }
     }
@@ -605,8 +760,12 @@ void SESSION::set_booting( bool boot ){ booting = boot; }
 const bool SESSION::is_quitting(){ return quitting; }
 void SESSION::set_quitting( bool quit ){ quitting = quit; }
 
-// ディストリ判定
-const std::string& SESSION::get_distribution(){ return distribution; }
+// ディストリ名取得
+const std::string& SESSION::get_distribution_name()
+{
+    if( distribution_name.empty() ) distribution_name = get_distribution_name_from_environment();
+    return distribution_name;
+}
 
 // WM 判定
 const int SESSION::get_wm(){ return win_manager; }
@@ -760,7 +919,7 @@ void SESSION::set_bbslist_page( int page ){ win_bbslist_page = page; }
 // 前回閉じたときに開いていたboardのページ番号とURL
 int SESSION::board_page(){ return win_board_page; }
 void SESSION::set_board_page( int page ){ win_board_page = page; }
-const std::list< std::string >& SESSION::board_URLs(){ return board_urls; }
+std::list< std::string >& SESSION::get_board_URLs(){ return board_urls; }
 void SESSION::set_board_URLs( const std::list< std::string >& urls ){ board_urls = urls; }
 
 // スレ一覧のロック状態
@@ -770,7 +929,7 @@ void SESSION::set_board_locked( const std::list< bool >& locked ){ board_locked
 // 前回閉じたときに開いていたスレタブのページ番号とURL
 int SESSION::article_page(){ return win_article_page; }
 void SESSION::set_article_page( int page ){ win_article_page = page; }
-const std::list< std::string >& SESSION::get_article_URLs(){ return article_urls; }
+std::list< std::string >& SESSION::get_article_URLs(){ return article_urls; }
 void SESSION::set_article_URLs( const std::list< std::string >& urls ){ article_urls = urls; }
 
 // スレタブのロック状態
@@ -915,3 +1074,83 @@ void SESSION::set_dir_draft( const std::string& dir ){ dir_draft = dir; }
 // ポップアップメニュー表示中
 const bool SESSION::is_popupmenu_shown(){ return popupmenu_shown; }
 void SESSION::set_popupmenu_shown( bool shown ){ popupmenu_shown = shown; }
+
+
+// JD終了時に削除するスレのリスト
+// 実況などしたスレは削除する。 Core::~Core()を参照
+std::vector< std::string >& SESSION::get_delete_list()
+{
+    return delete_list;
+}
+
+
+void SESSION::append_delete_list( const std::string& url )
+{
+    std::vector< std::string >::iterator it = delete_list.begin();
+    for( ; it != delete_list.end(); ++it ){
+        if( ( *it ) == url ) return;
+    }
+
+    delete_list.push_back( url );
+
+#ifdef _DEBUG
+    std::cout << "SESSION::append_delete_list urls == " << delete_list.size() << " url = " << url << std::endl;
+#endif
+}
+
+
+void SESSION::remove_delete_list( const std::string& url )
+{
+    if( delete_list.empty() ) return;
+
+    std::vector< std::string >::iterator it = delete_list.begin();
+    for( ; it != delete_list.end(); ++it ) if( ( *it ) == url ){ delete_list.erase( it ); break; }
+
+#ifdef _DEBUG
+    std::cout << "SESSION::remove_delete_list urls == " << delete_list.size() << " url = " << url << std::endl;
+#endif
+}
+
+
+// 実況実行中のスレか
+const bool SESSION::is_live( const std::string& url )
+{
+#ifdef _DEBUG
+    std::cout << "SESSION::is_live live_urls == " << live_urls.size() << " url = " << url << std::endl;
+#endif
+
+    if( live_urls.empty() ) return false;
+
+    std::vector< std::string >::iterator it = live_urls.begin();
+    for( ; it != live_urls.end(); ++it ){
+#ifdef _DEBUG
+        std::cout << (*it) << std::endl;
+#endif
+        if( ( *it ) == url ) return true;
+    }
+
+    return false;
+}
+
+
+void SESSION::append_live( const std::string& url )
+{
+    if( ! is_live( url ) ) live_urls.push_back( url );
+
+#ifdef _DEBUG
+    std::cout << "SESSION::append_live live_urls == " << live_urls.size() << " url = " << url << std::endl;
+#endif
+}
+
+void SESSION::remove_live( const std::string& url )
+{
+    if( live_urls.empty() ) return;
+
+    std::vector< std::string >::iterator it = live_urls.begin();
+    for( ; it != live_urls.end(); ++it ) if( ( *it ) == url ){ live_urls.erase( it ); break; }
+
+#ifdef _DEBUG
+    std::cout << "SESSION::remove_live live_urls == " << live_urls.size() << " url = " << url << std::endl;
+#endif
+}
+
