@@ -6,7 +6,10 @@
 #ifndef _DRAGNOTE_H
 #define _DRAGNOTE_H
 
-#include "notebook.h"
+#include "tabnote.h"
+#include "toolbarnote.h"
+#include "viewnote.h"
+
 #include "tooltip.h"
 
 #include "control.h"
@@ -15,8 +18,12 @@
 
 namespace SKELETON
 {
+    class View;
+    class ToolBar;
     class TabLabel;
+    class IconPopup;
 
+    typedef sigc::signal< void, GtkNotebookPage*, int > SIG_SWITCH_PAGE;
     typedef sigc::signal< void, int > SIG_TAB_CLICK;
     typedef sigc::signal< void, int > SIG_TAB_CLOSE;
     typedef sigc::signal< void, int > SIG_TAB_RELOAD;
@@ -26,8 +33,22 @@ namespace SKELETON
     typedef sigc::signal< void, int > SIG_DRAG_BEGIN;
     typedef sigc::signal< void > SIG_DRAG_END;
 
-    class DragableNoteBook : public SKELETON::JDNotebook
+    // DragableNoteBook を構成している各Notebookの高さ
+    // 及びタブの高さや位置の情報
+    struct Alloc_NoteBook
     {
+        int height_tabbar;
+        int height_toolbar;
+        int height_view;
+
+        int x_tab;
+        int height_tab;
+        int width_tab;
+    };
+
+    class DragableNoteBook : public Gtk::VBox
+    {
+        SIG_SWITCH_PAGE m_sig_switch_page;
         SIG_TAB_CLICK m_sig_tab_click;
         SIG_TAB_CLOSE m_sig_tab_close;
         SIG_TAB_RELOAD m_sig_tab_reload;
@@ -36,7 +57,13 @@ namespace SKELETON
         SIG_DRAG_BEGIN m_sig_drag_begin;
         SIG_DRAG_END m_sig_drag_end;
 
-        Glib::RefPtr< Pango::Layout > m_layout_tab;
+        // DragableNoteBook は 下の3つのノートブックから出来ている
+        TabNotebook m_notebook_tab;  // タブ
+        ToolBarNotebook m_notebook_toolbar; // ツールバー
+        ViewNotebook m_notebook_view; // ビュー
+
+        bool m_show_tabs;
+        bool m_show_toolbar;
 
         int m_page;
         bool m_drag;
@@ -48,12 +75,12 @@ namespace SKELETON
         Tooltip m_tooltip;
 
         bool m_dragable;
-        bool m_fixtab;
 
-        int m_pre_width;
+        SKELETON::IconPopup* m_down_arrow;
 
       public:
 
+        SIG_SWITCH_PAGE signal_switch_page(){ return m_sig_switch_page; }
         SIG_TAB_CLICK sig_tab_click() { return m_sig_tab_click; }
         SIG_TAB_CLOSE sig_tab_close() { return m_sig_tab_close; }
         SIG_TAB_RELOAD sig_tab_reload(){ return m_sig_tab_reload; }
@@ -63,14 +90,38 @@ namespace SKELETON
         SIG_DRAG_END sig_drag_end() { return m_sig_drag_end; }
 
         DragableNoteBook();
+        virtual ~DragableNoteBook();
 
         void clock_in();
         void focus_out();
 
+        // DragableNoteBook を構成している各Notebookの高さ
+        // 及びタブの高さと位置を取得 ( 枠の描画用 )
+        const Alloc_NoteBook get_alloc_notebook();
+
+        const bool get_show_tabs() const{ return m_show_tabs; }
+        void set_show_tabs( bool show_tabs );
+        void set_scrollable( bool scrollable );
+        const int get_n_pages();
+        Gtk::Widget* get_nth_page( int page_num );
+        const int page_num( const Gtk::Widget& child );
+        const int get_current_page();
+        void set_current_page( int page_num );
+
         int append_page( const std::string& url, Gtk::Widget& child );
         int insert_page( const std::string& url, Gtk::Widget& child, int page );
         void remove_page( int page );
 
+        // ツールバー関係
+        void show_toolbar();
+        void hide_toolbar();
+        void append_toolbar( Gtk::Widget& toolbar );
+        void set_current_toolbar( int page_num, SKELETON::View* view );
+        const int get_current_toolbar();
+        void focus_toolbar_search(); // ツールバー内の検索entryにフォーカスを移す
+        void update_toolbar_url( std::string& url_old, std::string& url_new );
+        void update_toolbar_button();
+
         // タブの文字列取得/セット
         const std::string get_tab_fulltext( int page );
         void set_tab_fulltext( const std::string& str, int page );
@@ -81,39 +132,40 @@ namespace SKELETON
         // ドラッグ可/不可切り替え(デフォルト false );
         void set_dragable( bool dragable ){ m_dragable = dragable; }
 
-        // タブの幅を固定するか(デフォルト false );
-        void set_fixtab( bool fix ){ m_fixtab = fix; }
+        // タブの幅を固定するか
+        void set_fixtab( bool fix );
 
         // タブ幅調整
         bool adjust_tabwidth();
 
       private:
 
+        virtual bool on_expose_event( GdkEventExpose* event );
+
+        // ツールバー取得
+        SKELETON::ToolBar* get_toolbar( int page );
+
         // タブ作成
         SKELETON::TabLabel* create_tablabel( const std::string& url );
 
-        // タブ取得
-        TabLabel* get_tablabel( int page );
-        TabLabel* get_tablabel( const std::string& url );
-
-        // マウスの下にあるタブの番号
-        int get_page_under_mouse();
+        // notebook_tabのタブが切り替わったときに呼び出されるslot
+        void slot_switch_page_tab( GtkNotebookPage*, guint page );
 
+        // notebook_tab の上でボタンを押した/離した
+        bool slot_button_press_event( GdkEventButton* event );
+        bool slot_button_release_event( GdkEventButton* event );
 
       protected:
 
         // コントローラ
         CONTROL::Control& get_control(){ return m_control; }
 
-        virtual bool on_button_press_event( GdkEventButton* event );
-        virtual bool on_button_release_event( GdkEventButton* event );
-
         // タブからくるシグナルにコネクトする
         void slot_motion_event();
         void slot_leave_event();
 
         void slot_drag_begin();
-        void slot_drag_drop();
+        void slot_drag_motion( const int page, const int tab_x, const int tab_y, const int tab_width );
         void slot_drag_end();
     };
 }
