@@ -20,6 +20,11 @@
 
 using namespace SKELETON;
 
+enum
+{
+    MIN_AAMENU_LINES = 12
+};
+
 
 EditTextView::EditTextView() :
     Gtk::TextView(),
@@ -335,13 +340,13 @@ bool EditTextView::on_key_press_event( GdkEventKey* event )
         case CONTROL::UndoEdit:
         case CONTROL::InputAA:
         {
-            GtkTextView *entry = gobj();
-            if( gtk_im_context_filter_keypress( entry->im_context, event ) )
+            GtkTextView *textview = gobj();
+            if( gtk_im_context_filter_keypress( textview->im_context, event ) )
             {
 #ifdef _DEBUG    
                 std::cout << "gtk_im_context_filter_keypress\n";
 #endif
-                entry->need_im_reset = TRUE;
+                textview->need_im_reset = TRUE;
                 return true;
             }
         }
@@ -511,7 +516,7 @@ bool EditTextView::slot_write_jdinfo( GdkEventButton* event )
     const std::string version = JDVERSIONSTR;
 
     // ディストリビューション名を取得
-    const std::string distribution = SESSION::get_distribution();
+    const std::string distribution = SESSION::get_distribution_name();
 
     // デスクトップ環境を取得( 環境変数から判別可能の場合 )
     std::string desktop_environment;
@@ -526,8 +531,7 @@ bool EditTextView::slot_write_jdinfo( GdkEventButton* event )
     std::string other;
 
     // $LANG が ja_JP.UTF-8 でない場合は"その他"に追加する。
-    std::string lang;
-    if( getenv( "LANG" ) ) lang = std::string( getenv( "LANG" ) );
+    const std::string lang = MISC::getenv_limited( "LANG", 11 );
     if( lang.empty() ) other.append( "LANG 未定義" );
     else if( lang != "ja_JP.utf8" && lang != "ja_JP.UTF-8" ) other.append( "LANG = " + lang );
 
@@ -609,11 +613,18 @@ void EditTextView::show_aalist_popup()
 //
 void EditTextView::slot_popup_aamenu_pos( int& x, int& y, bool& push_in )
 {
-    Gdk::Rectangle rect = get_cursor_root_origin();
+    push_in = false;
+
+    const Gdk::Rectangle rect = get_cursor_root_origin();
+    const int line_height = rect.get_height();
+    const int sh = get_screen()->get_height();
+    const int min_height = MIN( CORE::get_aamanager()->get_size(), MIN_AAMENU_LINES ) * line_height;
 
     x = rect.get_x();
-    y = rect.get_y() + rect.get_height();
-    push_in = false;
+    y = rect.get_y() + line_height;
+
+    // 最低でも MIN_AAMENU_LINES 行よりも表示領域が高くなるようにする
+    if( y + min_height > sh ) y = sh - min_height;
 }
 
 
